<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bisou : adulte, adulte, peau claire et peau modérément claire',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bisou : adulte, adulte, peau claire et peau légèrement mate',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bisou : adulte, adulte, peau claire et peau modérément foncée',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bisou : adulte, adulte, peau claire et peau foncée',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bisou : adulte, adulte, peau modérément claire et peau claire',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bisou : adulte, adulte, peau modérément claire et peau légèrement mate',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bisou : adulte, adulte, peau modérément claire et peau modérément foncée',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bisou : adulte, adulte, peau modérément claire et peau foncée',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bisou : adulte, adulte, peau légèrement mate et peau claire',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bisou : adulte, adulte, peau légèrement mate et peau modérément claire',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bisou : adulte, adulte, peau légèrement mate et peau modérément foncée',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bisou : adulte, adulte, peau légèrement mate et peau foncée',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bisou : adulte, adulte, peau modérément foncée et peau claire',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bisou : adulte, adulte, peau modérément foncée et peau modérément claire',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bisou : adulte, adulte, peau modérément foncée et peau légèrement mate',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bisou : adulte, adulte, peau modérément foncée et peau foncée',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bisou : adulte, adulte, peau foncée et peau claire',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bisou : adulte, adulte, peau foncée et peau modérément claire',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bisou : adulte, adulte, peau foncée et peau légèrement mate',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bisou : adulte, adulte, peau foncée et peau modérément foncée',
    '👨🏻‍❤‍💋‍👨🏻' => 'bisou : homme, homme et peau claire',
    '👨🏻‍❤‍💋‍👨🏼' => 'bisou : homme, homme, peau claire et peau modérément claire',
    '👨🏻‍❤‍💋‍👨🏽' => 'bisou : homme, homme, peau claire et peau légèrement mate',
    '👨🏻‍❤‍💋‍👨🏾' => 'bisou : homme, homme, peau claire et peau modérément foncée',
    '👨🏻‍❤‍💋‍👨🏿' => 'bisou : homme, homme, peau claire et peau foncée',
    '👨🏼‍❤‍💋‍👨🏻' => 'bisou : homme, homme, peau modérément claire et peau claire',
    '👨🏼‍❤‍💋‍👨🏼' => 'bisou : homme, homme et peau modérément claire',
    '👨🏼‍❤‍💋‍👨🏽' => 'bisou : homme, homme, peau modérément claire et peau légèrement mate',
    '👨🏼‍❤‍💋‍👨🏾' => 'bisou : homme, homme, peau modérément claire et peau modérément foncée',
    '👨🏼‍❤‍💋‍👨🏿' => 'bisou : homme, homme, peau modérément claire et peau foncée',
    '👨🏽‍❤‍💋‍👨🏻' => 'bisou : homme, homme, peau légèrement mate et peau claire',
    '👨🏽‍❤‍💋‍👨🏼' => 'bisou : homme, homme, peau légèrement mate et peau modérément claire',
    '👨🏽‍❤‍💋‍👨🏽' => 'bisou : homme, homme et peau légèrement mate',
    '👨🏽‍❤‍💋‍👨🏾' => 'bisou : homme, homme, peau légèrement mate et peau modérément foncée',
    '👨🏽‍❤‍💋‍👨🏿' => 'bisou : homme, homme, peau légèrement mate et peau foncée',
    '👨🏾‍❤‍💋‍👨🏻' => 'bisou : homme, homme, peau modérément foncée et peau claire',
    '👨🏾‍❤‍💋‍👨🏼' => 'bisou : homme, homme, peau modérément foncée et peau modérément claire',
    '👨🏾‍❤‍💋‍👨🏽' => 'bisou : homme, homme, peau modérément foncée et peau légèrement mate',
    '👨🏾‍❤‍💋‍👨🏾' => 'bisou : homme, homme et peau modérément foncée',
    '👨🏾‍❤‍💋‍👨🏿' => 'bisou : homme, homme, peau modérément foncée et peau foncée',
    '👨🏿‍❤‍💋‍👨🏻' => 'bisou : homme, homme, peau foncée et peau claire',
    '👨🏿‍❤‍💋‍👨🏼' => 'bisou : homme, homme, peau foncée et peau modérément claire',
    '👨🏿‍❤‍💋‍👨🏽' => 'bisou : homme, homme, peau foncée et peau légèrement mate',
    '👨🏿‍❤‍💋‍👨🏾' => 'bisou : homme, homme, peau foncée et peau modérément foncée',
    '👨🏿‍❤‍💋‍👨🏿' => 'bisou : homme, homme et peau foncée',
    '👩🏻‍❤‍💋‍👨🏻' => 'bisou : femme, homme et peau claire',
    '👩🏻‍❤‍💋‍👨🏼' => 'bisou : femme, homme, peau claire et peau modérément claire',
    '👩🏻‍❤‍💋‍👨🏽' => 'bisou : femme, homme, peau claire et peau légèrement mate',
    '👩🏻‍❤‍💋‍👨🏾' => 'bisou : femme, homme, peau claire et peau modérément foncée',
    '👩🏻‍❤‍💋‍👨🏿' => 'bisou : femme, homme, peau claire et peau foncée',
    '👩🏼‍❤‍💋‍👨🏻' => 'bisou : femme, homme, peau modérément claire et peau claire',
    '👩🏼‍❤‍💋‍👨🏼' => 'bisou : femme, homme et peau modérément claire',
    '👩🏼‍❤‍💋‍👨🏽' => 'bisou : femme, homme, peau modérément claire et peau légèrement mate',
    '👩🏼‍❤‍💋‍👨🏾' => 'bisou : femme, homme, peau modérément claire et peau modérément foncée',
    '👩🏼‍❤‍💋‍👨🏿' => 'bisou : femme, homme, peau modérément claire et peau foncée',
    '👩🏽‍❤‍💋‍👨🏻' => 'bisou : femme, homme, peau légèrement mate et peau claire',
    '👩🏽‍❤‍💋‍👨🏼' => 'bisou : femme, homme, peau légèrement mate et peau modérément claire',
    '👩🏽‍❤‍💋‍👨🏽' => 'bisou : femme, homme et peau légèrement mate',
    '👩🏽‍❤‍💋‍👨🏾' => 'bisou : femme, homme, peau légèrement mate et peau modérément foncée',
    '👩🏽‍❤‍💋‍👨🏿' => 'bisou : femme, homme, peau légèrement mate et peau foncée',
    '👩🏾‍❤‍💋‍👨🏻' => 'bisou : femme, homme, peau modérément foncée et peau claire',
    '👩🏾‍❤‍💋‍👨🏼' => 'bisou : femme, homme, peau modérément foncée et peau modérément claire',
    '👩🏾‍❤‍💋‍👨🏽' => 'bisou : femme, homme, peau modérément foncée et peau légèrement mate',
    '👩🏾‍❤‍💋‍👨🏾' => 'bisou : femme, homme et peau modérément foncée',
    '👩🏾‍❤‍💋‍👨🏿' => 'bisou : femme, homme, peau modérément foncée et peau foncée',
    '👩🏿‍❤‍💋‍👨🏻' => 'bisou : femme, homme, peau foncée et peau claire',
    '👩🏿‍❤‍💋‍👨🏼' => 'bisou : femme, homme, peau foncée et peau modérément claire',
    '👩🏿‍❤‍💋‍👨🏽' => 'bisou : femme, homme, peau foncée et peau légèrement mate',
    '👩🏿‍❤‍💋‍👨🏾' => 'bisou : femme, homme, peau foncée et peau modérément foncée',
    '👩🏿‍❤‍💋‍👨🏿' => 'bisou : femme, homme et peau foncée',
    '👩🏻‍❤‍💋‍👩🏻' => 'bisou : femme, femme et peau claire',
    '👩🏻‍❤‍💋‍👩🏼' => 'bisou : femme, femme, peau claire et peau modérément claire',
    '👩🏻‍❤‍💋‍👩🏽' => 'bisou : femme, femme, peau claire et peau légèrement mate',
    '👩🏻‍❤‍💋‍👩🏾' => 'bisou : femme, femme, peau claire et peau modérément foncée',
    '👩🏻‍❤‍💋‍👩🏿' => 'bisou : femme, femme, peau claire et peau foncée',
    '👩🏼‍❤‍💋‍👩🏻' => 'bisou : femme, femme, peau modérément claire et peau claire',
    '👩🏼‍❤‍💋‍👩🏼' => 'bisou : femme, femme et peau modérément claire',
    '👩🏼‍❤‍💋‍👩🏽' => 'bisou : femme, femme, peau modérément claire et peau légèrement mate',
    '👩🏼‍❤‍💋‍👩🏾' => 'bisou : femme, femme, peau modérément claire et peau modérément foncée',
    '👩🏼‍❤‍💋‍👩🏿' => 'bisou : femme, femme, peau modérément claire et peau foncée',
    '👩🏽‍❤‍💋‍👩🏻' => 'bisou : femme, femme, peau légèrement mate et peau claire',
    '👩🏽‍❤‍💋‍👩🏼' => 'bisou : femme, femme, peau légèrement mate et peau modérément claire',
    '👩🏽‍❤‍💋‍👩🏽' => 'bisou : femme, femme et peau légèrement mate',
    '👩🏽‍❤‍💋‍👩🏾' => 'bisou : femme, femme, peau légèrement mate et peau modérément foncée',
    '👩🏽‍❤‍💋‍👩🏿' => 'bisou : femme, femme, peau légèrement mate et peau foncée',
    '👩🏾‍❤‍💋‍👩🏻' => 'bisou : femme, femme, peau modérément foncée et peau claire',
    '👩🏾‍❤‍💋‍👩🏼' => 'bisou : femme, femme, peau modérément foncée et peau modérément claire',
    '👩🏾‍❤‍💋‍👩🏽' => 'bisou : femme, femme, peau modérément foncée et peau légèrement mate',
    '👩🏾‍❤‍💋‍👩🏾' => 'bisou : femme, femme et peau modérément foncée',
    '👩🏾‍❤‍💋‍👩🏿' => 'bisou : femme, femme, peau modérément foncée et peau foncée',
    '👩🏿‍❤‍💋‍👩🏻' => 'bisou : femme, femme, peau foncée et peau claire',
    '👩🏿‍❤‍💋‍👩🏼' => 'bisou : femme, femme, peau foncée et peau modérément claire',
    '👩🏿‍❤‍💋‍👩🏽' => 'bisou : femme, femme, peau foncée et peau légèrement mate',
    '👩🏿‍❤‍💋‍👩🏾' => 'bisou : femme, femme, peau foncée et peau modérément foncée',
    '👩🏿‍❤‍💋‍👩🏿' => 'bisou : femme, femme et peau foncée',
    '🧑🏻‍🫯‍🧑🏼' => 'personnes faisant de la lutte : peau claire et peau modérément claire',
    '🧑🏻‍🫯‍🧑🏽' => 'personnes faisant de la lutte : peau claire et peau légèrement mate',
    '🧑🏻‍🫯‍🧑🏾' => 'personnes faisant de la lutte : peau claire et peau modérément foncée',
    '🧑🏻‍🫯‍🧑🏿' => 'personnes faisant de la lutte : peau claire et peau foncée',
    '🧑🏼‍🫯‍🧑🏻' => 'personnes faisant de la lutte : peau modérément claire et peau claire',
    '🧑🏼‍🫯‍🧑🏽' => 'personnes faisant de la lutte : peau modérément claire et peau légèrement mate',
    '🧑🏼‍🫯‍🧑🏾' => 'personnes faisant de la lutte : peau modérément claire et peau modérément foncée',
    '🧑🏼‍🫯‍🧑🏿' => 'personnes faisant de la lutte : peau modérément claire et peau foncée',
    '🧑🏽‍🫯‍🧑🏻' => 'personnes faisant de la lutte : peau légèrement mate et peau claire',
    '🧑🏽‍🫯‍🧑🏼' => 'personnes faisant de la lutte : peau légèrement mate et peau modérément claire',
    '🧑🏽‍🫯‍🧑🏾' => 'personnes faisant de la lutte : peau légèrement mate et peau modérément foncée',
    '🧑🏽‍🫯‍🧑🏿' => 'personnes faisant de la lutte : peau légèrement mate et peau foncée',
    '🧑🏾‍🫯‍🧑🏻' => 'personnes faisant de la lutte : peau modérément foncée et peau claire',
    '🧑🏾‍🫯‍🧑🏼' => 'personnes faisant de la lutte : peau modérément foncée et peau modérément claire',
    '🧑🏾‍🫯‍🧑🏽' => 'personnes faisant de la lutte : peau modérément foncée et peau légèrement mate',
    '🧑🏾‍🫯‍🧑🏿' => 'personnes faisant de la lutte : peau modérément foncée et peau foncée',
    '🧑🏿‍🫯‍🧑🏻' => 'personnes faisant de la lutte : peau foncée et peau claire',
    '🧑🏿‍🫯‍🧑🏼' => 'personnes faisant de la lutte : peau foncée et peau modérément claire',
    '🧑🏿‍🫯‍🧑🏽' => 'personnes faisant de la lutte : peau foncée et peau légèrement mate',
    '🧑🏿‍🫯‍🧑🏾' => 'personnes faisant de la lutte : peau foncée et peau modérément foncée',
    '🧑🏻‍❤‍🧑🏼' => 'couple avec cœur : adulte, adulte, peau claire et peau modérément claire',
    '🧑🏻‍❤‍🧑🏽' => 'couple avec cœur : adulte, adulte, peau claire et peau légèrement mate',
    '🧑🏻‍❤‍🧑🏾' => 'couple avec cœur : adulte, adulte, peau claire et peau modérément foncée',
    '🧑🏻‍❤‍🧑🏿' => 'couple avec cœur : adulte, adulte, peau claire et peau foncée',
    '🧑🏼‍❤‍🧑🏻' => 'couple avec cœur : adulte, adulte, peau modérément claire et peau claire',
    '🧑🏼‍❤‍🧑🏽' => 'couple avec cœur : adulte, adulte, peau modérément claire et peau légèrement mate',
    '🧑🏼‍❤‍🧑🏾' => 'couple avec cœur : adulte, adulte, peau modérément claire et peau modérément foncée',
    '🧑🏼‍❤‍🧑🏿' => 'couple avec cœur : adulte, adulte, peau modérément claire et peau foncée',
    '🧑🏽‍❤‍🧑🏻' => 'couple avec cœur : adulte, adulte, peau légèrement mate et peau claire',
    '🧑🏽‍❤‍🧑🏼' => 'couple avec cœur : adulte, adulte, peau légèrement mate et peau modérément claire',
    '🧑🏽‍❤‍🧑🏾' => 'couple avec cœur : adulte, adulte, peau légèrement mate et peau modérément foncée',
    '🧑🏽‍❤‍🧑🏿' => 'couple avec cœur : adulte, adulte, peau légèrement mate et peau foncée',
    '🧑🏾‍❤‍🧑🏻' => 'couple avec cœur : adulte, adulte, peau modérément foncée et peau claire',
    '🧑🏾‍❤‍🧑🏼' => 'couple avec cœur : adulte, adulte, peau modérément foncée et peau modérément claire',
    '🧑🏾‍❤‍🧑🏽' => 'couple avec cœur : adulte, adulte, peau modérément foncée et peau légèrement mate',
    '🧑🏾‍❤‍🧑🏿' => 'couple avec cœur : adulte, adulte, peau modérément foncée et peau foncée',
    '🧑🏿‍❤‍🧑🏻' => 'couple avec cœur : adulte, adulte, peau foncée et peau claire',
    '🧑🏿‍❤‍🧑🏼' => 'couple avec cœur : adulte, adulte, peau foncée et peau modérément claire',
    '🧑🏿‍❤‍🧑🏽' => 'couple avec cœur : adulte, adulte, peau foncée et peau légèrement mate',
    '🧑🏿‍❤‍🧑🏾' => 'couple avec cœur : adulte, adulte, peau foncée et peau modérément foncée',
    '🧑🏻‍🐰‍🧑🏼' => 'personnes qui portent des oreilles de lapin : peau claire et peau modérément claire',
    '🧑🏻‍🐰‍🧑🏽' => 'personnes qui portent des oreilles de lapin : peau claire et peau légèrement mate',
    '🧑🏻‍🐰‍🧑🏾' => 'personnes qui portent des oreilles de lapin : peau claire et peau modérément foncée',
    '🧑🏻‍🐰‍🧑🏿' => 'personnes qui portent des oreilles de lapin : peau claire et peau foncée',
    '🧑🏼‍🐰‍🧑🏻' => 'personnes qui portent des oreilles de lapin : peau modérément claire et peau claire',
    '🧑🏼‍🐰‍🧑🏽' => 'personnes qui portent des oreilles de lapin : peau modérément claire et peau légèrement mate',
    '🧑🏼‍🐰‍🧑🏾' => 'personnes qui portent des oreilles de lapin : peau modérément claire et peau modérément foncée',
    '🧑🏼‍🐰‍🧑🏿' => 'personnes qui portent des oreilles de lapin : peau modérément claire et peau foncée',
    '🧑🏽‍🐰‍🧑🏻' => 'personnes qui portent des oreilles de lapin : peau légèrement mate et peau claire',
    '🧑🏽‍🐰‍🧑🏼' => 'personnes qui portent des oreilles de lapin : peau légèrement mate et peau modérément claire',
    '🧑🏽‍🐰‍🧑🏾' => 'personnes qui portent des oreilles de lapin : peau légèrement mate et peau modérément foncée',
    '🧑🏽‍🐰‍🧑🏿' => 'personnes qui portent des oreilles de lapin : peau légèrement mate et peau foncée',
    '🧑🏾‍🐰‍🧑🏻' => 'personnes qui portent des oreilles de lapin : peau modérément foncée et peau claire',
    '🧑🏾‍🐰‍🧑🏼' => 'personnes qui portent des oreilles de lapin : peau modérément foncée et peau modérément claire',
    '🧑🏾‍🐰‍🧑🏽' => 'personnes qui portent des oreilles de lapin : peau modérément foncée et peau légèrement mate',
    '🧑🏾‍🐰‍🧑🏿' => 'personnes qui portent des oreilles de lapin : peau modérément foncée et peau foncée',
    '🧑🏿‍🐰‍🧑🏻' => 'personnes qui portent des oreilles de lapin : peau foncée et peau claire',
    '🧑🏿‍🐰‍🧑🏼' => 'personnes qui portent des oreilles de lapin : peau foncée et peau modérément claire',
    '🧑🏿‍🐰‍🧑🏽' => 'personnes qui portent des oreilles de lapin : peau foncée et peau légèrement mate',
    '🧑🏿‍🐰‍🧑🏾' => 'personnes qui portent des oreilles de lapin : peau foncée et peau modérément foncée',
    '👨🏻‍🫯‍👨🏼' => 'lutteurs : peau claire et peau modérément claire',
    '👨🏻‍🫯‍👨🏽' => 'lutteurs : peau claire et peau légèrement mate',
    '👨🏻‍🫯‍👨🏾' => 'lutteurs : peau claire et peau modérément foncée',
    '👨🏻‍🫯‍👨🏿' => 'lutteurs : peau claire et peau foncée',
    '👨🏼‍🫯‍👨🏻' => 'lutteurs : peau modérément claire et peau claire',
    '👨🏼‍🫯‍👨🏽' => 'lutteurs : peau modérément claire et peau légèrement mate',
    '👨🏼‍🫯‍👨🏾' => 'lutteurs : peau modérément claire et peau modérément foncée',
    '👨🏼‍🫯‍👨🏿' => 'lutteurs : peau modérément claire et peau foncée',
    '👨🏽‍🫯‍👨🏻' => 'lutteurs : peau légèrement mate et peau claire',
    '👨🏽‍🫯‍👨🏼' => 'lutteurs : peau légèrement mate et peau modérément claire',
    '👨🏽‍🫯‍👨🏾' => 'lutteurs : peau légèrement mate et peau modérément foncée',
    '👨🏽‍🫯‍👨🏿' => 'lutteurs : peau légèrement mate et peau foncée',
    '👨🏾‍🫯‍👨🏻' => 'lutteurs : peau modérément foncée et peau claire',
    '👨🏾‍🫯‍👨🏼' => 'lutteurs : peau modérément foncée et peau modérément claire',
    '👨🏾‍🫯‍👨🏽' => 'lutteurs : peau modérément foncée et peau légèrement mate',
    '👨🏾‍🫯‍👨🏿' => 'lutteurs : peau modérément foncée et peau foncée',
    '👨🏿‍🫯‍👨🏻' => 'lutteurs : peau foncée et peau claire',
    '👨🏿‍🫯‍👨🏼' => 'lutteurs : peau foncée et peau modérément claire',
    '👨🏿‍🫯‍👨🏽' => 'lutteurs : peau foncée et peau légèrement mate',
    '👨🏿‍🫯‍👨🏾' => 'lutteurs : peau foncée et peau modérément foncée',
    '👨🏻‍❤‍👨🏻' => 'couple avec cœur : homme, homme et peau claire',
    '👨🏻‍❤‍👨🏼' => 'couple avec cœur : homme, homme, peau claire et peau modérément claire',
    '👨🏻‍❤‍👨🏽' => 'couple avec cœur : homme, homme, peau claire et peau légèrement mate',
    '👨🏻‍❤‍👨🏾' => 'couple avec cœur : homme, homme, peau claire et peau modérément foncée',
    '👨🏻‍❤‍👨🏿' => 'couple avec cœur : homme, homme, peau claire et peau foncée',
    '👨🏼‍❤‍👨🏻' => 'couple avec cœur : homme, homme, peau modérément claire et peau claire',
    '👨🏼‍❤‍👨🏼' => 'couple avec cœur : homme, homme et peau modérément claire',
    '👨🏼‍❤‍👨🏽' => 'couple avec cœur : homme, homme, peau modérément claire et peau légèrement mate',
    '👨🏼‍❤‍👨🏾' => 'couple avec cœur : homme, homme, peau modérément claire et peau modérément foncée',
    '👨🏼‍❤‍👨🏿' => 'couple avec cœur : homme, homme, peau modérément claire et peau foncée',
    '👨🏽‍❤‍👨🏻' => 'couple avec cœur : homme, homme, peau légèrement mate et peau claire',
    '👨🏽‍❤‍👨🏼' => 'couple avec cœur : homme, homme, peau légèrement mate et peau modérément claire',
    '👨🏽‍❤‍👨🏽' => 'couple avec cœur : homme, homme et peau légèrement mate',
    '👨🏽‍❤‍👨🏾' => 'couple avec cœur : homme, homme, peau légèrement mate et peau modérément foncée',
    '👨🏽‍❤‍👨🏿' => 'couple avec cœur : homme, homme, peau légèrement mate et peau foncée',
    '👨🏾‍❤‍👨🏻' => 'couple avec cœur : homme, homme, peau modérément foncée et peau claire',
    '👨🏾‍❤‍👨🏼' => 'couple avec cœur : homme, homme, peau modérément foncée et peau modérément claire',
    '👨🏾‍❤‍👨🏽' => 'couple avec cœur : homme, homme, peau modérément foncée et peau légèrement mate',
    '👨🏾‍❤‍👨🏾' => 'couple avec cœur : homme, homme et peau modérément foncée',
    '👨🏾‍❤‍👨🏿' => 'couple avec cœur : homme, homme, peau modérément foncée et peau foncée',
    '👨🏿‍❤‍👨🏻' => 'couple avec cœur : homme, homme, peau foncée et peau claire',
    '👨🏿‍❤‍👨🏼' => 'couple avec cœur : homme, homme, peau foncée et peau modérément claire',
    '👨🏿‍❤‍👨🏽' => 'couple avec cœur : homme, homme, peau foncée et peau légèrement mate',
    '👨🏿‍❤‍👨🏾' => 'couple avec cœur : homme, homme, peau foncée et peau modérément foncée',
    '👨🏿‍❤‍👨🏿' => 'couple avec cœur : homme, homme et peau foncée',
    '👨🏻‍🐰‍👨🏼' => 'hommes qui portent des oreilles de lapin : peau claire et peau modérément claire',
    '👨🏻‍🐰‍👨🏽' => 'hommes qui portent des oreilles de lapin : peau claire et peau légèrement mate',
    '👨🏻‍🐰‍👨🏾' => 'hommes qui portent des oreilles de lapin : peau claire et peau modérément foncée',
    '👨🏻‍🐰‍👨🏿' => 'hommes qui portent des oreilles de lapin : peau claire et peau foncée',
    '👨🏼‍🐰‍👨🏻' => 'hommes qui portent des oreilles de lapin : peau modérément claire et peau claire',
    '👨🏼‍🐰‍👨🏽' => 'hommes qui portent des oreilles de lapin : peau modérément claire et peau légèrement mate',
    '👨🏼‍🐰‍👨🏾' => 'hommes qui portent des oreilles de lapin : peau modérément claire et peau modérément foncée',
    '👨🏼‍🐰‍👨🏿' => 'hommes qui portent des oreilles de lapin : peau modérément claire et peau foncée',
    '👨🏽‍🐰‍👨🏻' => 'hommes qui portent des oreilles de lapin : peau légèrement mate et peau claire',
    '👨🏽‍🐰‍👨🏼' => 'hommes qui portent des oreilles de lapin : peau légèrement mate et peau modérément claire',
    '👨🏽‍🐰‍👨🏾' => 'hommes qui portent des oreilles de lapin : peau légèrement mate et peau modérément foncée',
    '👨🏽‍🐰‍👨🏿' => 'hommes qui portent des oreilles de lapin : peau légèrement mate et peau foncée',
    '👨🏾‍🐰‍👨🏻' => 'hommes qui portent des oreilles de lapin : peau modérément foncée et peau claire',
    '👨🏾‍🐰‍👨🏼' => 'hommes qui portent des oreilles de lapin : peau modérément foncée et peau modérément claire',
    '👨🏾‍🐰‍👨🏽' => 'hommes qui portent des oreilles de lapin : peau modérément foncée et peau légèrement mate',
    '👨🏾‍🐰‍👨🏿' => 'hommes qui portent des oreilles de lapin : peau modérément foncée et peau foncée',
    '👨🏿‍🐰‍👨🏻' => 'hommes qui portent des oreilles de lapin : peau foncée et peau claire',
    '👨🏿‍🐰‍👨🏼' => 'hommes qui portent des oreilles de lapin : peau foncée et peau modérément claire',
    '👨🏿‍🐰‍👨🏽' => 'hommes qui portent des oreilles de lapin : peau foncée et peau légèrement mate',
    '👨🏿‍🐰‍👨🏾' => 'hommes qui portent des oreilles de lapin : peau foncée et peau modérément foncée',
    '👩🏻‍🫯‍👩🏼' => 'lutteuses : peau claire et peau modérément claire',
    '👩🏻‍🫯‍👩🏽' => 'lutteuses : peau claire et peau légèrement mate',
    '👩🏻‍🫯‍👩🏾' => 'lutteuses : peau claire et peau modérément foncée',
    '👩🏻‍🫯‍👩🏿' => 'lutteuses : peau claire et peau foncée',
    '👩🏼‍🫯‍👩🏻' => 'lutteuses : peau modérément claire et peau claire',
    '👩🏼‍🫯‍👩🏽' => 'lutteuses : peau modérément claire et peau légèrement mate',
    '👩🏼‍🫯‍👩🏾' => 'lutteuses : peau modérément claire et peau modérément foncée',
    '👩🏼‍🫯‍👩🏿' => 'lutteuses : peau modérément claire et peau foncée',
    '👩🏽‍🫯‍👩🏻' => 'lutteuses : peau légèrement mate et peau claire',
    '👩🏽‍🫯‍👩🏼' => 'lutteuses : peau légèrement mate et peau modérément claire',
    '👩🏽‍🫯‍👩🏾' => 'lutteuses : peau légèrement mate et peau modérément foncée',
    '👩🏽‍🫯‍👩🏿' => 'lutteuses : peau légèrement mate et peau foncée',
    '👩🏾‍🫯‍👩🏻' => 'lutteuses : peau modérément foncée et peau claire',
    '👩🏾‍🫯‍👩🏼' => 'lutteuses : peau modérément foncée et peau modérément claire',
    '👩🏾‍🫯‍👩🏽' => 'lutteuses : peau modérément foncée et peau légèrement mate',
    '👩🏾‍🫯‍👩🏿' => 'lutteuses : peau modérément foncée et peau foncée',
    '👩🏿‍🫯‍👩🏻' => 'lutteuses : peau foncée et peau claire',
    '👩🏿‍🫯‍👩🏼' => 'lutteuses : peau foncée et peau modérément claire',
    '👩🏿‍🫯‍👩🏽' => 'lutteuses : peau foncée et peau légèrement mate',
    '👩🏿‍🫯‍👩🏾' => 'lutteuses : peau foncée et peau modérément foncée',
    '👩🏻‍❤‍👨🏻' => 'couple avec cœur : femme, homme et peau claire',
    '👩🏻‍❤‍👨🏼' => 'couple avec cœur : femme, homme, peau claire et peau modérément claire',
    '👩🏻‍❤‍👨🏽' => 'couple avec cœur : femme, homme, peau claire et peau légèrement mate',
    '👩🏻‍❤‍👨🏾' => 'couple avec cœur : femme, homme, peau claire et peau modérément foncée',
    '👩🏻‍❤‍👨🏿' => 'couple avec cœur : femme, homme, peau claire et peau foncée',
    '👩🏼‍❤‍👨🏻' => 'couple avec cœur : femme, homme, peau modérément claire et peau claire',
    '👩🏼‍❤‍👨🏼' => 'couple avec cœur : femme, homme et peau modérément claire',
    '👩🏼‍❤‍👨🏽' => 'couple avec cœur : femme, homme, peau modérément claire et peau légèrement mate',
    '👩🏼‍❤‍👨🏾' => 'couple avec cœur : femme, homme, peau modérément claire et peau modérément foncée',
    '👩🏼‍❤‍👨🏿' => 'couple avec cœur : femme, homme, peau modérément claire et peau foncée',
    '👩🏽‍❤‍👨🏻' => 'couple avec cœur : femme, homme, peau légèrement mate et peau claire',
    '👩🏽‍❤‍👨🏼' => 'couple avec cœur : femme, homme, peau légèrement mate et peau modérément claire',
    '👩🏽‍❤‍👨🏽' => 'couple avec cœur : femme, homme et peau légèrement mate',
    '👩🏽‍❤‍👨🏾' => 'couple avec cœur : femme, homme, peau légèrement mate et peau modérément foncée',
    '👩🏽‍❤‍👨🏿' => 'couple avec cœur : femme, homme, peau légèrement mate et peau foncée',
    '👩🏾‍❤‍👨🏻' => 'couple avec cœur : femme, homme, peau modérément foncée et peau claire',
    '👩🏾‍❤‍👨🏼' => 'couple avec cœur : femme, homme, peau modérément foncée et peau modérément claire',
    '👩🏾‍❤‍👨🏽' => 'couple avec cœur : femme, homme, peau modérément foncée et peau légèrement mate',
    '👩🏾‍❤‍👨🏾' => 'couple avec cœur : femme, homme et peau modérément foncée',
    '👩🏾‍❤‍👨🏿' => 'couple avec cœur : femme, homme, peau modérément foncée et peau foncée',
    '👩🏿‍❤‍👨🏻' => 'couple avec cœur : femme, homme, peau foncée et peau claire',
    '👩🏿‍❤‍👨🏼' => 'couple avec cœur : femme, homme, peau foncée et peau modérément claire',
    '👩🏿‍❤‍👨🏽' => 'couple avec cœur : femme, homme, peau foncée et peau légèrement mate',
    '👩🏿‍❤‍👨🏾' => 'couple avec cœur : femme, homme, peau foncée et peau modérément foncée',
    '👩🏿‍❤‍👨🏿' => 'couple avec cœur : femme, homme et peau foncée',
    '👩🏻‍❤‍👩🏻' => 'couple avec cœur : femme, femme et peau claire',
    '👩🏻‍❤‍👩🏼' => 'couple avec cœur : femme, femme, peau claire et peau modérément claire',
    '👩🏻‍❤‍👩🏽' => 'couple avec cœur : femme, femme, peau claire et peau légèrement mate',
    '👩🏻‍❤‍👩🏾' => 'couple avec cœur : femme, femme, peau claire et peau modérément foncée',
    '👩🏻‍❤‍👩🏿' => 'couple avec cœur : femme, femme, peau claire et peau foncée',
    '👩🏼‍❤‍👩🏻' => 'couple avec cœur : femme, femme, peau modérément claire et peau claire',
    '👩🏼‍❤‍👩🏼' => 'couple avec cœur : femme, femme et peau modérément claire',
    '👩🏼‍❤‍👩🏽' => 'couple avec cœur : femme, femme, peau modérément claire et peau légèrement mate',
    '👩🏼‍❤‍👩🏾' => 'couple avec cœur : femme, femme, peau modérément claire et peau modérément foncée',
    '👩🏼‍❤‍👩🏿' => 'couple avec cœur : femme, femme, peau modérément claire et peau foncée',
    '👩🏽‍❤‍👩🏻' => 'couple avec cœur : femme, femme, peau légèrement mate et peau claire',
    '👩🏽‍❤‍👩🏼' => 'couple avec cœur : femme, femme, peau légèrement mate et peau modérément claire',
    '👩🏽‍❤‍👩🏽' => 'couple avec cœur : femme, femme et peau légèrement mate',
    '👩🏽‍❤‍👩🏾' => 'couple avec cœur : femme, femme, peau légèrement mate et peau modérément foncée',
    '👩🏽‍❤‍👩🏿' => 'couple avec cœur : femme, femme, peau légèrement mate et peau foncée',
    '👩🏾‍❤‍👩🏻' => 'couple avec cœur : femme, femme, peau modérément foncée et peau claire',
    '👩🏾‍❤‍👩🏼' => 'couple avec cœur : femme, femme, peau modérément foncée et peau modérément claire',
    '👩🏾‍❤‍👩🏽' => 'couple avec cœur : femme, femme, peau modérément foncée et peau légèrement mate',
    '👩🏾‍❤‍👩🏾' => 'couple avec cœur : femme, femme et peau modérément foncée',
    '👩🏾‍❤‍👩🏿' => 'couple avec cœur : femme, femme, peau modérément foncée et peau foncée',
    '👩🏿‍❤‍👩🏻' => 'couple avec cœur : femme, femme, peau foncée et peau claire',
    '👩🏿‍❤‍👩🏼' => 'couple avec cœur : femme, femme, peau foncée et peau modérément claire',
    '👩🏿‍❤‍👩🏽' => 'couple avec cœur : femme, femme, peau foncée et peau légèrement mate',
    '👩🏿‍❤‍👩🏾' => 'couple avec cœur : femme, femme, peau foncée et peau modérément foncée',
    '👩🏿‍❤‍👩🏿' => 'couple avec cœur : femme, femme et peau foncée',
    '👩🏻‍🐰‍👩🏼' => 'femmes qui portent des oreilles de lapin : peau claire et peau modérément claire',
    '👩🏻‍🐰‍👩🏽' => 'femmes qui portent des oreilles de lapin : peau claire et peau légèrement mate',
    '👩🏻‍🐰‍👩🏾' => 'femmes qui portent des oreilles de lapin : peau claire et peau modérément foncée',
    '👩🏻‍🐰‍👩🏿' => 'femmes qui portent des oreilles de lapin : peau claire et peau foncée',
    '👩🏼‍🐰‍👩🏻' => 'femmes qui portent des oreilles de lapin : peau modérément claire et peau claire',
    '👩🏼‍🐰‍👩🏽' => 'femmes qui portent des oreilles de lapin : peau modérément claire et peau légèrement mate',
    '👩🏼‍🐰‍👩🏾' => 'femmes qui portent des oreilles de lapin : peau modérément claire et peau modérément foncée',
    '👩🏼‍🐰‍👩🏿' => 'femmes qui portent des oreilles de lapin : peau modérément claire et peau foncée',
    '👩🏽‍🐰‍👩🏻' => 'femmes qui portent des oreilles de lapin : peau légèrement mate et peau claire',
    '👩🏽‍🐰‍👩🏼' => 'femmes qui portent des oreilles de lapin : peau légèrement mate et peau modérément claire',
    '👩🏽‍🐰‍👩🏾' => 'femmes qui portent des oreilles de lapin : peau légèrement mate et peau modérément foncée',
    '👩🏽‍🐰‍👩🏿' => 'femmes qui portent des oreilles de lapin : peau légèrement mate et peau foncée',
    '👩🏾‍🐰‍👩🏻' => 'femmes qui portent des oreilles de lapin : peau modérément foncée et peau claire',
    '👩🏾‍🐰‍👩🏼' => 'femmes qui portent des oreilles de lapin : peau modérément foncée et peau modérément claire',
    '👩🏾‍🐰‍👩🏽' => 'femmes qui portent des oreilles de lapin : peau modérément foncée et peau légèrement mate',
    '👩🏾‍🐰‍👩🏿' => 'femmes qui portent des oreilles de lapin : peau modérément foncée et peau foncée',
    '👩🏿‍🐰‍👩🏻' => 'femmes qui portent des oreilles de lapin : peau foncée et peau claire',
    '👩🏿‍🐰‍👩🏼' => 'femmes qui portent des oreilles de lapin : peau foncée et peau modérément claire',
    '👩🏿‍🐰‍👩🏽' => 'femmes qui portent des oreilles de lapin : peau foncée et peau légèrement mate',
    '👩🏿‍🐰‍👩🏾' => 'femmes qui portent des oreilles de lapin : peau foncée et peau modérément foncée',
    '🧑🏻‍🤝‍🧑🏻' => 'personnes se tenant par la main : peau claire',
    '🧑🏻‍🤝‍🧑🏼' => 'personnes se tenant par la main : peau claire et peau modérément claire',
    '🧑🏻‍🤝‍🧑🏽' => 'personnes se tenant par la main : peau claire et peau légèrement mate',
    '🧑🏻‍🤝‍🧑🏾' => 'personnes se tenant par la main : peau claire et peau modérément foncée',
    '🧑🏻‍🤝‍🧑🏿' => 'personnes se tenant par la main : peau claire et peau foncée',
    '🧑🏼‍🤝‍🧑🏻' => 'personnes se tenant par la main : peau modérément claire et peau claire',
    '🧑🏼‍🤝‍🧑🏼' => 'personnes se tenant par la main : peau modérément claire',
    '🧑🏼‍🤝‍🧑🏽' => 'personnes se tenant par la main : peau modérément claire et peau légèrement mate',
    '🧑🏼‍🤝‍🧑🏾' => 'personnes se tenant par la main : peau modérément claire et peau modérément foncée',
    '🧑🏼‍🤝‍🧑🏿' => 'personnes se tenant par la main : peau modérément claire et peau foncée',
    '🧑🏽‍🤝‍🧑🏻' => 'personnes se tenant par la main : peau légèrement mate et peau claire',
    '🧑🏽‍🤝‍🧑🏼' => 'personnes se tenant par la main : peau légèrement mate et peau modérément claire',
    '🧑🏽‍🤝‍🧑🏽' => 'personnes se tenant par la main : peau légèrement mate',
    '🧑🏽‍🤝‍🧑🏾' => 'personnes se tenant par la main : peau légèrement mate et peau modérément foncée',
    '🧑🏽‍🤝‍🧑🏿' => 'personnes se tenant par la main : peau légèrement mate et peau foncée',
    '🧑🏾‍🤝‍🧑🏻' => 'personnes se tenant par la main : peau modérément foncée et peau claire',
    '🧑🏾‍🤝‍🧑🏼' => 'personnes se tenant par la main : peau modérément foncée et peau modérément claire',
    '🧑🏾‍🤝‍🧑🏽' => 'personnes se tenant par la main : peau modérément foncée et peau légèrement mate',
    '🧑🏾‍🤝‍🧑🏾' => 'personnes se tenant par la main : peau modérément foncée',
    '🧑🏾‍🤝‍🧑🏿' => 'personnes se tenant par la main : peau modérément foncée et peau foncée',
    '🧑🏿‍🤝‍🧑🏻' => 'personnes se tenant par la main : peau foncée et peau claire',
    '🧑🏿‍🤝‍🧑🏼' => 'personnes se tenant par la main : peau foncée et peau modérément claire',
    '🧑🏿‍🤝‍🧑🏽' => 'personnes se tenant par la main : peau foncée et peau légèrement mate',
    '🧑🏿‍🤝‍🧑🏾' => 'personnes se tenant par la main : peau foncée et peau modérément foncée',
    '🧑🏿‍🤝‍🧑🏿' => 'personnes se tenant par la main : peau foncée',
    '👩🏻‍🤝‍👩🏼' => 'deux femmes se tenant par la main : peau claire et peau modérément claire',
    '👩🏻‍🤝‍👩🏽' => 'deux femmes se tenant par la main : peau claire et peau légèrement mate',
    '👩🏻‍🤝‍👩🏾' => 'deux femmes se tenant par la main : peau claire et peau modérément foncée',
    '👩🏻‍🤝‍👩🏿' => 'deux femmes se tenant par la main : peau claire et peau foncée',
    '👩🏼‍🤝‍👩🏻' => 'deux femmes se tenant par la main : peau modérément claire et peau claire',
    '👩🏼‍🤝‍👩🏽' => 'deux femmes se tenant par la main : peau modérément claire et peau légèrement mate',
    '👩🏼‍🤝‍👩🏾' => 'deux femmes se tenant par la main : peau modérément claire et peau modérément foncée',
    '👩🏼‍🤝‍👩🏿' => 'deux femmes se tenant par la main : peau modérément claire et peau foncée',
    '👩🏽‍🤝‍👩🏻' => 'deux femmes se tenant par la main : peau légèrement mate et peau claire',
    '👩🏽‍🤝‍👩🏼' => 'deux femmes se tenant par la main : peau légèrement mate et peau modérément claire',
    '👩🏽‍🤝‍👩🏾' => 'deux femmes se tenant par la main : peau légèrement mate et peau modérément foncée',
    '👩🏽‍🤝‍👩🏿' => 'deux femmes se tenant par la main : peau légèrement mate et peau foncée',
    '👩🏾‍🤝‍👩🏻' => 'deux femmes se tenant par la main : peau modérément foncée et peau claire',
    '👩🏾‍🤝‍👩🏼' => 'deux femmes se tenant par la main : peau modérément foncée et peau modérément claire',
    '👩🏾‍🤝‍👩🏽' => 'deux femmes se tenant par la main : peau modérément foncée et peau légèrement mate',
    '👩🏾‍🤝‍👩🏿' => 'deux femmes se tenant par la main : peau modérément foncée et peau foncée',
    '👩🏿‍🤝‍👩🏻' => 'deux femmes se tenant par la main : peau foncée et peau claire',
    '👩🏿‍🤝‍👩🏼' => 'deux femmes se tenant par la main : peau foncée et peau modérément claire',
    '👩🏿‍🤝‍👩🏽' => 'deux femmes se tenant par la main : peau foncée et peau légèrement mate',
    '👩🏿‍🤝‍👩🏾' => 'deux femmes se tenant par la main : peau foncée et peau modérément foncée',
    '👩🏻‍🤝‍👨🏼' => 'homme et femme se tenant par la main : peau claire et peau modérément claire',
    '👩🏻‍🤝‍👨🏽' => 'homme et femme se tenant par la main : peau claire et peau légèrement mate',
    '👩🏻‍🤝‍👨🏾' => 'homme et femme se tenant par la main : peau claire et peau modérément foncée',
    '👩🏻‍🤝‍👨🏿' => 'homme et femme se tenant par la main : peau claire et peau foncée',
    '👩🏼‍🤝‍👨🏻' => 'homme et femme se tenant par la main : peau modérément claire et peau claire',
    '👩🏼‍🤝‍👨🏽' => 'homme et femme se tenant par la main : peau modérément claire et peau légèrement mate',
    '👩🏼‍🤝‍👨🏾' => 'homme et femme se tenant par la main : peau modérément claire et peau modérément foncée',
    '👩🏼‍🤝‍👨🏿' => 'homme et femme se tenant par la main : peau modérément claire et peau foncée',
    '👩🏽‍🤝‍👨🏻' => 'homme et femme se tenant par la main : peau légèrement mate et peau claire',
    '👩🏽‍🤝‍👨🏼' => 'homme et femme se tenant par la main : peau légèrement mate et peau modérément claire',
    '👩🏽‍🤝‍👨🏾' => 'homme et femme se tenant par la main : peau légèrement mate et peau modérément foncée',
    '👩🏽‍🤝‍👨🏿' => 'homme et femme se tenant par la main : peau légèrement mate et peau foncée',
    '👩🏾‍🤝‍👨🏻' => 'homme et femme se tenant par la main : peau modérément foncée et peau claire',
    '👩🏾‍🤝‍👨🏼' => 'homme et femme se tenant par la main : peau modérément foncée et peau modérément claire',
    '👩🏾‍🤝‍👨🏽' => 'homme et femme se tenant par la main : peau modérément foncée et peau légèrement mate',
    '👩🏾‍🤝‍👨🏿' => 'homme et femme se tenant par la main : peau modérément foncée et peau foncée',
    '👩🏿‍🤝‍👨🏻' => 'homme et femme se tenant par la main : peau foncée et peau claire',
    '👩🏿‍🤝‍👨🏼' => 'homme et femme se tenant par la main : peau foncée et peau modérément claire',
    '👩🏿‍🤝‍👨🏽' => 'homme et femme se tenant par la main : peau foncée et peau légèrement mate',
    '👩🏿‍🤝‍👨🏾' => 'homme et femme se tenant par la main : peau foncée et peau modérément foncée',
    '👨🏻‍🤝‍👨🏼' => 'deux hommes se tenant par la main : peau claire et peau modérément claire',
    '👨🏻‍🤝‍👨🏽' => 'deux hommes se tenant par la main : peau claire et peau légèrement mate',
    '👨🏻‍🤝‍👨🏾' => 'deux hommes se tenant par la main : peau claire et peau modérément foncée',
    '👨🏻‍🤝‍👨🏿' => 'deux hommes se tenant par la main : peau claire et peau foncée',
    '👨🏼‍🤝‍👨🏻' => 'deux hommes se tenant par la main : peau modérément claire et peau claire',
    '👨🏼‍🤝‍👨🏽' => 'deux hommes se tenant par la main : peau modérément claire et peau légèrement mate',
    '👨🏼‍🤝‍👨🏾' => 'deux hommes se tenant par la main : peau modérément claire et peau modérément foncée',
    '👨🏼‍🤝‍👨🏿' => 'deux hommes se tenant par la main : peau modérément claire et peau foncée',
    '👨🏽‍🤝‍👨🏻' => 'deux hommes se tenant par la main : peau légèrement mate et peau claire',
    '👨🏽‍🤝‍👨🏼' => 'deux hommes se tenant par la main : peau légèrement mate et peau modérément claire',
    '👨🏽‍🤝‍👨🏾' => 'deux hommes se tenant par la main : peau légèrement mate et peau modérément foncée',
    '👨🏽‍🤝‍👨🏿' => 'deux hommes se tenant par la main : peau légèrement mate et peau foncée',
    '👨🏾‍🤝‍👨🏻' => 'deux hommes se tenant par la main : peau modérément foncée et peau claire',
    '👨🏾‍🤝‍👨🏼' => 'deux hommes se tenant par la main : peau modérément foncée et peau modérément claire',
    '👨🏾‍🤝‍👨🏽' => 'deux hommes se tenant par la main : peau modérément foncée et peau légèrement mate',
    '👨🏾‍🤝‍👨🏿' => 'deux hommes se tenant par la main : peau modérément foncée et peau foncée',
    '👨🏿‍🤝‍👨🏻' => 'deux hommes se tenant par la main : peau foncée et peau claire',
    '👨🏿‍🤝‍👨🏼' => 'deux hommes se tenant par la main : peau foncée et peau modérément claire',
    '👨🏿‍🤝‍👨🏽' => 'deux hommes se tenant par la main : peau foncée et peau légèrement mate',
    '👨🏿‍🤝‍👨🏾' => 'deux hommes se tenant par la main : peau foncée et peau modérément foncée',
    '👩‍❤‍💋‍👨' => 'bisou : femme et homme',
    '👨‍❤‍💋‍👨' => 'bisou : homme et homme',
    '👩‍❤‍💋‍👩' => 'bisou : femme et femme',
    '👨‍👩‍👧‍👦' => 'famille : homme, femme, fille et garçon',
    '👨‍👩‍👦‍👦' => 'famille : homme, femme, garçon et garçon',
    '👨‍👩‍👧‍👧' => 'famille : homme, femme, fille et fille',
    '👨‍👨‍👧‍👦' => 'famille : homme, homme, fille et garçon',
    '👨‍👨‍👦‍👦' => 'famille : homme, homme, garçon et garçon',
    '👨‍👨‍👧‍👧' => 'famille : homme, homme, fille et fille',
    '👩‍👩‍👧‍👦' => 'famille : femme, femme, fille et garçon',
    '👩‍👩‍👦‍👦' => 'famille : femme, femme, garçon et garçon',
    '👩‍👩‍👧‍👧' => 'famille : femme, femme, fille et fille',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'drapeau : Angleterre',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'drapeau : Écosse',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'drapeau : Pays de Galles',
    '🧑‍🧑‍🧒‍🧒' => 'famille : adulte, adulte, enfant, enfant',
    '🚶🏻‍♀‍➡' => 'femme qui marche : peau claire et vers la droite',
    '🚶🏼‍♀‍➡' => 'femme qui marche : peau modérément claire et vers la droite',
    '🚶🏽‍♀‍➡' => 'femme qui marche : peau légèrement mate et vers la droite',
    '🚶🏾‍♀‍➡' => 'femme qui marche : peau modérément foncée et vers la droite',
    '🚶🏿‍♀‍➡' => 'femme qui marche : peau foncée et vers la droite',
    '🚶🏻‍♂‍➡' => 'homme qui marche : peau claire et vers la droite',
    '🚶🏼‍♂‍➡' => 'homme qui marche : peau modérément claire et vers la droite',
    '🚶🏽‍♂‍➡' => 'homme qui marche : peau légèrement mate et vers la droite',
    '🚶🏾‍♂‍➡' => 'homme qui marche : peau modérément foncée et vers la droite',
    '🚶🏿‍♂‍➡' => 'homme qui marche : peau foncée et vers la droite',
    '🧎🏻‍♀‍➡' => 'femme à genoux : peau claire et vers la droite',
    '🧎🏼‍♀‍➡' => 'femme à genoux : peau modérément claire et vers la droite',
    '🧎🏽‍♀‍➡' => 'femme à genoux : peau légèrement mate et vers la droite',
    '🧎🏾‍♀‍➡' => 'femme à genoux : peau modérément foncée et vers la droite',
    '🧎🏿‍♀‍➡' => 'femme à genoux : peau foncée et vers la droite',
    '🧎🏻‍♂‍➡' => 'homme à genoux : peau claire et vers la droite',
    '🧎🏼‍♂‍➡' => 'homme à genoux : peau modérément claire et vers la droite',
    '🧎🏽‍♂‍➡' => 'homme à genoux : peau légèrement mate et vers la droite',
    '🧎🏾‍♂‍➡' => 'homme à genoux : peau modérément foncée et vers la droite',
    '🧎🏿‍♂‍➡' => 'homme à genoux : peau foncée et vers la droite',
    '🧑🏻‍🦯‍➡' => 'personne avec une canne blanche : peau claire et vers la droite',
    '🧑🏼‍🦯‍➡' => 'personne avec une canne blanche : peau modérément claire et vers la droite',
    '🧑🏽‍🦯‍➡' => 'personne avec une canne blanche : peau légèrement mate et vers la droite',
    '🧑🏾‍🦯‍➡' => 'personne avec une canne blanche : peau modérément foncée et vers la droite',
    '🧑🏿‍🦯‍➡' => 'personne avec une canne blanche : peau foncée et vers la droite',
    '👨🏻‍🦯‍➡' => 'homme avec canne blanche : peau claire et vers la droite',
    '👨🏼‍🦯‍➡' => 'homme avec canne blanche : peau modérément claire et vers la droite',
    '👨🏽‍🦯‍➡' => 'homme avec canne blanche : peau légèrement mate et vers la droite',
    '👨🏾‍🦯‍➡' => 'homme avec canne blanche : peau modérément foncée et vers la droite',
    '👨🏿‍🦯‍➡' => 'homme avec canne blanche : peau foncée et vers la droite',
    '👩🏻‍🦯‍➡' => 'femme avec canne blanche : peau claire et vers la droite',
    '👩🏼‍🦯‍➡' => 'femme avec canne blanche : peau modérément claire et vers la droite',
    '👩🏽‍🦯‍➡' => 'femme avec canne blanche : peau légèrement mate et vers la droite',
    '👩🏾‍🦯‍➡' => 'femme avec canne blanche : peau modérément foncée et vers la droite',
    '👩🏿‍🦯‍➡' => 'femme avec canne blanche : peau foncée et vers la droite',
    '🧑🏻‍🦼‍➡' => 'personne en fauteuil motorisé : peau claire et vers la droite',
    '🧑🏼‍🦼‍➡' => 'personne en fauteuil motorisé : peau modérément claire et vers la droite',
    '🧑🏽‍🦼‍➡' => 'personne en fauteuil motorisé : peau légèrement mate et vers la droite',
    '🧑🏾‍🦼‍➡' => 'personne en fauteuil motorisé : peau modérément foncée et vers la droite',
    '🧑🏿‍🦼‍➡' => 'personne en fauteuil motorisé : peau foncée et vers la droite',
    '👨🏻‍🦼‍➡' => 'homme en fauteuil motorisé : peau claire et vers la droite',
    '👨🏼‍🦼‍➡' => 'homme en fauteuil motorisé : peau modérément claire et vers la droite',
    '👨🏽‍🦼‍➡' => 'homme en fauteuil motorisé : peau légèrement mate et vers la droite',
    '👨🏾‍🦼‍➡' => 'homme en fauteuil motorisé : peau modérément foncée et vers la droite',
    '👨🏿‍🦼‍➡' => 'homme en fauteuil motorisé : peau foncée et vers la droite',
    '👩🏻‍🦼‍➡' => 'femme en fauteuil motorisé : peau claire et vers la droite',
    '👩🏼‍🦼‍➡' => 'femme en fauteuil motorisé : peau modérément claire et vers la droite',
    '👩🏽‍🦼‍➡' => 'femme en fauteuil motorisé : peau légèrement mate et vers la droite',
    '👩🏾‍🦼‍➡' => 'femme en fauteuil motorisé : peau modérément foncée et vers la droite',
    '👩🏿‍🦼‍➡' => 'femme en fauteuil motorisé : peau foncée et vers la droite',
    '🧑🏻‍🦽‍➡' => 'personne en fauteuil roulant manuel : peau claire et vers la droite',
    '🧑🏼‍🦽‍➡' => 'personne en fauteuil roulant manuel : peau modérément claire et vers la droite',
    '🧑🏽‍🦽‍➡' => 'personne en fauteuil roulant manuel : peau légèrement mate et vers la droite',
    '🧑🏾‍🦽‍➡' => 'personne en fauteuil roulant manuel : peau modérément foncée et vers la droite',
    '🧑🏿‍🦽‍➡' => 'personne en fauteuil roulant manuel : peau foncée et vers la droite',
    '👨🏻‍🦽‍➡' => 'homme en fauteuil roulant manuel : peau claire et vers la droite',
    '👨🏼‍🦽‍➡' => 'homme en fauteuil roulant manuel : peau modérément claire et vers la droite',
    '👨🏽‍🦽‍➡' => 'homme en fauteuil roulant manuel : peau légèrement mate et vers la droite',
    '👨🏾‍🦽‍➡' => 'homme en fauteuil roulant manuel : peau modérément foncée et vers la droite',
    '👨🏿‍🦽‍➡' => 'homme en fauteuil roulant manuel : peau foncée et vers la droite',
    '👩🏻‍🦽‍➡' => 'femme en fauteuil roulant manuel : peau claire et vers la droite',
    '👩🏼‍🦽‍➡' => 'femme en fauteuil roulant manuel : peau modérément claire et vers la droite',
    '👩🏽‍🦽‍➡' => 'femme en fauteuil roulant manuel : peau légèrement mate et vers la droite',
    '👩🏾‍🦽‍➡' => 'femme en fauteuil roulant manuel : peau modérément foncée et vers la droite',
    '👩🏿‍🦽‍➡' => 'femme en fauteuil roulant manuel : peau foncée et vers la droite',
    '🏃🏻‍♀‍➡' => 'femme qui court : peau claire et vers la droite',
    '🏃🏼‍♀‍➡' => 'femme qui court : peau modérément claire et vers la droite',
    '🏃🏽‍♀‍➡' => 'femme qui court : peau légèrement mate et vers la droite',
    '🏃🏾‍♀‍➡' => 'femme qui court : peau modérément foncée et vers la droite',
    '🏃🏿‍♀‍➡' => 'femme qui court : peau foncée et vers la droite',
    '🏃🏻‍♂‍➡' => 'homme qui court : peau claire et vers la droite',
    '🏃🏼‍♂‍➡' => 'homme qui court : peau modérément claire et vers la droite',
    '🏃🏽‍♂‍➡' => 'homme qui court : peau légèrement mate et vers la droite',
    '🏃🏾‍♂‍➡' => 'homme qui court : peau modérément foncée et vers la droite',
    '🏃🏿‍♂‍➡' => 'homme qui court : peau foncée et vers la droite',
    '🫱🏻‍🫲🏼' => 'poignée de main : peau claire et peau modérément claire',
    '🫱🏻‍🫲🏽' => 'poignée de main : peau claire et peau légèrement mate',
    '🫱🏻‍🫲🏾' => 'poignée de main : peau claire et peau modérément foncée',
    '🫱🏻‍🫲🏿' => 'poignée de main : peau claire et peau foncée',
    '🫱🏼‍🫲🏻' => 'poignée de main : peau modérément claire et peau claire',
    '🫱🏼‍🫲🏽' => 'poignée de main : peau modérément claire et peau légèrement mate',
    '🫱🏼‍🫲🏾' => 'poignée de main : peau modérément claire et peau modérément foncée',
    '🫱🏼‍🫲🏿' => 'poignée de main : peau modérément claire et peau foncée',
    '🫱🏽‍🫲🏻' => 'poignée de main : peau légèrement mate et peau claire',
    '🫱🏽‍🫲🏼' => 'poignée de main : peau légèrement mate et peau modérément claire',
    '🫱🏽‍🫲🏾' => 'poignée de main : peau légèrement mate et peau modérément foncée',
    '🫱🏽‍🫲🏿' => 'poignée de main : peau légèrement mate et peau foncée',
    '🫱🏾‍🫲🏻' => 'poignée de main : peau modérément foncée et peau claire',
    '🫱🏾‍🫲🏼' => 'poignée de main : peau modérément foncée et peau modérément claire',
    '🫱🏾‍🫲🏽' => 'poignée de main : peau modérément foncée et peau légèrement mate',
    '🫱🏾‍🫲🏿' => 'poignée de main : peau modérément foncée et peau foncée',
    '🫱🏿‍🫲🏻' => 'poignée de main : peau foncée et peau claire',
    '🫱🏿‍🫲🏼' => 'poignée de main : peau foncée et peau modérément claire',
    '🫱🏿‍🫲🏽' => 'poignée de main : peau foncée et peau légèrement mate',
    '🫱🏿‍🫲🏾' => 'poignée de main : peau foncée et peau modérément foncée',
    '🚶‍♀‍➡' => 'femme qui marche : vers la droite',
    '🚶‍♂‍➡' => 'homme qui marche : vers la droite',
    '🧎‍♀‍➡' => 'femme à genoux : vers la droite',
    '🧎‍♂‍➡' => 'homme à genoux : vers la droite',
    '🧑‍🦯‍➡' => 'personne avec une canne blanche : vers la droite',
    '👨‍🦯‍➡' => 'homme avec canne blanche : vers la droite',
    '👩‍🦯‍➡' => 'femme avec canne blanche : vers la droite',
    '🧑‍🦼‍➡' => 'personne en fauteuil motorisé : vers la droite',
    '👨‍🦼‍➡' => 'homme en fauteuil motorisé : vers la droite',
    '👩‍🦼‍➡' => 'femme en fauteuil motorisé : vers la droite',
    '🧑‍🦽‍➡' => 'personne en fauteuil roulant manuel : vers la droite',
    '👨‍🦽‍➡' => 'homme en fauteuil roulant manuel : vers la droite',
    '👩‍🦽‍➡' => 'femme en fauteuil roulant manuel : vers la droite',
    '🏃‍♀‍➡' => 'femme qui court : vers la droite',
    '🏃‍♂‍➡' => 'homme qui court : vers la droite',
    '👩‍❤‍👨' => 'couple avec cœur : femme et homme',
    '👨‍❤‍👨' => 'couple avec cœur : homme et homme',
    '👩‍❤‍👩' => 'couple avec cœur : femme et femme',
    '👨‍👩‍👦' => 'famille : homme, femme et garçon',
    '👨‍👩‍👧' => 'famille : homme, femme et fille',
    '👨‍👨‍👦' => 'famille : homme, homme et garçon',
    '👨‍👨‍👧' => 'famille : homme, homme et fille',
    '👩‍👩‍👦' => 'famille : femme, femme et garçon',
    '👩‍👩‍👧' => 'famille : femme, femme et fille',
    '👨‍👦‍👦' => 'famille : homme, garçon et garçon',
    '👨‍👧‍👦' => 'famille : homme, fille et garçon',
    '👨‍👧‍👧' => 'famille : homme, fille et fille',
    '👩‍👦‍👦' => 'famille : femme, garçon et garçon',
    '👩‍👧‍👦' => 'famille : femme, fille et garçon',
    '👩‍👧‍👧' => 'famille : femme, fille et fille',
    '🧑‍🤝‍🧑' => 'personnes se tenant par la main',
    '🧑‍🧑‍🧒' => 'famille : adulte, adulte, enfant',
    '🧑‍🧒‍🧒' => 'famille : adulte, enfant, enfant',
    '🧑🏻‍🦰' => 'adulte : peau claire et cheveux roux',
    '🧑🏼‍🦰' => 'adulte : peau modérément claire et cheveux roux',
    '🧑🏽‍🦰' => 'adulte : peau légèrement mate et cheveux roux',
    '🧑🏾‍🦰' => 'adulte : peau modérément foncée et cheveux roux',
    '🧑🏿‍🦰' => 'adulte : peau foncée et cheveux roux',
    '🧑🏻‍🦱' => 'adulte : peau claire et cheveux bouclés',
    '🧑🏼‍🦱' => 'adulte : peau modérément claire et cheveux bouclés',
    '🧑🏽‍🦱' => 'adulte : peau légèrement mate et cheveux bouclés',
    '🧑🏾‍🦱' => 'adulte : peau modérément foncée et cheveux bouclés',
    '🧑🏿‍🦱' => 'adulte : peau foncée et cheveux bouclés',
    '🧑🏻‍🦳' => 'adulte : peau claire et cheveux blancs',
    '🧑🏼‍🦳' => 'adulte : peau modérément claire et cheveux blancs',
    '🧑🏽‍🦳' => 'adulte : peau légèrement mate et cheveux blancs',
    '🧑🏾‍🦳' => 'adulte : peau modérément foncée et cheveux blancs',
    '🧑🏿‍🦳' => 'adulte : peau foncée et cheveux blancs',
    '🧑🏻‍🦲' => 'adulte : peau claire et chauve',
    '🧑🏼‍🦲' => 'adulte : peau modérément claire et chauve',
    '🧑🏽‍🦲' => 'adulte : peau légèrement mate et chauve',
    '🧑🏾‍🦲' => 'adulte : peau modérément foncée et chauve',
    '🧑🏿‍🦲' => 'adulte : peau foncée et chauve',
    '🧑🏻‍🩰' => 'danseuse de ballet : peau claire',
    '🧑🏼‍🩰' => 'danseuse de ballet : peau modérément claire',
    '🧑🏽‍🩰' => 'danseuse de ballet : peau légèrement mate',
    '🧑🏾‍🩰' => 'danseuse de ballet : peau modérément foncée',
    '🧑🏿‍🩰' => 'danseuse de ballet : peau foncée',
    '🧔🏻‍♂' => 'homme barbu : peau claire',
    '🧔🏼‍♂' => 'homme barbu : peau modérément claire',
    '🧔🏽‍♂' => 'homme barbu : peau légèrement mate',
    '🧔🏾‍♂' => 'homme barbu : peau modérément foncée',
    '🧔🏿‍♂' => 'homme barbu : peau foncée',
    '👱🏻‍♂' => 'homme blond : peau claire',
    '👱🏼‍♂' => 'homme blond : peau modérément claire',
    '👱🏽‍♂' => 'homme blond : peau légèrement mate',
    '👱🏾‍♂' => 'homme blond : peau modérément foncée',
    '👱🏿‍♂' => 'homme blond : peau foncée',
    '👨🏻‍🦰' => 'homme : peau claire et cheveux roux',
    '👨🏼‍🦰' => 'homme : peau modérément claire et cheveux roux',
    '👨🏽‍🦰' => 'homme : peau légèrement mate et cheveux roux',
    '👨🏾‍🦰' => 'homme : peau modérément foncée et cheveux roux',
    '👨🏿‍🦰' => 'homme : peau foncée et cheveux roux',
    '👨🏻‍🦱' => 'homme : peau claire et cheveux bouclés',
    '👨🏼‍🦱' => 'homme : peau modérément claire et cheveux bouclés',
    '👨🏽‍🦱' => 'homme : peau légèrement mate et cheveux bouclés',
    '👨🏾‍🦱' => 'homme : peau modérément foncée et cheveux bouclés',
    '👨🏿‍🦱' => 'homme : peau foncée et cheveux bouclés',
    '👨🏻‍🦳' => 'homme : peau claire et cheveux blancs',
    '👨🏼‍🦳' => 'homme : peau modérément claire et cheveux blancs',
    '👨🏽‍🦳' => 'homme : peau légèrement mate et cheveux blancs',
    '👨🏾‍🦳' => 'homme : peau modérément foncée et cheveux blancs',
    '👨🏿‍🦳' => 'homme : peau foncée et cheveux blancs',
    '👨🏻‍🦲' => 'homme : peau claire et chauve',
    '👨🏼‍🦲' => 'homme : peau modérément claire et chauve',
    '👨🏽‍🦲' => 'homme : peau légèrement mate et chauve',
    '👨🏾‍🦲' => 'homme : peau modérément foncée et chauve',
    '👨🏿‍🦲' => 'homme : peau foncée et chauve',
    '🧔🏻‍♀' => 'femme barbue : peau claire',
    '🧔🏼‍♀' => 'femme barbue : peau modérément claire',
    '🧔🏽‍♀' => 'femme barbue : peau légèrement mate',
    '🧔🏾‍♀' => 'femme barbue : peau modérément foncée',
    '🧔🏿‍♀' => 'femme barbue : peau foncée',
    '👱🏻‍♀' => 'femme blonde : peau claire',
    '👱🏼‍♀' => 'femme blonde : peau modérément claire',
    '👱🏽‍♀' => 'femme blonde : peau légèrement mate',
    '👱🏾‍♀' => 'femme blonde : peau modérément foncée',
    '👱🏿‍♀' => 'femme blonde : peau foncée',
    '👩🏻‍🦰' => 'femme : peau claire et cheveux roux',
    '👩🏼‍🦰' => 'femme : peau modérément claire et cheveux roux',
    '👩🏽‍🦰' => 'femme : peau légèrement mate et cheveux roux',
    '👩🏾‍🦰' => 'femme : peau modérément foncée et cheveux roux',
    '👩🏿‍🦰' => 'femme : peau foncée et cheveux roux',
    '👩🏻‍🦱' => 'femme : peau claire et cheveux bouclés',
    '👩🏼‍🦱' => 'femme : peau modérément claire et cheveux bouclés',
    '👩🏽‍🦱' => 'femme : peau légèrement mate et cheveux bouclés',
    '👩🏾‍🦱' => 'femme : peau modérément foncée et cheveux bouclés',
    '👩🏿‍🦱' => 'femme : peau foncée et cheveux bouclés',
    '👩🏻‍🦳' => 'femme : peau claire et cheveux blancs',
    '👩🏼‍🦳' => 'femme : peau modérément claire et cheveux blancs',
    '👩🏽‍🦳' => 'femme : peau légèrement mate et cheveux blancs',
    '👩🏾‍🦳' => 'femme : peau modérément foncée et cheveux blancs',
    '👩🏿‍🦳' => 'femme : peau foncée et cheveux blancs',
    '👩🏻‍🦲' => 'femme : peau claire et chauve',
    '👩🏼‍🦲' => 'femme : peau modérément claire et chauve',
    '👩🏽‍🦲' => 'femme : peau légèrement mate et chauve',
    '👩🏾‍🦲' => 'femme : peau modérément foncée et chauve',
    '👩🏿‍🦲' => 'femme : peau foncée et chauve',
    '🙍🏻‍♂' => 'homme fronçant les sourcils : peau claire',
    '🙍🏼‍♂' => 'homme fronçant les sourcils : peau modérément claire',
    '🙍🏽‍♂' => 'homme fronçant les sourcils : peau légèrement mate',
    '🙍🏾‍♂' => 'homme fronçant les sourcils : peau modérément foncée',
    '🙍🏿‍♂' => 'homme fronçant les sourcils : peau foncée',
    '🙍🏻‍♀' => 'femme fronçant les sourcils : peau claire',
    '🙍🏼‍♀' => 'femme fronçant les sourcils : peau modérément claire',
    '🙍🏽‍♀' => 'femme fronçant les sourcils : peau légèrement mate',
    '🙍🏾‍♀' => 'femme fronçant les sourcils : peau modérément foncée',
    '🙍🏿‍♀' => 'femme fronçant les sourcils : peau foncée',
    '🙎🏻‍♂' => 'homme qui boude : peau claire',
    '🙎🏼‍♂' => 'homme qui boude : peau modérément claire',
    '🙎🏽‍♂' => 'homme qui boude : peau légèrement mate',
    '🙎🏾‍♂' => 'homme qui boude : peau modérément foncée',
    '🙎🏿‍♂' => 'homme qui boude : peau foncée',
    '🙎🏻‍♀' => 'femme qui boude : peau claire',
    '🙎🏼‍♀' => 'femme qui boude : peau modérément claire',
    '🙎🏽‍♀' => 'femme qui boude : peau légèrement mate',
    '🙎🏾‍♀' => 'femme qui boude : peau modérément foncée',
    '🙎🏿‍♀' => 'femme qui boude : peau foncée',
    '🙅🏻‍♂' => 'homme faisant un geste de négation : peau claire',
    '🙅🏼‍♂' => 'homme faisant un geste de négation : peau modérément claire',
    '🙅🏽‍♂' => 'homme faisant un geste de négation : peau légèrement mate',
    '🙅🏾‍♂' => 'homme faisant un geste de négation : peau modérément foncée',
    '🙅🏿‍♂' => 'homme faisant un geste de négation : peau foncée',
    '🙅🏻‍♀' => 'femme faisant un geste de négation : peau claire',
    '🙅🏼‍♀' => 'femme faisant un geste de négation : peau modérément claire',
    '🙅🏽‍♀' => 'femme faisant un geste de négation : peau légèrement mate',
    '🙅🏾‍♀' => 'femme faisant un geste de négation : peau modérément foncée',
    '🙅🏿‍♀' => 'femme faisant un geste de négation : peau foncée',
    '🙆🏻‍♂' => 'homme faisant un geste d’affirmation : peau claire',
    '🙆🏼‍♂' => 'homme faisant un geste d’affirmation : peau modérément claire',
    '🙆🏽‍♂' => 'homme faisant un geste d’affirmation : peau légèrement mate',
    '🙆🏾‍♂' => 'homme faisant un geste d’affirmation : peau modérément foncée',
    '🙆🏿‍♂' => 'homme faisant un geste d’affirmation : peau foncée',
    '🙆🏻‍♀' => 'femme faisant un geste d’affirmation : peau claire',
    '🙆🏼‍♀' => 'femme faisant un geste d’affirmation : peau modérément claire',
    '🙆🏽‍♀' => 'femme faisant un geste d’affirmation : peau légèrement mate',
    '🙆🏾‍♀' => 'femme faisant un geste d’affirmation : peau modérément foncée',
    '🙆🏿‍♀' => 'femme faisant un geste d’affirmation : peau foncée',
    '💁🏻‍♂' => 'homme paume vers le haut : peau claire',
    '💁🏼‍♂' => 'homme paume vers le haut : peau modérément claire',
    '💁🏽‍♂' => 'homme paume vers le haut : peau légèrement mate',
    '💁🏾‍♂' => 'homme paume vers le haut : peau modérément foncée',
    '💁🏿‍♂' => 'homme paume vers le haut : peau foncée',
    '💁🏻‍♀' => 'guichetière : peau claire',
    '💁🏼‍♀' => 'guichetière : peau modérément claire',
    '💁🏽‍♀' => 'guichetière : peau légèrement mate',
    '💁🏾‍♀' => 'guichetière : peau modérément foncée',
    '💁🏿‍♀' => 'guichetière : peau foncée',
    '🙋🏻‍♂' => 'homme qui lève la main : peau claire',
    '🙋🏼‍♂' => 'homme qui lève la main : peau modérément claire',
    '🙋🏽‍♂' => 'homme qui lève la main : peau légèrement mate',
    '🙋🏾‍♂' => 'homme qui lève la main : peau modérément foncée',
    '🙋🏿‍♂' => 'homme qui lève la main : peau foncée',
    '🙋🏻‍♀' => 'femme qui lève la main : peau claire',
    '🙋🏼‍♀' => 'femme qui lève la main : peau modérément claire',
    '🙋🏽‍♀' => 'femme qui lève la main : peau légèrement mate',
    '🙋🏾‍♀' => 'femme qui lève la main : peau modérément foncée',
    '🙋🏿‍♀' => 'femme qui lève la main : peau foncée',
    '🧏🏻‍♂' => 'homme sourd : peau claire',
    '🧏🏼‍♂' => 'homme sourd : peau modérément claire',
    '🧏🏽‍♂' => 'homme sourd : peau légèrement mate',
    '🧏🏾‍♂' => 'homme sourd : peau modérément foncée',
    '🧏🏿‍♂' => 'homme sourd : peau foncée',
    '🧏🏻‍♀' => 'femme sourde : peau claire',
    '🧏🏼‍♀' => 'femme sourde : peau modérément claire',
    '🧏🏽‍♀' => 'femme sourde : peau légèrement mate',
    '🧏🏾‍♀' => 'femme sourde : peau modérément foncée',
    '🧏🏿‍♀' => 'femme sourde : peau foncée',
    '🙇🏻‍♂' => 'homme qui s’incline : peau claire',
    '🙇🏼‍♂' => 'homme qui s’incline : peau modérément claire',
    '🙇🏽‍♂' => 'homme qui s’incline : peau légèrement mate',
    '🙇🏾‍♂' => 'homme qui s’incline : peau modérément foncée',
    '🙇🏿‍♂' => 'homme qui s’incline : peau foncée',
    '🙇🏻‍♀' => 'femme qui s’incline : peau claire',
    '🙇🏼‍♀' => 'femme qui s’incline : peau modérément claire',
    '🙇🏽‍♀' => 'femme qui s’incline : peau légèrement mate',
    '🙇🏾‍♀' => 'femme qui s’incline : peau modérément foncée',
    '🙇🏿‍♀' => 'femme qui s’incline : peau foncée',
    '🤦🏻‍♂' => 'homme avec la paume sur le visage : peau claire',
    '🤦🏼‍♂' => 'homme avec la paume sur le visage : peau modérément claire',
    '🤦🏽‍♂' => 'homme avec la paume sur le visage : peau légèrement mate',
    '🤦🏾‍♂' => 'homme avec la paume sur le visage : peau modérément foncée',
    '🤦🏿‍♂' => 'homme avec la paume sur le visage : peau foncée',
    '🤦🏻‍♀' => 'femme avec paume de la main sur le visage : peau claire',
    '🤦🏼‍♀' => 'femme avec paume de la main sur le visage : peau modérément claire',
    '🤦🏽‍♀' => 'femme avec paume de la main sur le visage : peau légèrement mate',
    '🤦🏾‍♀' => 'femme avec paume de la main sur le visage : peau modérément foncée',
    '🤦🏿‍♀' => 'femme avec paume de la main sur le visage : peau foncée',
    '🤷🏻‍♂' => 'homme qui hausse les épaules : peau claire',
    '🤷🏼‍♂' => 'homme qui hausse les épaules : peau modérément claire',
    '🤷🏽‍♂' => 'homme qui hausse les épaules : peau légèrement mate',
    '🤷🏾‍♂' => 'homme qui hausse les épaules : peau modérément foncée',
    '🤷🏿‍♂' => 'homme qui hausse les épaules : peau foncée',
    '🤷🏻‍♀' => 'femme qui hausse les épaules : peau claire',
    '🤷🏼‍♀' => 'femme qui hausse les épaules : peau modérément claire',
    '🤷🏽‍♀' => 'femme qui hausse les épaules : peau légèrement mate',
    '🤷🏾‍♀' => 'femme qui hausse les épaules : peau modérément foncée',
    '🤷🏿‍♀' => 'femme qui hausse les épaules : peau foncée',
    '🧑🏻‍⚕' => 'professionnel de la santé : peau claire',
    '🧑🏼‍⚕' => 'professionnel de la santé : peau modérément claire',
    '🧑🏽‍⚕' => 'professionnel de la santé : peau légèrement mate',
    '🧑🏾‍⚕' => 'professionnel de la santé : peau modérément foncée',
    '🧑🏿‍⚕' => 'professionnel de la santé : peau foncée',
    '👨🏻‍⚕' => 'professionnel de la santé homme : peau claire',
    '👨🏼‍⚕' => 'professionnel de la santé homme : peau modérément claire',
    '👨🏽‍⚕' => 'professionnel de la santé homme : peau légèrement mate',
    '👨🏾‍⚕' => 'professionnel de la santé homme : peau modérément foncée',
    '👨🏿‍⚕' => 'professionnel de la santé homme : peau foncée',
    '👩🏻‍⚕' => 'professionnelle de la santé : peau claire',
    '👩🏼‍⚕' => 'professionnelle de la santé : peau modérément claire',
    '👩🏽‍⚕' => 'professionnelle de la santé : peau légèrement mate',
    '👩🏾‍⚕' => 'professionnelle de la santé : peau modérément foncée',
    '👩🏿‍⚕' => 'professionnelle de la santé : peau foncée',
    '🧑🏻‍🎓' => 'étudiant universitaire : peau claire',
    '🧑🏼‍🎓' => 'étudiant universitaire : peau modérément claire',
    '🧑🏽‍🎓' => 'étudiant universitaire : peau légèrement mate',
    '🧑🏾‍🎓' => 'étudiant universitaire : peau modérément foncée',
    '🧑🏿‍🎓' => 'étudiant universitaire : peau foncée',
    '👨🏻‍🎓' => 'étudiant : peau claire',
    '👨🏼‍🎓' => 'étudiant : peau modérément claire',
    '👨🏽‍🎓' => 'étudiant : peau légèrement mate',
    '👨🏾‍🎓' => 'étudiant : peau modérément foncée',
    '👨🏿‍🎓' => 'étudiant : peau foncée',
    '👩🏻‍🎓' => 'étudiante : peau claire',
    '👩🏼‍🎓' => 'étudiante : peau modérément claire',
    '👩🏽‍🎓' => 'étudiante : peau légèrement mate',
    '👩🏾‍🎓' => 'étudiante : peau modérément foncée',
    '👩🏿‍🎓' => 'étudiante : peau foncée',
    '🧑🏻‍🏫' => 'personnel enseignant : peau claire',
    '🧑🏼‍🏫' => 'personnel enseignant : peau modérément claire',
    '🧑🏽‍🏫' => 'personnel enseignant : peau légèrement mate',
    '🧑🏾‍🏫' => 'personnel enseignant : peau modérément foncée',
    '🧑🏿‍🏫' => 'personnel enseignant : peau foncée',
    '👨🏻‍🏫' => 'enseignant : peau claire',
    '👨🏼‍🏫' => 'enseignant : peau modérément claire',
    '👨🏽‍🏫' => 'enseignant : peau légèrement mate',
    '👨🏾‍🏫' => 'enseignant : peau modérément foncée',
    '👨🏿‍🏫' => 'enseignant : peau foncée',
    '👩🏻‍🏫' => 'enseignante : peau claire',
    '👩🏼‍🏫' => 'enseignante : peau modérément claire',
    '👩🏽‍🏫' => 'enseignante : peau légèrement mate',
    '👩🏾‍🏫' => 'enseignante : peau modérément foncée',
    '👩🏿‍🏫' => 'enseignante : peau foncée',
    '🧑🏻‍⚖' => 'juge : peau claire',
    '🧑🏼‍⚖' => 'juge : peau modérément claire',
    '🧑🏽‍⚖' => 'juge : peau légèrement mate',
    '🧑🏾‍⚖' => 'juge : peau modérément foncée',
    '🧑🏿‍⚖' => 'juge : peau foncée',
    '👨🏻‍⚖' => 'juge homme : peau claire',
    '👨🏼‍⚖' => 'juge homme : peau modérément claire',
    '👨🏽‍⚖' => 'juge homme : peau légèrement mate',
    '👨🏾‍⚖' => 'juge homme : peau modérément foncée',
    '👨🏿‍⚖' => 'juge homme : peau foncée',
    '👩🏻‍⚖' => 'juge femme : peau claire',
    '👩🏼‍⚖' => 'juge femme : peau modérément claire',
    '👩🏽‍⚖' => 'juge femme : peau légèrement mate',
    '👩🏾‍⚖' => 'juge femme : peau modérément foncée',
    '👩🏿‍⚖' => 'juge femme : peau foncée',
    '🧑🏻‍🌾' => 'fermier : peau claire',
    '🧑🏼‍🌾' => 'fermier : peau modérément claire',
    '🧑🏽‍🌾' => 'fermier : peau légèrement mate',
    '🧑🏾‍🌾' => 'fermier : peau modérément foncée',
    '🧑🏿‍🌾' => 'fermier : peau foncée',
    '👨🏻‍🌾' => 'fermier homme : peau claire',
    '👨🏼‍🌾' => 'fermier homme : peau modérément claire',
    '👨🏽‍🌾' => 'fermier homme : peau légèrement mate',
    '👨🏾‍🌾' => 'fermier homme : peau modérément foncée',
    '👨🏿‍🌾' => 'fermier homme : peau foncée',
    '👩🏻‍🌾' => 'fermière : peau claire',
    '👩🏼‍🌾' => 'fermière : peau modérément claire',
    '👩🏽‍🌾' => 'fermière : peau légèrement mate',
    '👩🏾‍🌾' => 'fermière : peau modérément foncée',
    '👩🏿‍🌾' => 'fermière : peau foncée',
    '🧑🏻‍🍳' => 'chef : peau claire',
    '🧑🏼‍🍳' => 'chef : peau modérément claire',
    '🧑🏽‍🍳' => 'chef : peau légèrement mate',
    '🧑🏾‍🍳' => 'chef : peau modérément foncée',
    '🧑🏿‍🍳' => 'chef : peau foncée',
    '👨🏻‍🍳' => 'cuisinier : peau claire',
    '👨🏼‍🍳' => 'cuisinier : peau modérément claire',
    '👨🏽‍🍳' => 'cuisinier : peau légèrement mate',
    '👨🏾‍🍳' => 'cuisinier : peau modérément foncée',
    '👨🏿‍🍳' => 'cuisinier : peau foncée',
    '👩🏻‍🍳' => 'cuisinière : peau claire',
    '👩🏼‍🍳' => 'cuisinière : peau modérément claire',
    '👩🏽‍🍳' => 'cuisinière : peau légèrement mate',
    '👩🏾‍🍳' => 'cuisinière : peau modérément foncée',
    '👩🏿‍🍳' => 'cuisinière : peau foncée',
    '🧑🏻‍🔧' => 'mécanicien : peau claire',
    '🧑🏼‍🔧' => 'mécanicien : peau modérément claire',
    '🧑🏽‍🔧' => 'mécanicien : peau légèrement mate',
    '🧑🏾‍🔧' => 'mécanicien : peau modérément foncée',
    '🧑🏿‍🔧' => 'mécanicien : peau foncée',
    '👨🏻‍🔧' => 'mécanicien homme : peau claire',
    '👨🏼‍🔧' => 'mécanicien homme : peau modérément claire',
    '👨🏽‍🔧' => 'mécanicien homme : peau légèrement mate',
    '👨🏾‍🔧' => 'mécanicien homme : peau modérément foncée',
    '👨🏿‍🔧' => 'mécanicien homme : peau foncée',
    '👩🏻‍🔧' => 'mécanicienne : peau claire',
    '👩🏼‍🔧' => 'mécanicienne : peau modérément claire',
    '👩🏽‍🔧' => 'mécanicienne : peau légèrement mate',
    '👩🏾‍🔧' => 'mécanicienne : peau modérément foncée',
    '👩🏿‍🔧' => 'mécanicienne : peau foncée',
    '🧑🏻‍🏭' => 'travailleur d’usine : peau claire',
    '🧑🏼‍🏭' => 'travailleur d’usine : peau modérément claire',
    '🧑🏽‍🏭' => 'travailleur d’usine : peau légèrement mate',
    '🧑🏾‍🏭' => 'travailleur d’usine : peau modérément foncée',
    '🧑🏿‍🏭' => 'travailleur d’usine : peau foncée',
    '👨🏻‍🏭' => 'ouvrier : peau claire',
    '👨🏼‍🏭' => 'ouvrier : peau modérément claire',
    '👨🏽‍🏭' => 'ouvrier : peau légèrement mate',
    '👨🏾‍🏭' => 'ouvrier : peau modérément foncée',
    '👨🏿‍🏭' => 'ouvrier : peau foncée',
    '👩🏻‍🏭' => 'ouvrière : peau claire',
    '👩🏼‍🏭' => 'ouvrière : peau modérément claire',
    '👩🏽‍🏭' => 'ouvrière : peau légèrement mate',
    '👩🏾‍🏭' => 'ouvrière : peau modérément foncée',
    '👩🏿‍🏭' => 'ouvrière : peau foncée',
    '🧑🏻‍💼' => 'employé de bureau : peau claire',
    '🧑🏼‍💼' => 'employé de bureau : peau modérément claire',
    '🧑🏽‍💼' => 'employé de bureau : peau légèrement mate',
    '🧑🏾‍💼' => 'employé de bureau : peau modérément foncée',
    '🧑🏿‍💼' => 'employé de bureau : peau foncée',
    '👨🏻‍💼' => 'employé de bureau homme : peau claire',
    '👨🏼‍💼' => 'employé de bureau homme : peau modérément claire',
    '👨🏽‍💼' => 'employé de bureau homme : peau légèrement mate',
    '👨🏾‍💼' => 'employé de bureau homme : peau modérément foncée',
    '👨🏿‍💼' => 'employé de bureau homme : peau foncée',
    '👩🏻‍💼' => 'employée de bureau : peau claire',
    '👩🏼‍💼' => 'employée de bureau : peau modérément claire',
    '👩🏽‍💼' => 'employée de bureau : peau légèrement mate',
    '👩🏾‍💼' => 'employée de bureau : peau modérément foncée',
    '👩🏿‍💼' => 'employée de bureau : peau foncée',
    '🧑🏻‍🔬' => 'scientifique : peau claire',
    '🧑🏼‍🔬' => 'scientifique : peau modérément claire',
    '🧑🏽‍🔬' => 'scientifique : peau légèrement mate',
    '🧑🏾‍🔬' => 'scientifique : peau modérément foncée',
    '🧑🏿‍🔬' => 'scientifique : peau foncée',
    '👨🏻‍🔬' => 'scientifique homme : peau claire',
    '👨🏼‍🔬' => 'scientifique homme : peau modérément claire',
    '👨🏽‍🔬' => 'scientifique homme : peau légèrement mate',
    '👨🏾‍🔬' => 'scientifique homme : peau modérément foncée',
    '👨🏿‍🔬' => 'scientifique homme : peau foncée',
    '👩🏻‍🔬' => 'scientifique femme : peau claire',
    '👩🏼‍🔬' => 'scientifique femme : peau modérément claire',
    '👩🏽‍🔬' => 'scientifique femme : peau légèrement mate',
    '👩🏾‍🔬' => 'scientifique femme : peau modérément foncée',
    '👩🏿‍🔬' => 'scientifique femme : peau foncée',
    '🧑🏻‍💻' => 'informaticien : peau claire',
    '🧑🏼‍💻' => 'informaticien : peau modérément claire',
    '🧑🏽‍💻' => 'informaticien : peau légèrement mate',
    '🧑🏾‍💻' => 'informaticien : peau modérément foncée',
    '🧑🏿‍💻' => 'informaticien : peau foncée',
    '👨🏻‍💻' => 'informaticien homme : peau claire',
    '👨🏼‍💻' => 'informaticien homme : peau modérément claire',
    '👨🏽‍💻' => 'informaticien homme : peau légèrement mate',
    '👨🏾‍💻' => 'informaticien homme : peau modérément foncée',
    '👨🏿‍💻' => 'informaticien homme : peau foncée',
    '👩🏻‍💻' => 'informaticienne : peau claire',
    '👩🏼‍💻' => 'informaticienne : peau modérément claire',
    '👩🏽‍💻' => 'informaticienne : peau légèrement mate',
    '👩🏾‍💻' => 'informaticienne : peau modérément foncée',
    '👩🏿‍💻' => 'informaticienne : peau foncée',
    '🧑🏻‍🎤' => 'chanteur : peau claire',
    '🧑🏼‍🎤' => 'chanteur : peau modérément claire',
    '🧑🏽‍🎤' => 'chanteur : peau légèrement mate',
    '🧑🏾‍🎤' => 'chanteur : peau modérément foncée',
    '🧑🏿‍🎤' => 'chanteur : peau foncée',
    '👨🏻‍🎤' => 'chanteur homme : peau claire',
    '👨🏼‍🎤' => 'chanteur homme : peau modérément claire',
    '👨🏽‍🎤' => 'chanteur homme : peau légèrement mate',
    '👨🏾‍🎤' => 'chanteur homme : peau modérément foncée',
    '👨🏿‍🎤' => 'chanteur homme : peau foncée',
    '👩🏻‍🎤' => 'chanteuse : peau claire',
    '👩🏼‍🎤' => 'chanteuse : peau modérément claire',
    '👩🏽‍🎤' => 'chanteuse : peau légèrement mate',
    '👩🏾‍🎤' => 'chanteuse : peau modérément foncée',
    '👩🏿‍🎤' => 'chanteuse : peau foncée',
    '🧑🏻‍🎨' => 'artiste : peau claire',
    '🧑🏼‍🎨' => 'artiste : peau modérément claire',
    '🧑🏽‍🎨' => 'artiste : peau légèrement mate',
    '🧑🏾‍🎨' => 'artiste : peau modérément foncée',
    '🧑🏿‍🎨' => 'artiste : peau foncée',
    '👨🏻‍🎨' => 'artiste homme : peau claire',
    '👨🏼‍🎨' => 'artiste homme : peau modérément claire',
    '👨🏽‍🎨' => 'artiste homme : peau légèrement mate',
    '👨🏾‍🎨' => 'artiste homme : peau modérément foncée',
    '👨🏿‍🎨' => 'artiste homme : peau foncée',
    '👩🏻‍🎨' => 'artiste femme : peau claire',
    '👩🏼‍🎨' => 'artiste femme : peau modérément claire',
    '👩🏽‍🎨' => 'artiste femme : peau légèrement mate',
    '👩🏾‍🎨' => 'artiste femme : peau modérément foncée',
    '👩🏿‍🎨' => 'artiste femme : peau foncée',
    '🧑🏻‍✈' => 'pilote : peau claire',
    '🧑🏼‍✈' => 'pilote : peau modérément claire',
    '🧑🏽‍✈' => 'pilote : peau légèrement mate',
    '🧑🏾‍✈' => 'pilote : peau modérément foncée',
    '🧑🏿‍✈' => 'pilote : peau foncée',
    '👨🏻‍✈' => 'pilote homme : peau claire',
    '👨🏼‍✈' => 'pilote homme : peau modérément claire',
    '👨🏽‍✈' => 'pilote homme : peau légèrement mate',
    '👨🏾‍✈' => 'pilote homme : peau modérément foncée',
    '👨🏿‍✈' => 'pilote homme : peau foncée',
    '👩🏻‍✈' => 'pilote femme : peau claire',
    '👩🏼‍✈' => 'pilote femme : peau modérément claire',
    '👩🏽‍✈' => 'pilote femme : peau légèrement mate',
    '👩🏾‍✈' => 'pilote femme : peau modérément foncée',
    '👩🏿‍✈' => 'pilote femme : peau foncée',
    '🧑🏻‍🚀' => 'astronaute : peau claire',
    '🧑🏼‍🚀' => 'astronaute : peau modérément claire',
    '🧑🏽‍🚀' => 'astronaute : peau légèrement mate',
    '🧑🏾‍🚀' => 'astronaute : peau modérément foncée',
    '🧑🏿‍🚀' => 'astronaute : peau foncée',
    '👨🏻‍🚀' => 'astronaute homme : peau claire',
    '👨🏼‍🚀' => 'astronaute homme : peau modérément claire',
    '👨🏽‍🚀' => 'astronaute homme : peau légèrement mate',
    '👨🏾‍🚀' => 'astronaute homme : peau modérément foncée',
    '👨🏿‍🚀' => 'astronaute homme : peau foncée',
    '👩🏻‍🚀' => 'astronaute femme : peau claire',
    '👩🏼‍🚀' => 'astronaute femme : peau modérément claire',
    '👩🏽‍🚀' => 'astronaute femme : peau légèrement mate',
    '👩🏾‍🚀' => 'astronaute femme : peau modérément foncée',
    '👩🏿‍🚀' => 'astronaute femme : peau foncée',
    '🧑🏻‍🚒' => 'pompier : peau claire',
    '🧑🏼‍🚒' => 'pompier : peau modérément claire',
    '🧑🏽‍🚒' => 'pompier : peau légèrement mate',
    '🧑🏾‍🚒' => 'pompier : peau modérément foncée',
    '🧑🏿‍🚒' => 'pompier : peau foncée',
    '👨🏻‍🚒' => 'pompier homme : peau claire',
    '👨🏼‍🚒' => 'pompier homme : peau modérément claire',
    '👨🏽‍🚒' => 'pompier homme : peau légèrement mate',
    '👨🏾‍🚒' => 'pompier homme : peau modérément foncée',
    '👨🏿‍🚒' => 'pompier homme : peau foncée',
    '👩🏻‍🚒' => 'pompier femme : peau claire',
    '👩🏼‍🚒' => 'pompier femme : peau modérément claire',
    '👩🏽‍🚒' => 'pompier femme : peau légèrement mate',
    '👩🏾‍🚒' => 'pompier femme : peau modérément foncée',
    '👩🏿‍🚒' => 'pompier femme : peau foncée',
    '👮🏻‍♂' => 'policier homme : peau claire',
    '👮🏼‍♂' => 'policier homme : peau modérément claire',
    '👮🏽‍♂' => 'policier homme : peau légèrement mate',
    '👮🏾‍♂' => 'policier homme : peau modérément foncée',
    '👮🏿‍♂' => 'policier homme : peau foncée',
    '👮🏻‍♀' => 'policière : peau claire',
    '👮🏼‍♀' => 'policière : peau modérément claire',
    '👮🏽‍♀' => 'policière : peau légèrement mate',
    '👮🏾‍♀' => 'policière : peau modérément foncée',
    '👮🏿‍♀' => 'policière : peau foncée',
    '🕵🏻‍♂' => 'détective homme : peau claire',
    '🕵🏼‍♂' => 'détective homme : peau modérément claire',
    '🕵🏽‍♂' => 'détective homme : peau légèrement mate',
    '🕵🏾‍♂' => 'détective homme : peau modérément foncée',
    '🕵🏿‍♂' => 'détective homme : peau foncée',
    '🕵🏻‍♀' => 'détective femme : peau claire',
    '🕵🏼‍♀' => 'détective femme : peau modérément claire',
    '🕵🏽‍♀' => 'détective femme : peau légèrement mate',
    '🕵🏾‍♀' => 'détective femme : peau modérément foncée',
    '🕵🏿‍♀' => 'détective femme : peau foncée',
    '💂🏻‍♂' => 'garde homme : peau claire',
    '💂🏼‍♂' => 'garde homme : peau modérément claire',
    '💂🏽‍♂' => 'garde homme : peau légèrement mate',
    '💂🏾‍♂' => 'garde homme : peau modérément foncée',
    '💂🏿‍♂' => 'garde homme : peau foncée',
    '💂🏻‍♀' => 'garde femme : peau claire',
    '💂🏼‍♀' => 'garde femme : peau modérément claire',
    '💂🏽‍♀' => 'garde femme : peau légèrement mate',
    '💂🏾‍♀' => 'garde femme : peau modérément foncée',
    '💂🏿‍♀' => 'garde femme : peau foncée',
    '👷🏻‍♂' => 'ouvrier du bâtiment : peau claire',
    '👷🏼‍♂' => 'ouvrier du bâtiment : peau modérément claire',
    '👷🏽‍♂' => 'ouvrier du bâtiment : peau légèrement mate',
    '👷🏾‍♂' => 'ouvrier du bâtiment : peau modérément foncée',
    '👷🏿‍♂' => 'ouvrier du bâtiment : peau foncée',
    '👷🏻‍♀' => 'ouvrière du bâtiment : peau claire',
    '👷🏼‍♀' => 'ouvrière du bâtiment : peau modérément claire',
    '👷🏽‍♀' => 'ouvrière du bâtiment : peau légèrement mate',
    '👷🏾‍♀' => 'ouvrière du bâtiment : peau modérément foncée',
    '👷🏿‍♀' => 'ouvrière du bâtiment : peau foncée',
    '👳🏻‍♂' => 'homme en turban : peau claire',
    '👳🏼‍♂' => 'homme en turban : peau modérément claire',
    '👳🏽‍♂' => 'homme en turban : peau légèrement mate',
    '👳🏾‍♂' => 'homme en turban : peau modérément foncée',
    '👳🏿‍♂' => 'homme en turban : peau foncée',
    '👳🏻‍♀' => 'femme en turban : peau claire',
    '👳🏼‍♀' => 'femme en turban : peau modérément claire',
    '👳🏽‍♀' => 'femme en turban : peau légèrement mate',
    '👳🏾‍♀' => 'femme en turban : peau modérément foncée',
    '👳🏿‍♀' => 'femme en turban : peau foncée',
    '🤵🏻‍♂' => 'homme en smoking : peau claire',
    '🤵🏼‍♂' => 'homme en smoking : peau modérément claire',
    '🤵🏽‍♂' => 'homme en smoking : peau légèrement mate',
    '🤵🏾‍♂' => 'homme en smoking : peau modérément foncée',
    '🤵🏿‍♂' => 'homme en smoking : peau foncée',
    '🤵🏻‍♀' => 'femme en smoking : peau claire',
    '🤵🏼‍♀' => 'femme en smoking : peau modérément claire',
    '🤵🏽‍♀' => 'femme en smoking : peau légèrement mate',
    '🤵🏾‍♀' => 'femme en smoking : peau modérément foncée',
    '🤵🏿‍♀' => 'femme en smoking : peau foncée',
    '👰🏻‍♂' => 'homme avec voile : peau claire',
    '👰🏼‍♂' => 'homme avec voile : peau modérément claire',
    '👰🏽‍♂' => 'homme avec voile : peau légèrement mate',
    '👰🏾‍♂' => 'homme avec voile : peau modérément foncée',
    '👰🏿‍♂' => 'homme avec voile : peau foncée',
    '👰🏻‍♀' => 'femme avec voile : peau claire',
    '👰🏼‍♀' => 'femme avec voile : peau modérément claire',
    '👰🏽‍♀' => 'femme avec voile : peau légèrement mate',
    '👰🏾‍♀' => 'femme avec voile : peau modérément foncée',
    '👰🏿‍♀' => 'femme avec voile : peau foncée',
    '👩🏻‍🍼' => 'femme allaitant un bébé : peau claire',
    '👩🏼‍🍼' => 'femme allaitant un bébé : peau modérément claire',
    '👩🏽‍🍼' => 'femme allaitant un bébé : peau légèrement mate',
    '👩🏾‍🍼' => 'femme allaitant un bébé : peau modérément foncée',
    '👩🏿‍🍼' => 'femme allaitant un bébé : peau foncée',
    '👨🏻‍🍼' => 'homme allaitant un bébé : peau claire',
    '👨🏼‍🍼' => 'homme allaitant un bébé : peau modérément claire',
    '👨🏽‍🍼' => 'homme allaitant un bébé : peau légèrement mate',
    '👨🏾‍🍼' => 'homme allaitant un bébé : peau modérément foncée',
    '👨🏿‍🍼' => 'homme allaitant un bébé : peau foncée',
    '🧑🏻‍🍼' => 'personne allaitant un bébé : peau claire',
    '🧑🏼‍🍼' => 'personne allaitant un bébé : peau modérément claire',
    '🧑🏽‍🍼' => 'personne allaitant un bébé : peau légèrement mate',
    '🧑🏾‍🍼' => 'personne allaitant un bébé : peau modérément foncée',
    '🧑🏿‍🍼' => 'personne allaitant un bébé : peau foncée',
    '🧑🏻‍🎄' => 'personnage de Noël : peau claire',
    '🧑🏼‍🎄' => 'personnage de Noël : peau modérément claire',
    '🧑🏽‍🎄' => 'personnage de Noël : peau légèrement mate',
    '🧑🏾‍🎄' => 'personnage de Noël : peau modérément foncée',
    '🧑🏿‍🎄' => 'personnage de Noël : peau foncée',
    '🦸🏻‍♂' => 'super-héros : peau claire',
    '🦸🏼‍♂' => 'super-héros : peau modérément claire',
    '🦸🏽‍♂' => 'super-héros : peau légèrement mate',
    '🦸🏾‍♂' => 'super-héros : peau modérément foncée',
    '🦸🏿‍♂' => 'super-héros : peau foncée',
    '🦸🏻‍♀' => 'super-héroïne : peau claire',
    '🦸🏼‍♀' => 'super-héroïne : peau modérément claire',
    '🦸🏽‍♀' => 'super-héroïne : peau légèrement mate',
    '🦸🏾‍♀' => 'super-héroïne : peau modérément foncée',
    '🦸🏿‍♀' => 'super-héroïne : peau foncée',
    '🦹🏻‍♂' => 'super-vilain homme : peau claire',
    '🦹🏼‍♂' => 'super-vilain homme : peau modérément claire',
    '🦹🏽‍♂' => 'super-vilain homme : peau légèrement mate',
    '🦹🏾‍♂' => 'super-vilain homme : peau modérément foncée',
    '🦹🏿‍♂' => 'super-vilain homme : peau foncée',
    '🦹🏻‍♀' => 'super-vilain femme : peau claire',
    '🦹🏼‍♀' => 'super-vilain femme : peau modérément claire',
    '🦹🏽‍♀' => 'super-vilain femme : peau légèrement mate',
    '🦹🏾‍♀' => 'super-vilain femme : peau modérément foncée',
    '🦹🏿‍♀' => 'super-vilain femme : peau foncée',
    '🧙🏻‍♂' => 'mage homme : peau claire',
    '🧙🏼‍♂' => 'mage homme : peau modérément claire',
    '🧙🏽‍♂' => 'mage homme : peau légèrement mate',
    '🧙🏾‍♂' => 'mage homme : peau modérément foncée',
    '🧙🏿‍♂' => 'mage homme : peau foncée',
    '🧙🏻‍♀' => 'mage femme : peau claire',
    '🧙🏼‍♀' => 'mage femme : peau modérément claire',
    '🧙🏽‍♀' => 'mage femme : peau légèrement mate',
    '🧙🏾‍♀' => 'mage femme : peau modérément foncée',
    '🧙🏿‍♀' => 'mage femme : peau foncée',
    '🧚🏻‍♂' => 'féetaud : peau claire',
    '🧚🏼‍♂' => 'féetaud : peau modérément claire',
    '🧚🏽‍♂' => 'féetaud : peau légèrement mate',
    '🧚🏾‍♂' => 'féetaud : peau modérément foncée',
    '🧚🏿‍♂' => 'féetaud : peau foncée',
    '🧚🏻‍♀' => 'fée : peau claire',
    '🧚🏼‍♀' => 'fée : peau modérément claire',
    '🧚🏽‍♀' => 'fée : peau légèrement mate',
    '🧚🏾‍♀' => 'fée : peau modérément foncée',
    '🧚🏿‍♀' => 'fée : peau foncée',
    '🧛🏻‍♂' => 'vampire homme : peau claire',
    '🧛🏼‍♂' => 'vampire homme : peau modérément claire',
    '🧛🏽‍♂' => 'vampire homme : peau légèrement mate',
    '🧛🏾‍♂' => 'vampire homme : peau modérément foncée',
    '🧛🏿‍♂' => 'vampire homme : peau foncée',
    '🧛🏻‍♀' => 'vampire femme : peau claire',
    '🧛🏼‍♀' => 'vampire femme : peau modérément claire',
    '🧛🏽‍♀' => 'vampire femme : peau légèrement mate',
    '🧛🏾‍♀' => 'vampire femme : peau modérément foncée',
    '🧛🏿‍♀' => 'vampire femme : peau foncée',
    '🧜🏻‍♂' => 'triton : peau claire',
    '🧜🏼‍♂' => 'triton : peau modérément claire',
    '🧜🏽‍♂' => 'triton : peau légèrement mate',
    '🧜🏾‍♂' => 'triton : peau modérément foncée',
    '🧜🏿‍♂' => 'triton : peau foncée',
    '🧜🏻‍♀' => 'sirène : peau claire',
    '🧜🏼‍♀' => 'sirène : peau modérément claire',
    '🧜🏽‍♀' => 'sirène : peau légèrement mate',
    '🧜🏾‍♀' => 'sirène : peau modérément foncée',
    '🧜🏿‍♀' => 'sirène : peau foncée',
    '🧝🏻‍♂' => 'elfe homme : peau claire',
    '🧝🏼‍♂' => 'elfe homme : peau modérément claire',
    '🧝🏽‍♂' => 'elfe homme : peau légèrement mate',
    '🧝🏾‍♂' => 'elfe homme : peau modérément foncée',
    '🧝🏿‍♂' => 'elfe homme : peau foncée',
    '🧝🏻‍♀' => 'elfe femme : peau claire',
    '🧝🏼‍♀' => 'elfe femme : peau modérément claire',
    '🧝🏽‍♀' => 'elfe femme : peau légèrement mate',
    '🧝🏾‍♀' => 'elfe femme : peau modérément foncée',
    '🧝🏿‍♀' => 'elfe femme : peau foncée',
    '💆🏻‍♂' => 'homme qui se fait masser : peau claire',
    '💆🏼‍♂' => 'homme qui se fait masser : peau modérément claire',
    '💆🏽‍♂' => 'homme qui se fait masser : peau légèrement mate',
    '💆🏾‍♂' => 'homme qui se fait masser : peau modérément foncée',
    '💆🏿‍♂' => 'homme qui se fait masser : peau foncée',
    '💆🏻‍♀' => 'femme qui se fait masser : peau claire',
    '💆🏼‍♀' => 'femme qui se fait masser : peau modérément claire',
    '💆🏽‍♀' => 'femme qui se fait masser : peau légèrement mate',
    '💆🏾‍♀' => 'femme qui se fait masser : peau modérément foncée',
    '💆🏿‍♀' => 'femme qui se fait masser : peau foncée',
    '💇🏻‍♂' => 'homme qui se fait couper les cheveux : peau claire',
    '💇🏼‍♂' => 'homme qui se fait couper les cheveux : peau modérément claire',
    '💇🏽‍♂' => 'homme qui se fait couper les cheveux : peau légèrement mate',
    '💇🏾‍♂' => 'homme qui se fait couper les cheveux : peau modérément foncée',
    '💇🏿‍♂' => 'homme qui se fait couper les cheveux : peau foncée',
    '💇🏻‍♀' => 'femme qui se fait couper les cheveux : peau claire',
    '💇🏼‍♀' => 'femme qui se fait couper les cheveux : peau modérément claire',
    '💇🏽‍♀' => 'femme qui se fait couper les cheveux : peau légèrement mate',
    '💇🏾‍♀' => 'femme qui se fait couper les cheveux : peau modérément foncée',
    '💇🏿‍♀' => 'femme qui se fait couper les cheveux : peau foncée',
    '🚶🏻‍♂' => 'homme qui marche : peau claire',
    '🚶🏼‍♂' => 'homme qui marche : peau modérément claire',
    '🚶🏽‍♂' => 'homme qui marche : peau légèrement mate',
    '🚶🏾‍♂' => 'homme qui marche : peau modérément foncée',
    '🚶🏿‍♂' => 'homme qui marche : peau foncée',
    '🚶🏻‍♀' => 'femme qui marche : peau claire',
    '🚶🏼‍♀' => 'femme qui marche : peau modérément claire',
    '🚶🏽‍♀' => 'femme qui marche : peau légèrement mate',
    '🚶🏾‍♀' => 'femme qui marche : peau modérément foncée',
    '🚶🏿‍♀' => 'femme qui marche : peau foncée',
    '🚶🏻‍➡' => 'personne qui marche : peau claire et vers la droite',
    '🚶🏼‍➡' => 'personne qui marche : peau modérément claire et vers la droite',
    '🚶🏽‍➡' => 'personne qui marche : peau légèrement mate et vers la droite',
    '🚶🏾‍➡' => 'personne qui marche : peau modérément foncée et vers la droite',
    '🚶🏿‍➡' => 'personne qui marche : peau foncée et vers la droite',
    '🧍🏻‍♂' => 'homme debout : peau claire',
    '🧍🏼‍♂' => 'homme debout : peau modérément claire',
    '🧍🏽‍♂' => 'homme debout : peau légèrement mate',
    '🧍🏾‍♂' => 'homme debout : peau modérément foncée',
    '🧍🏿‍♂' => 'homme debout : peau foncée',
    '🧍🏻‍♀' => 'femme debout : peau claire',
    '🧍🏼‍♀' => 'femme debout : peau modérément claire',
    '🧍🏽‍♀' => 'femme debout : peau légèrement mate',
    '🧍🏾‍♀' => 'femme debout : peau modérément foncée',
    '🧍🏿‍♀' => 'femme debout : peau foncée',
    '🧎🏻‍♂' => 'homme à genoux : peau claire',
    '🧎🏼‍♂' => 'homme à genoux : peau modérément claire',
    '🧎🏽‍♂' => 'homme à genoux : peau légèrement mate',
    '🧎🏾‍♂' => 'homme à genoux : peau modérément foncée',
    '🧎🏿‍♂' => 'homme à genoux : peau foncée',
    '🧎🏻‍♀' => 'femme à genoux : peau claire',
    '🧎🏼‍♀' => 'femme à genoux : peau modérément claire',
    '🧎🏽‍♀' => 'femme à genoux : peau légèrement mate',
    '🧎🏾‍♀' => 'femme à genoux : peau modérément foncée',
    '🧎🏿‍♀' => 'femme à genoux : peau foncée',
    '🧎🏻‍➡' => 'personne à genoux : peau claire et vers la droite',
    '🧎🏼‍➡' => 'personne à genoux : peau modérément claire et vers la droite',
    '🧎🏽‍➡' => 'personne à genoux : peau légèrement mate et vers la droite',
    '🧎🏾‍➡' => 'personne à genoux : peau modérément foncée et vers la droite',
    '🧎🏿‍➡' => 'personne à genoux : peau foncée et vers la droite',
    '🧑🏻‍🦯' => 'personne avec une canne blanche : peau claire',
    '🧑🏼‍🦯' => 'personne avec une canne blanche : peau modérément claire',
    '🧑🏽‍🦯' => 'personne avec une canne blanche : peau légèrement mate',
    '🧑🏾‍🦯' => 'personne avec une canne blanche : peau modérément foncée',
    '🧑🏿‍🦯' => 'personne avec une canne blanche : peau foncée',
    '👨🏻‍🦯' => 'homme avec canne blanche : peau claire',
    '👨🏼‍🦯' => 'homme avec canne blanche : peau modérément claire',
    '👨🏽‍🦯' => 'homme avec canne blanche : peau légèrement mate',
    '👨🏾‍🦯' => 'homme avec canne blanche : peau modérément foncée',
    '👨🏿‍🦯' => 'homme avec canne blanche : peau foncée',
    '👩🏻‍🦯' => 'femme avec canne blanche : peau claire',
    '👩🏼‍🦯' => 'femme avec canne blanche : peau modérément claire',
    '👩🏽‍🦯' => 'femme avec canne blanche : peau légèrement mate',
    '👩🏾‍🦯' => 'femme avec canne blanche : peau modérément foncée',
    '👩🏿‍🦯' => 'femme avec canne blanche : peau foncée',
    '🧑🏻‍🦼' => 'personne en fauteuil motorisé : peau claire',
    '🧑🏼‍🦼' => 'personne en fauteuil motorisé : peau modérément claire',
    '🧑🏽‍🦼' => 'personne en fauteuil motorisé : peau légèrement mate',
    '🧑🏾‍🦼' => 'personne en fauteuil motorisé : peau modérément foncée',
    '🧑🏿‍🦼' => 'personne en fauteuil motorisé : peau foncée',
    '👨🏻‍🦼' => 'homme en fauteuil motorisé : peau claire',
    '👨🏼‍🦼' => 'homme en fauteuil motorisé : peau modérément claire',
    '👨🏽‍🦼' => 'homme en fauteuil motorisé : peau légèrement mate',
    '👨🏾‍🦼' => 'homme en fauteuil motorisé : peau modérément foncée',
    '👨🏿‍🦼' => 'homme en fauteuil motorisé : peau foncée',
    '👩🏻‍🦼' => 'femme en fauteuil motorisé : peau claire',
    '👩🏼‍🦼' => 'femme en fauteuil motorisé : peau modérément claire',
    '👩🏽‍🦼' => 'femme en fauteuil motorisé : peau légèrement mate',
    '👩🏾‍🦼' => 'femme en fauteuil motorisé : peau modérément foncée',
    '👩🏿‍🦼' => 'femme en fauteuil motorisé : peau foncée',
    '🧑🏻‍🦽' => 'personne en fauteuil roulant manuel : peau claire',
    '🧑🏼‍🦽' => 'personne en fauteuil roulant manuel : peau modérément claire',
    '🧑🏽‍🦽' => 'personne en fauteuil roulant manuel : peau légèrement mate',
    '🧑🏾‍🦽' => 'personne en fauteuil roulant manuel : peau modérément foncée',
    '🧑🏿‍🦽' => 'personne en fauteuil roulant manuel : peau foncée',
    '👨🏻‍🦽' => 'homme en fauteuil roulant manuel : peau claire',
    '👨🏼‍🦽' => 'homme en fauteuil roulant manuel : peau modérément claire',
    '👨🏽‍🦽' => 'homme en fauteuil roulant manuel : peau légèrement mate',
    '👨🏾‍🦽' => 'homme en fauteuil roulant manuel : peau modérément foncée',
    '👨🏿‍🦽' => 'homme en fauteuil roulant manuel : peau foncée',
    '👩🏻‍🦽' => 'femme en fauteuil roulant manuel : peau claire',
    '👩🏼‍🦽' => 'femme en fauteuil roulant manuel : peau modérément claire',
    '👩🏽‍🦽' => 'femme en fauteuil roulant manuel : peau légèrement mate',
    '👩🏾‍🦽' => 'femme en fauteuil roulant manuel : peau modérément foncée',
    '👩🏿‍🦽' => 'femme en fauteuil roulant manuel : peau foncée',
    '🏃🏻‍♂' => 'homme qui court : peau claire',
    '🏃🏼‍♂' => 'homme qui court : peau modérément claire',
    '🏃🏽‍♂' => 'homme qui court : peau légèrement mate',
    '🏃🏾‍♂' => 'homme qui court : peau modérément foncée',
    '🏃🏿‍♂' => 'homme qui court : peau foncée',
    '🏃🏻‍♀' => 'femme qui court : peau claire',
    '🏃🏼‍♀' => 'femme qui court : peau modérément claire',
    '🏃🏽‍♀' => 'femme qui court : peau légèrement mate',
    '🏃🏾‍♀' => 'femme qui court : peau modérément foncée',
    '🏃🏿‍♀' => 'femme qui court : peau foncée',
    '🏃🏻‍➡' => 'personne qui court : peau claire et vers la droite',
    '🏃🏼‍➡' => 'personne qui court : peau modérément claire et vers la droite',
    '🏃🏽‍➡' => 'personne qui court : peau légèrement mate et vers la droite',
    '🏃🏾‍➡' => 'personne qui court : peau modérément foncée et vers la droite',
    '🏃🏿‍➡' => 'personne qui court : peau foncée et vers la droite',
    '👯🏻‍♀' => 'femmes qui portent des oreilles de lapin : peau claire',
    '👯🏼‍♀' => 'femmes qui portent des oreilles de lapin : peau modérément claire',
    '👯🏽‍♀' => 'femmes qui portent des oreilles de lapin : peau légèrement mate',
    '👯🏾‍♀' => 'femmes qui portent des oreilles de lapin : peau modérément foncée',
    '👯🏿‍♀' => 'femmes qui portent des oreilles de lapin : peau foncée',
    '👯🏻‍♂' => 'hommes qui portent des oreilles de lapin : peau claire',
    '👯🏼‍♂' => 'hommes qui portent des oreilles de lapin : peau modérément claire',
    '👯🏽‍♂' => 'hommes qui portent des oreilles de lapin : peau légèrement mate',
    '👯🏾‍♂' => 'hommes qui portent des oreilles de lapin : peau modérément foncée',
    '👯🏿‍♂' => 'hommes qui portent des oreilles de lapin : peau foncée',
    '🧖🏻‍♂' => 'homme dans un bain de vapeur : peau claire',
    '🧖🏼‍♂' => 'homme dans un bain de vapeur : peau modérément claire',
    '🧖🏽‍♂' => 'homme dans un bain de vapeur : peau légèrement mate',
    '🧖🏾‍♂' => 'homme dans un bain de vapeur : peau modérément foncée',
    '🧖🏿‍♂' => 'homme dans un bain de vapeur : peau foncée',
    '🧖🏻‍♀' => 'femme dans un bain de vapeur : peau claire',
    '🧖🏼‍♀' => 'femme dans un bain de vapeur : peau modérément claire',
    '🧖🏽‍♀' => 'femme dans un bain de vapeur : peau légèrement mate',
    '🧖🏾‍♀' => 'femme dans un bain de vapeur : peau modérément foncée',
    '🧖🏿‍♀' => 'femme dans un bain de vapeur : peau foncée',
    '🧗🏻‍♂' => 'homme qui grimpe : peau claire',
    '🧗🏼‍♂' => 'homme qui grimpe : peau modérément claire',
    '🧗🏽‍♂' => 'homme qui grimpe : peau légèrement mate',
    '🧗🏾‍♂' => 'homme qui grimpe : peau modérément foncée',
    '🧗🏿‍♂' => 'homme qui grimpe : peau foncée',
    '🧗🏻‍♀' => 'femme qui grimpe : peau claire',
    '🧗🏼‍♀' => 'femme qui grimpe : peau modérément claire',
    '🧗🏽‍♀' => 'femme qui grimpe : peau légèrement mate',
    '🧗🏾‍♀' => 'femme qui grimpe : peau modérément foncée',
    '🧗🏿‍♀' => 'femme qui grimpe : peau foncée',
    '🏌🏻‍♂' => 'golfeur : peau claire',
    '🏌🏼‍♂' => 'golfeur : peau modérément claire',
    '🏌🏽‍♂' => 'golfeur : peau légèrement mate',
    '🏌🏾‍♂' => 'golfeur : peau modérément foncée',
    '🏌🏿‍♂' => 'golfeur : peau foncée',
    '🏌🏻‍♀' => 'golfeuse : peau claire',
    '🏌🏼‍♀' => 'golfeuse : peau modérément claire',
    '🏌🏽‍♀' => 'golfeuse : peau légèrement mate',
    '🏌🏾‍♀' => 'golfeuse : peau modérément foncée',
    '🏌🏿‍♀' => 'golfeuse : peau foncée',
    '🏄🏻‍♂' => 'surfeur : peau claire',
    '🏄🏼‍♂' => 'surfeur : peau modérément claire',
    '🏄🏽‍♂' => 'surfeur : peau légèrement mate',
    '🏄🏾‍♂' => 'surfeur : peau modérément foncée',
    '🏄🏿‍♂' => 'surfeur : peau foncée',
    '🏄🏻‍♀' => 'surfeuse : peau claire',
    '🏄🏼‍♀' => 'surfeuse : peau modérément claire',
    '🏄🏽‍♀' => 'surfeuse : peau légèrement mate',
    '🏄🏾‍♀' => 'surfeuse : peau modérément foncée',
    '🏄🏿‍♀' => 'surfeuse : peau foncée',
    '🚣🏻‍♂' => 'rameur dans une barque : peau claire',
    '🚣🏼‍♂' => 'rameur dans une barque : peau modérément claire',
    '🚣🏽‍♂' => 'rameur dans une barque : peau légèrement mate',
    '🚣🏾‍♂' => 'rameur dans une barque : peau modérément foncée',
    '🚣🏿‍♂' => 'rameur dans une barque : peau foncée',
    '🚣🏻‍♀' => 'rameuse dans une barque : peau claire',
    '🚣🏼‍♀' => 'rameuse dans une barque : peau modérément claire',
    '🚣🏽‍♀' => 'rameuse dans une barque : peau légèrement mate',
    '🚣🏾‍♀' => 'rameuse dans une barque : peau modérément foncée',
    '🚣🏿‍♀' => 'rameuse dans une barque : peau foncée',
    '🏊🏻‍♂' => 'nageur : peau claire',
    '🏊🏼‍♂' => 'nageur : peau modérément claire',
    '🏊🏽‍♂' => 'nageur : peau légèrement mate',
    '🏊🏾‍♂' => 'nageur : peau modérément foncée',
    '🏊🏿‍♂' => 'nageur : peau foncée',
    '🏊🏻‍♀' => 'nageuse : peau claire',
    '🏊🏼‍♀' => 'nageuse : peau modérément claire',
    '🏊🏽‍♀' => 'nageuse : peau légèrement mate',
    '🏊🏾‍♀' => 'nageuse : peau modérément foncée',
    '🏊🏿‍♀' => 'nageuse : peau foncée',
    '⛹🏻‍♂' => 'homme qui fait rebondir un ballon : peau claire',
    '⛹🏼‍♂' => 'homme qui fait rebondir un ballon : peau modérément claire',
    '⛹🏽‍♂' => 'homme qui fait rebondir un ballon : peau légèrement mate',
    '⛹🏾‍♂' => 'homme qui fait rebondir un ballon : peau modérément foncée',
    '⛹🏿‍♂' => 'homme qui fait rebondir un ballon : peau foncée',
    '⛹🏻‍♀' => 'femme qui fait rebondir un ballon : peau claire',
    '⛹🏼‍♀' => 'femme qui fait rebondir un ballon : peau modérément claire',
    '⛹🏽‍♀' => 'femme qui fait rebondir un ballon : peau légèrement mate',
    '⛹🏾‍♀' => 'femme qui fait rebondir un ballon : peau modérément foncée',
    '⛹🏿‍♀' => 'femme qui fait rebondir un ballon : peau foncée',
    '🏋🏻‍♂' => 'homme haltérophile : peau claire',
    '🏋🏼‍♂' => 'homme haltérophile : peau modérément claire',
    '🏋🏽‍♂' => 'homme haltérophile : peau légèrement mate',
    '🏋🏾‍♂' => 'homme haltérophile : peau modérément foncée',
    '🏋🏿‍♂' => 'homme haltérophile : peau foncée',
    '🏋🏻‍♀' => 'femme haltérophile : peau claire',
    '🏋🏼‍♀' => 'femme haltérophile : peau modérément claire',
    '🏋🏽‍♀' => 'femme haltérophile : peau légèrement mate',
    '🏋🏾‍♀' => 'femme haltérophile : peau modérément foncée',
    '🏋🏿‍♀' => 'femme haltérophile : peau foncée',
    '🚴🏻‍♂' => 'cycliste homme : peau claire',
    '🚴🏼‍♂' => 'cycliste homme : peau modérément claire',
    '🚴🏽‍♂' => 'cycliste homme : peau légèrement mate',
    '🚴🏾‍♂' => 'cycliste homme : peau modérément foncée',
    '🚴🏿‍♂' => 'cycliste homme : peau foncée',
    '🚴🏻‍♀' => 'cycliste femme : peau claire',
    '🚴🏼‍♀' => 'cycliste femme : peau modérément claire',
    '🚴🏽‍♀' => 'cycliste femme : peau légèrement mate',
    '🚴🏾‍♀' => 'cycliste femme : peau modérément foncée',
    '🚴🏿‍♀' => 'cycliste femme : peau foncée',
    '🚵🏻‍♂' => 'homme en vélo de montagne : peau claire',
    '🚵🏼‍♂' => 'homme en vélo de montagne : peau modérément claire',
    '🚵🏽‍♂' => 'homme en vélo de montagne : peau légèrement mate',
    '🚵🏾‍♂' => 'homme en vélo de montagne : peau modérément foncée',
    '🚵🏿‍♂' => 'homme en vélo de montagne : peau foncée',
    '🚵🏻‍♀' => 'femme en vélo de montagne : peau claire',
    '🚵🏼‍♀' => 'femme en vélo de montagne : peau modérément claire',
    '🚵🏽‍♀' => 'femme en vélo de montagne : peau légèrement mate',
    '🚵🏾‍♀' => 'femme en vélo de montagne : peau modérément foncée',
    '🚵🏿‍♀' => 'femme en vélo de montagne : peau foncée',
    '🤸🏻‍♂' => 'homme faisant la roue : peau claire',
    '🤸🏼‍♂' => 'homme faisant la roue : peau modérément claire',
    '🤸🏽‍♂' => 'homme faisant la roue : peau légèrement mate',
    '🤸🏾‍♂' => 'homme faisant la roue : peau modérément foncée',
    '🤸🏿‍♂' => 'homme faisant la roue : peau foncée',
    '🤸🏻‍♀' => 'femme faisant la roue : peau claire',
    '🤸🏼‍♀' => 'femme faisant la roue : peau modérément claire',
    '🤸🏽‍♀' => 'femme faisant la roue : peau légèrement mate',
    '🤸🏾‍♀' => 'femme faisant la roue : peau modérément foncée',
    '🤸🏿‍♀' => 'femme faisant la roue : peau foncée',
    '🤼🏻‍♀' => 'lutteuses : peau claire',
    '🤼🏼‍♀' => 'lutteuses : peau modérément claire',
    '🤼🏽‍♀' => 'lutteuses : peau légèrement mate',
    '🤼🏾‍♀' => 'lutteuses : peau modérément foncée',
    '🤼🏿‍♀' => 'lutteuses : peau foncée',
    '🤼🏻‍♂' => 'lutteurs : peau claire',
    '🤼🏼‍♂' => 'lutteurs : peau modérément claire',
    '🤼🏽‍♂' => 'lutteurs : peau légèrement mate',
    '🤼🏾‍♂' => 'lutteurs : peau modérément foncée',
    '🤼🏿‍♂' => 'lutteurs : peau foncée',
    '🤽🏻‍♂' => 'joueur de water-polo : peau claire',
    '🤽🏼‍♂' => 'joueur de water-polo : peau modérément claire',
    '🤽🏽‍♂' => 'joueur de water-polo : peau légèrement mate',
    '🤽🏾‍♂' => 'joueur de water-polo : peau modérément foncée',
    '🤽🏿‍♂' => 'joueur de water-polo : peau foncée',
    '🤽🏻‍♀' => 'joueuse de water-polo : peau claire',
    '🤽🏼‍♀' => 'joueuse de water-polo : peau modérément claire',
    '🤽🏽‍♀' => 'joueuse de water-polo : peau légèrement mate',
    '🤽🏾‍♀' => 'joueuse de water-polo : peau modérément foncée',
    '🤽🏿‍♀' => 'joueuse de water-polo : peau foncée',
    '🤾🏻‍♂' => 'handballeur : peau claire',
    '🤾🏼‍♂' => 'handballeur : peau modérément claire',
    '🤾🏽‍♂' => 'handballeur : peau légèrement mate',
    '🤾🏾‍♂' => 'handballeur : peau modérément foncée',
    '🤾🏿‍♂' => 'handballeur : peau foncée',
    '🤾🏻‍♀' => 'handballeuse : peau claire',
    '🤾🏼‍♀' => 'handballeuse : peau modérément claire',
    '🤾🏽‍♀' => 'handballeuse : peau légèrement mate',
    '🤾🏾‍♀' => 'handballeuse : peau modérément foncée',
    '🤾🏿‍♀' => 'handballeuse : peau foncée',
    '🤹🏻‍♂' => 'jongleur : peau claire',
    '🤹🏼‍♂' => 'jongleur : peau modérément claire',
    '🤹🏽‍♂' => 'jongleur : peau légèrement mate',
    '🤹🏾‍♂' => 'jongleur : peau modérément foncée',
    '🤹🏿‍♂' => 'jongleur : peau foncée',
    '🤹🏻‍♀' => 'jongleuse : peau claire',
    '🤹🏼‍♀' => 'jongleuse : peau modérément claire',
    '🤹🏽‍♀' => 'jongleuse : peau légèrement mate',
    '🤹🏾‍♀' => 'jongleuse : peau modérément foncée',
    '🤹🏿‍♀' => 'jongleuse : peau foncée',
    '🧘🏻‍♂' => 'homme dans la posture du lotus : peau claire',
    '🧘🏼‍♂' => 'homme dans la posture du lotus : peau modérément claire',
    '🧘🏽‍♂' => 'homme dans la posture du lotus : peau légèrement mate',
    '🧘🏾‍♂' => 'homme dans la posture du lotus : peau modérément foncée',
    '🧘🏿‍♂' => 'homme dans la posture du lotus : peau foncée',
    '🧘🏻‍♀' => 'femme dans la posture du lotus : peau claire',
    '🧘🏼‍♀' => 'femme dans la posture du lotus : peau modérément claire',
    '🧘🏽‍♀' => 'femme dans la posture du lotus : peau légèrement mate',
    '🧘🏾‍♀' => 'femme dans la posture du lotus : peau modérément foncée',
    '🧘🏿‍♀' => 'femme dans la posture du lotus : peau foncée',
    '🧑‍🦰' => 'adulte : cheveux roux',
    '🧑‍🦱' => 'adulte : cheveux bouclés',
    '🧑‍🦳' => 'adulte : cheveux blancs',
    '🧑‍🦲' => 'adulte : chauve',
    '👨‍🦰' => 'homme : cheveux roux',
    '👨‍🦱' => 'homme : cheveux bouclés',
    '👨‍🦳' => 'homme : cheveux blancs',
    '👨‍🦲' => 'homme : chauve',
    '👩‍🦰' => 'femme : cheveux roux',
    '👩‍🦱' => 'femme : cheveux bouclés',
    '👩‍🦳' => 'femme : cheveux blancs',
    '👩‍🦲' => 'femme : chauve',
    '🚶‍➡' => 'personne qui marche : vers la droite',
    '🧎‍➡' => 'personne à genoux : vers la droite',
    '🏃‍➡' => 'personne qui court : vers la droite',
    '👨‍👦' => 'famille : homme et garçon',
    '👨‍👧' => 'famille : homme et fille',
    '👩‍👦' => 'famille : femme et garçon',
    '👩‍👧' => 'famille : femme et fille',
    '😶‍🌫' => 'visage dans les nuages',
    '😮‍💨' => 'visage expirant',
    '🙂‍↕' => 'tête secouée verticalement',
    '😵‍💫' => 'visage avec yeux en spirale',
    '❤‍🔥' => 'cœur en feu',
    '❤‍🩹' => 'cœur avec bandages',
    '👁‍🗨' => 'œil dans une bulle de parole',
    '🧔‍♂' => 'homme barbu',
    '👱‍♂' => 'homme blond',
    '🧔‍♀' => 'femme barbue',
    '👱‍♀' => 'femme blonde',
    '🙍‍♂' => 'homme fronçant les sourcils',
    '🙍‍♀' => 'femme fronçant les sourcils',
    '🙎‍♂' => 'homme qui boude',
    '🙎‍♀' => 'femme qui boude',
    '🙅‍♂' => 'homme faisant un geste de négation',
    '🙅‍♀' => 'femme faisant un geste de négation',
    '🙆‍♂' => 'homme faisant un geste d’affirmation',
    '🙆‍♀' => 'femme faisant un geste d’affirmation',
    '💁‍♂' => 'homme paume vers le haut',
    '💁‍♀' => 'guichetière',
    '🙋‍♂' => 'homme qui lève la main',
    '🙋‍♀' => 'femme qui lève la main',
    '🧏‍♂' => 'homme sourd',
    '🧏‍♀' => 'femme sourde',
    '🙇‍♂' => 'homme qui s’incline',
    '🙇‍♀' => 'femme qui s’incline',
    '🤦‍♂' => 'homme avec la paume sur le visage',
    '🤦‍♀' => 'femme avec paume de la main sur le visage',
    '🤷‍♂' => 'homme qui hausse les épaules',
    '🤷‍♀' => 'femme qui hausse les épaules',
    '🧑‍⚕' => 'professionnel de la santé',
    '👨‍⚕' => 'professionnel de la santé homme',
    '👩‍⚕' => 'professionnelle de la santé',
    '🧑‍🎓' => 'étudiant universitaire',
    '👨‍🎓' => 'étudiant',
    '👩‍🎓' => 'étudiante',
    '🧑‍🏫' => 'personnel enseignant',
    '👨‍🏫' => 'enseignant',
    '👩‍🏫' => 'enseignante',
    '🧑‍⚖' => 'juge',
    '👨‍⚖' => 'juge homme',
    '👩‍⚖' => 'juge femme',
    '🧑‍🌾' => 'fermier',
    '👨‍🌾' => 'fermier homme',
    '👩‍🌾' => 'fermière',
    '🧑‍🍳' => 'chef',
    '👨‍🍳' => 'cuisinier',
    '👩‍🍳' => 'cuisinière',
    '🧑‍🔧' => 'mécanicien',
    '👨‍🔧' => 'mécanicien homme',
    '👩‍🔧' => 'mécanicienne',
    '🧑‍🏭' => 'travailleur d’usine',
    '👨‍🏭' => 'ouvrier',
    '👩‍🏭' => 'ouvrière',
    '🧑‍💼' => 'employé de bureau',
    '👨‍💼' => 'employé de bureau homme',
    '👩‍💼' => 'employée de bureau',
    '🧑‍🔬' => 'scientifique',
    '👨‍🔬' => 'scientifique homme',
    '👩‍🔬' => 'scientifique femme',
    '🧑‍💻' => 'informaticien',
    '👨‍💻' => 'informaticien homme',
    '👩‍💻' => 'informaticienne',
    '🧑‍🎤' => 'chanteur',
    '👨‍🎤' => 'chanteur homme',
    '👩‍🎤' => 'chanteuse',
    '🧑‍🎨' => 'artiste',
    '👨‍🎨' => 'artiste homme',
    '👩‍🎨' => 'artiste femme',
    '🧑‍✈' => 'pilote',
    '👨‍✈' => 'pilote homme',
    '👩‍✈' => 'pilote femme',
    '🧑‍🚀' => 'astronaute',
    '👨‍🚀' => 'astronaute homme',
    '👩‍🚀' => 'astronaute femme',
    '🧑‍🚒' => 'pompier',
    '👨‍🚒' => 'pompier homme',
    '👩‍🚒' => 'pompier femme',
    '👮‍♂' => 'policier homme',
    '👮‍♀' => 'policière',
    '🕵‍♂' => 'détective homme',
    '🕵‍♀' => 'détective femme',
    '💂‍♂' => 'garde homme',
    '💂‍♀' => 'garde femme',
    '👷‍♂' => 'ouvrier du bâtiment',
    '👷‍♀' => 'ouvrière du bâtiment',
    '👳‍♂' => 'homme en turban',
    '👳‍♀' => 'femme en turban',
    '🤵‍♂' => 'homme en smoking',
    '🤵‍♀' => 'femme en smoking',
    '👰‍♂' => 'homme avec voile',
    '👰‍♀' => 'femme avec voile',
    '👩‍🍼' => 'femme allaitant un bébé',
    '👨‍🍼' => 'homme allaitant un bébé',
    '🧑‍🍼' => 'personne allaitant un bébé',
    '🧑‍🎄' => 'personnage de Noël',
    '🦸‍♂' => 'super-héros',
    '🦸‍♀' => 'super-héroïne',
    '🦹‍♂' => 'super-vilain homme',
    '🦹‍♀' => 'super-vilain femme',
    '🧙‍♂' => 'mage homme',
    '🧙‍♀' => 'mage femme',
    '🧚‍♂' => 'féetaud',
    '🧚‍♀' => 'fée',
    '🧛‍♂' => 'vampire homme',
    '🧛‍♀' => 'vampire femme',
    '🧜‍♂' => 'triton',
    '🧜‍♀' => 'sirène',
    '🧝‍♂' => 'elfe homme',
    '🧝‍♀' => 'elfe femme',
    '🧞‍♂' => 'génie homme',
    '🧞‍♀' => 'génie femme',
    '🧟‍♂' => 'zombie homme',
    '🧟‍♀' => 'zombie femme',
    '💆‍♂' => 'homme qui se fait masser',
    '💆‍♀' => 'femme qui se fait masser',
    '💇‍♂' => 'homme qui se fait couper les cheveux',
    '💇‍♀' => 'femme qui se fait couper les cheveux',
    '🚶‍♂' => 'homme qui marche',
    '🚶‍♀' => 'femme qui marche',
    '🧍‍♂' => 'homme debout',
    '🧍‍♀' => 'femme debout',
    '🧎‍♂' => 'homme à genoux',
    '🧎‍♀' => 'femme à genoux',
    '🧑‍🦯' => 'personne avec une canne blanche',
    '👨‍🦯' => 'homme avec canne blanche',
    '👩‍🦯' => 'femme avec canne blanche',
    '🧑‍🦼' => 'personne en fauteuil motorisé',
    '👨‍🦼' => 'homme en fauteuil motorisé',
    '👩‍🦼' => 'femme en fauteuil motorisé',
    '🧑‍🦽' => 'personne en fauteuil roulant manuel',
    '👨‍🦽' => 'homme en fauteuil roulant manuel',
    '👩‍🦽' => 'femme en fauteuil roulant manuel',
    '🏃‍♂' => 'homme qui court',
    '🏃‍♀' => 'femme qui court',
    '🧑‍🩰' => 'danseuse de ballet',
    '👯‍♂' => 'hommes qui portent des oreilles de lapin',
    '👯‍♀' => 'femmes qui portent des oreilles de lapin',
    '🧖‍♂' => 'homme dans un bain de vapeur',
    '🧖‍♀' => 'femme dans un bain de vapeur',
    '🧗‍♂' => 'homme qui grimpe',
    '🧗‍♀' => 'femme qui grimpe',
    '🏌‍♂' => 'golfeur',
    '🏌‍♀' => 'golfeuse',
    '🏄‍♂' => 'surfeur',
    '🏄‍♀' => 'surfeuse',
    '🚣‍♂' => 'rameur dans une barque',
    '🚣‍♀' => 'rameuse dans une barque',
    '🏊‍♂' => 'nageur',
    '🏊‍♀' => 'nageuse',
    '⛹‍♂' => 'homme qui fait rebondir un ballon',
    '⛹‍♀' => 'femme qui fait rebondir un ballon',
    '🏋‍♂' => 'homme haltérophile',
    '🏋‍♀' => 'femme haltérophile',
    '🚴‍♂' => 'cycliste homme',
    '🚴‍♀' => 'cycliste femme',
    '🚵‍♂' => 'homme en vélo de montagne',
    '🚵‍♀' => 'femme en vélo de montagne',
    '🤸‍♂' => 'homme faisant la roue',
    '🤸‍♀' => 'femme faisant la roue',
    '🤼‍♂' => 'lutteurs',
    '🤼‍♀' => 'lutteuses',
    '🤽‍♂' => 'joueur de water-polo',
    '🤽‍♀' => 'joueuse de water-polo',
    '🤾‍♂' => 'handballeur',
    '🤾‍♀' => 'handballeuse',
    '🤹‍♂' => 'jongleur',
    '🤹‍♀' => 'jongleuse',
    '🧘‍♂' => 'homme dans la posture du lotus',
    '🧘‍♀' => 'femme dans la posture du lotus',
    '🧑‍🧒' => 'famille : adulte, enfant',
    '🐕‍🦺' => 'chien d’assistance',
    '🐈‍⬛' => 'chat noir',
    '🐻‍❄' => 'ours polaire',
    '🐦‍⬛' => 'oiseau noir',
    '🐦‍🔥' => 'phénix',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'champignon brun',
    '⛓‍💥' => 'chaîne brisée',
    '🏳‍🌈' => 'drapeau arc-en-ciel',
    '🏳‍⚧' => 'drapeau transgenre',
    '🏴‍☠' => 'drapeau de pirate',
    '👋🏻' => 'signe de la main : peau claire',
    '👋🏼' => 'signe de la main : peau modérément claire',
    '👋🏽' => 'signe de la main : peau légèrement mate',
    '👋🏾' => 'signe de la main : peau modérément foncée',
    '👋🏿' => 'signe de la main : peau foncée',
    '🤚🏻' => 'dos de main levée : peau claire',
    '🤚🏼' => 'dos de main levée : peau modérément claire',
    '🤚🏽' => 'dos de main levée : peau légèrement mate',
    '🤚🏾' => 'dos de main levée : peau modérément foncée',
    '🤚🏿' => 'dos de main levée : peau foncée',
    '🖐🏻' => 'main aux doigts écartés : peau claire',
    '🖐🏼' => 'main aux doigts écartés : peau modérément claire',
    '🖐🏽' => 'main aux doigts écartés : peau légèrement mate',
    '🖐🏾' => 'main aux doigts écartés : peau modérément foncée',
    '🖐🏿' => 'main aux doigts écartés : peau foncée',
    '✋🏻' => 'main levée : peau claire',
    '✋🏼' => 'main levée : peau modérément claire',
    '✋🏽' => 'main levée : peau légèrement mate',
    '✋🏾' => 'main levée : peau modérément foncée',
    '✋🏿' => 'main levée : peau foncée',
    '🖖🏻' => 'salut vulcain : peau claire',
    '🖖🏼' => 'salut vulcain : peau modérément claire',
    '🖖🏽' => 'salut vulcain : peau légèrement mate',
    '🖖🏾' => 'salut vulcain : peau modérément foncée',
    '🖖🏿' => 'salut vulcain : peau foncée',
    '🫱🏻' => 'main vers la droite : peau claire',
    '🫱🏼' => 'main vers la droite : peau modérément claire',
    '🫱🏽' => 'main vers la droite : peau légèrement mate',
    '🫱🏾' => 'main vers la droite : peau modérément foncée',
    '🫱🏿' => 'main vers la droite : peau foncée',
    '🫲🏻' => 'main vers la gauche : peau claire',
    '🫲🏼' => 'main vers la gauche : peau modérément claire',
    '🫲🏽' => 'main vers la gauche : peau légèrement mate',
    '🫲🏾' => 'main vers la gauche : peau modérément foncée',
    '🫲🏿' => 'main vers la gauche : peau foncée',
    '🫳🏻' => 'main paume vers le bas : peau claire',
    '🫳🏼' => 'main paume vers le bas : peau modérément claire',
    '🫳🏽' => 'main paume vers le bas : peau légèrement mate',
    '🫳🏾' => 'main paume vers le bas : peau modérément foncée',
    '🫳🏿' => 'main paume vers le bas : peau foncée',
    '🫴🏻' => 'main paume vers le haut : peau claire',
    '🫴🏼' => 'main paume vers le haut : peau modérément claire',
    '🫴🏽' => 'main paume vers le haut : peau légèrement mate',
    '🫴🏾' => 'main paume vers le haut : peau modérément foncée',
    '🫴🏿' => 'main paume vers le haut : peau foncée',
    '🫷🏻' => 'main qui pousse vers la gauche : peau claire',
    '🫷🏼' => 'main qui pousse vers la gauche : peau modérément claire',
    '🫷🏽' => 'main qui pousse vers la gauche : peau légèrement mate',
    '🫷🏾' => 'main qui pousse vers la gauche : peau modérément foncée',
    '🫷🏿' => 'main qui pousse vers la gauche : peau foncée',
    '🫸🏻' => 'main qui pousse vers la droite : peau claire',
    '🫸🏼' => 'main qui pousse vers la droite : peau modérément claire',
    '🫸🏽' => 'main qui pousse vers la droite : peau légèrement mate',
    '🫸🏾' => 'main qui pousse vers la droite : peau modérément foncée',
    '🫸🏿' => 'main qui pousse vers la droite : peau foncée',
    '👌🏻' => 'ok : peau claire',
    '👌🏼' => 'ok : peau modérément claire',
    '👌🏽' => 'ok : peau légèrement mate',
    '👌🏾' => 'ok : peau modérément foncée',
    '👌🏿' => 'ok : peau foncée',
    '🤌🏻' => 'main qui interroge : peau claire',
    '🤌🏼' => 'main qui interroge : peau modérément claire',
    '🤌🏽' => 'main qui interroge : peau légèrement mate',
    '🤌🏾' => 'main qui interroge : peau modérément foncée',
    '🤌🏿' => 'main qui interroge : peau foncée',
    '🤏🏻' => 'pouce et index rapprochés : peau claire',
    '🤏🏼' => 'pouce et index rapprochés : peau modérément claire',
    '🤏🏽' => 'pouce et index rapprochés : peau légèrement mate',
    '🤏🏾' => 'pouce et index rapprochés : peau modérément foncée',
    '🤏🏿' => 'pouce et index rapprochés : peau foncée',
    '✌🏻' => 'V de la victoire : peau claire',
    '✌🏼' => 'V de la victoire : peau modérément claire',
    '✌🏽' => 'V de la victoire : peau légèrement mate',
    '✌🏾' => 'V de la victoire : peau modérément foncée',
    '✌🏿' => 'V de la victoire : peau foncée',
    '🤞🏻' => 'doigts croisés : peau claire',
    '🤞🏼' => 'doigts croisés : peau modérément claire',
    '🤞🏽' => 'doigts croisés : peau légèrement mate',
    '🤞🏾' => 'doigts croisés : peau modérément foncée',
    '🤞🏿' => 'doigts croisés : peau foncée',
    '🫰🏻' => 'main avec index et pouce croisés : peau claire',
    '🫰🏼' => 'main avec index et pouce croisés : peau modérément claire',
    '🫰🏽' => 'main avec index et pouce croisés : peau légèrement mate',
    '🫰🏾' => 'main avec index et pouce croisés : peau modérément foncée',
    '🫰🏿' => 'main avec index et pouce croisés : peau foncée',
    '🤟🏻' => 'signe je t’aime : peau claire',
    '🤟🏼' => 'signe je t’aime : peau modérément claire',
    '🤟🏽' => 'signe je t’aime : peau légèrement mate',
    '🤟🏾' => 'signe je t’aime : peau modérément foncée',
    '🤟🏿' => 'signe je t’aime : peau foncée',
    '🤘🏻' => 'cornes avec les doigts : peau claire',
    '🤘🏼' => 'cornes avec les doigts : peau modérément claire',
    '🤘🏽' => 'cornes avec les doigts : peau légèrement mate',
    '🤘🏾' => 'cornes avec les doigts : peau modérément foncée',
    '🤘🏿' => 'cornes avec les doigts : peau foncée',
    '🤙🏻' => 'appelle-moi : peau claire',
    '🤙🏼' => 'appelle-moi : peau modérément claire',
    '🤙🏽' => 'appelle-moi : peau légèrement mate',
    '🤙🏾' => 'appelle-moi : peau modérément foncée',
    '🤙🏿' => 'appelle-moi : peau foncée',
    '👈🏻' => 'main avec index pointant à gauche : peau claire',
    '👈🏼' => 'main avec index pointant à gauche : peau modérément claire',
    '👈🏽' => 'main avec index pointant à gauche : peau légèrement mate',
    '👈🏾' => 'main avec index pointant à gauche : peau modérément foncée',
    '👈🏿' => 'main avec index pointant à gauche : peau foncée',
    '👉🏻' => 'main avec index pointant à droite : peau claire',
    '👉🏼' => 'main avec index pointant à droite : peau modérément claire',
    '👉🏽' => 'main avec index pointant à droite : peau légèrement mate',
    '👉🏾' => 'main avec index pointant à droite : peau modérément foncée',
    '👉🏿' => 'main avec index pointant à droite : peau foncée',
    '👆🏻' => 'main avec index pointant vers le haut : peau claire',
    '👆🏼' => 'main avec index pointant vers le haut : peau modérément claire',
    '👆🏽' => 'main avec index pointant vers le haut : peau légèrement mate',
    '👆🏾' => 'main avec index pointant vers le haut : peau modérément foncée',
    '👆🏿' => 'main avec index pointant vers le haut : peau foncée',
    '🖕🏻' => 'doigt d’honneur : peau claire',
    '🖕🏼' => 'doigt d’honneur : peau modérément claire',
    '🖕🏽' => 'doigt d’honneur : peau légèrement mate',
    '🖕🏾' => 'doigt d’honneur : peau modérément foncée',
    '🖕🏿' => 'doigt d’honneur : peau foncée',
    '👇🏻' => 'main avec index pointant vers le bas : peau claire',
    '👇🏼' => 'main avec index pointant vers le bas : peau modérément claire',
    '👇🏽' => 'main avec index pointant vers le bas : peau légèrement mate',
    '👇🏾' => 'main avec index pointant vers le bas : peau modérément foncée',
    '👇🏿' => 'main avec index pointant vers le bas : peau foncée',
    '☝🏻' => 'index pointant vers le haut : peau claire',
    '☝🏼' => 'index pointant vers le haut : peau modérément claire',
    '☝🏽' => 'index pointant vers le haut : peau légèrement mate',
    '☝🏾' => 'index pointant vers le haut : peau modérément foncée',
    '☝🏿' => 'index pointant vers le haut : peau foncée',
    '🫵🏻' => 'index pointant vers l’utilisateur : peau claire',
    '🫵🏼' => 'index pointant vers l’utilisateur : peau modérément claire',
    '🫵🏽' => 'index pointant vers l’utilisateur : peau légèrement mate',
    '🫵🏾' => 'index pointant vers l’utilisateur : peau modérément foncée',
    '🫵🏿' => 'index pointant vers l’utilisateur : peau foncée',
    '👍🏻' => 'pouce vers le haut : peau claire',
    '👍🏼' => 'pouce vers le haut : peau modérément claire',
    '👍🏽' => 'pouce vers le haut : peau légèrement mate',
    '👍🏾' => 'pouce vers le haut : peau modérément foncée',
    '👍🏿' => 'pouce vers le haut : peau foncée',
    '👎🏻' => 'pouce vers le bas : peau claire',
    '👎🏼' => 'pouce vers le bas : peau modérément claire',
    '👎🏽' => 'pouce vers le bas : peau légèrement mate',
    '👎🏾' => 'pouce vers le bas : peau modérément foncée',
    '👎🏿' => 'pouce vers le bas : peau foncée',
    '✊🏻' => 'poing levé : peau claire',
    '✊🏼' => 'poing levé : peau modérément claire',
    '✊🏽' => 'poing levé : peau légèrement mate',
    '✊🏾' => 'poing levé : peau modérément foncée',
    '✊🏿' => 'poing levé : peau foncée',
    '👊🏻' => 'poing de face : peau claire',
    '👊🏼' => 'poing de face : peau modérément claire',
    '👊🏽' => 'poing de face : peau légèrement mate',
    '👊🏾' => 'poing de face : peau modérément foncée',
    '👊🏿' => 'poing de face : peau foncée',
    '🤛🏻' => 'poing à gauche : peau claire',
    '🤛🏼' => 'poing à gauche : peau modérément claire',
    '🤛🏽' => 'poing à gauche : peau légèrement mate',
    '🤛🏾' => 'poing à gauche : peau modérément foncée',
    '🤛🏿' => 'poing à gauche : peau foncée',
    '🤜🏻' => 'poing à droite : peau claire',
    '🤜🏼' => 'poing à droite : peau modérément claire',
    '🤜🏽' => 'poing à droite : peau légèrement mate',
    '🤜🏾' => 'poing à droite : peau modérément foncée',
    '🤜🏿' => 'poing à droite : peau foncée',
    '👏🏻' => 'applaudissements : peau claire',
    '👏🏼' => 'applaudissements : peau modérément claire',
    '👏🏽' => 'applaudissements : peau légèrement mate',
    '👏🏾' => 'applaudissements : peau modérément foncée',
    '👏🏿' => 'applaudissements : peau foncée',
    '🙌🏻' => 'mains levées : peau claire',
    '🙌🏼' => 'mains levées : peau modérément claire',
    '🙌🏽' => 'mains levées : peau légèrement mate',
    '🙌🏾' => 'mains levées : peau modérément foncée',
    '🙌🏿' => 'mains levées : peau foncée',
    '🫶🏻' => 'mains qui forment un cœur : peau claire',
    '🫶🏼' => 'mains qui forment un cœur : peau modérément claire',
    '🫶🏽' => 'mains qui forment un cœur : peau légèrement mate',
    '🫶🏾' => 'mains qui forment un cœur : peau modérément foncée',
    '🫶🏿' => 'mains qui forment un cœur : peau foncée',
    '👐🏻' => 'mains ouvertes : peau claire',
    '👐🏼' => 'mains ouvertes : peau modérément claire',
    '👐🏽' => 'mains ouvertes : peau légèrement mate',
    '👐🏾' => 'mains ouvertes : peau modérément foncée',
    '👐🏿' => 'mains ouvertes : peau foncée',
    '🤲🏻' => 'paume contre paume doigts vers le haut : peau claire',
    '🤲🏼' => 'paume contre paume doigts vers le haut : peau modérément claire',
    '🤲🏽' => 'paume contre paume doigts vers le haut : peau légèrement mate',
    '🤲🏾' => 'paume contre paume doigts vers le haut : peau modérément foncée',
    '🤲🏿' => 'paume contre paume doigts vers le haut : peau foncée',
    '🤝🏻' => 'poignée de main : peau claire',
    '🤝🏼' => 'poignée de main : peau modérément claire',
    '🤝🏽' => 'poignée de main : peau légèrement mate',
    '🤝🏾' => 'poignée de main : peau modérément foncée',
    '🤝🏿' => 'poignée de main : peau foncée',
    '🙏🏻' => 'mains en prière : peau claire',
    '🙏🏼' => 'mains en prière : peau modérément claire',
    '🙏🏽' => 'mains en prière : peau légèrement mate',
    '🙏🏾' => 'mains en prière : peau modérément foncée',
    '🙏🏿' => 'mains en prière : peau foncée',
    '✍🏻' => 'main qui écrit : peau claire',
    '✍🏼' => 'main qui écrit : peau modérément claire',
    '✍🏽' => 'main qui écrit : peau légèrement mate',
    '✍🏾' => 'main qui écrit : peau modérément foncée',
    '✍🏿' => 'main qui écrit : peau foncée',
    '💅🏻' => 'vernis à ongles : peau claire',
    '💅🏼' => 'vernis à ongles : peau modérément claire',
    '💅🏽' => 'vernis à ongles : peau légèrement mate',
    '💅🏾' => 'vernis à ongles : peau modérément foncée',
    '💅🏿' => 'vernis à ongles : peau foncée',
    '🤳🏻' => 'égoportrait : peau claire',
    '🤳🏼' => 'égoportrait : peau modérément claire',
    '🤳🏽' => 'égoportrait : peau légèrement mate',
    '🤳🏾' => 'égoportrait : peau modérément foncée',
    '🤳🏿' => 'égoportrait : peau foncée',
    '💪🏻' => 'biceps contracté : peau claire',
    '💪🏼' => 'biceps contracté : peau modérément claire',
    '💪🏽' => 'biceps contracté : peau légèrement mate',
    '💪🏾' => 'biceps contracté : peau modérément foncée',
    '💪🏿' => 'biceps contracté : peau foncée',
    '🦵🏻' => 'jambe : peau claire',
    '🦵🏼' => 'jambe : peau modérément claire',
    '🦵🏽' => 'jambe : peau légèrement mate',
    '🦵🏾' => 'jambe : peau modérément foncée',
    '🦵🏿' => 'jambe : peau foncée',
    '🦶🏻' => 'pied : peau claire',
    '🦶🏼' => 'pied : peau modérément claire',
    '🦶🏽' => 'pied : peau légèrement mate',
    '🦶🏾' => 'pied : peau modérément foncée',
    '🦶🏿' => 'pied : peau foncée',
    '👂🏻' => 'oreille : peau claire',
    '👂🏼' => 'oreille : peau modérément claire',
    '👂🏽' => 'oreille : peau légèrement mate',
    '👂🏾' => 'oreille : peau modérément foncée',
    '👂🏿' => 'oreille : peau foncée',
    '🦻🏻' => 'oreille appareillée : peau claire',
    '🦻🏼' => 'oreille appareillée : peau modérément claire',
    '🦻🏽' => 'oreille appareillée : peau légèrement mate',
    '🦻🏾' => 'oreille appareillée : peau modérément foncée',
    '🦻🏿' => 'oreille appareillée : peau foncée',
    '👃🏻' => 'nez : peau claire',
    '👃🏼' => 'nez : peau modérément claire',
    '👃🏽' => 'nez : peau légèrement mate',
    '👃🏾' => 'nez : peau modérément foncée',
    '👃🏿' => 'nez : peau foncée',
    '👶🏻' => 'bébé : peau claire',
    '👶🏼' => 'bébé : peau modérément claire',
    '👶🏽' => 'bébé : peau légèrement mate',
    '👶🏾' => 'bébé : peau modérément foncée',
    '👶🏿' => 'bébé : peau foncée',
    '🧒🏻' => 'enfant : peau claire',
    '🧒🏼' => 'enfant : peau modérément claire',
    '🧒🏽' => 'enfant : peau légèrement mate',
    '🧒🏾' => 'enfant : peau modérément foncée',
    '🧒🏿' => 'enfant : peau foncée',
    '👦🏻' => 'garçon : peau claire',
    '👦🏼' => 'garçon : peau modérément claire',
    '👦🏽' => 'garçon : peau légèrement mate',
    '👦🏾' => 'garçon : peau modérément foncée',
    '👦🏿' => 'garçon : peau foncée',
    '👧🏻' => 'fille : peau claire',
    '👧🏼' => 'fille : peau modérément claire',
    '👧🏽' => 'fille : peau légèrement mate',
    '👧🏾' => 'fille : peau modérément foncée',
    '👧🏿' => 'fille : peau foncée',
    '🧑🏻' => 'adulte : peau claire',
    '🧑🏼' => 'adulte : peau modérément claire',
    '🧑🏽' => 'adulte : peau légèrement mate',
    '🧑🏾' => 'adulte : peau modérément foncée',
    '🧑🏿' => 'adulte : peau foncée',
    '👱🏻' => 'personne blonde : peau claire',
    '👱🏼' => 'personne blonde : peau modérément claire',
    '👱🏽' => 'personne blonde : peau légèrement mate',
    '👱🏾' => 'personne blonde : peau modérément foncée',
    '👱🏿' => 'personne blonde : peau foncée',
    '👨🏻' => 'homme : peau claire',
    '👨🏼' => 'homme : peau modérément claire',
    '👨🏽' => 'homme : peau légèrement mate',
    '👨🏾' => 'homme : peau modérément foncée',
    '👨🏿' => 'homme : peau foncée',
    '🧔🏻' => 'personne barbue : peau claire',
    '🧔🏼' => 'personne barbue : peau modérément claire',
    '🧔🏽' => 'personne barbue : peau légèrement mate',
    '🧔🏾' => 'personne barbue : peau modérément foncée',
    '🧔🏿' => 'personne barbue : peau foncée',
    '👩🏻' => 'femme : peau claire',
    '👩🏼' => 'femme : peau modérément claire',
    '👩🏽' => 'femme : peau légèrement mate',
    '👩🏾' => 'femme : peau modérément foncée',
    '👩🏿' => 'femme : peau foncée',
    '🧓🏻' => 'personne âgée : peau claire',
    '🧓🏼' => 'personne âgée : peau modérément claire',
    '🧓🏽' => 'personne âgée : peau légèrement mate',
    '🧓🏾' => 'personne âgée : peau modérément foncée',
    '🧓🏿' => 'personne âgée : peau foncée',
    '👴🏻' => 'homme âgé : peau claire',
    '👴🏼' => 'homme âgé : peau modérément claire',
    '👴🏽' => 'homme âgé : peau légèrement mate',
    '👴🏾' => 'homme âgé : peau modérément foncée',
    '👴🏿' => 'homme âgé : peau foncée',
    '👵🏻' => 'femme âgée : peau claire',
    '👵🏼' => 'femme âgée : peau modérément claire',
    '👵🏽' => 'femme âgée : peau légèrement mate',
    '👵🏾' => 'femme âgée : peau modérément foncée',
    '👵🏿' => 'femme âgée : peau foncée',
    '🙍🏻' => 'personne mécontente : peau claire',
    '🙍🏼' => 'personne mécontente : peau modérément claire',
    '🙍🏽' => 'personne mécontente : peau légèrement mate',
    '🙍🏾' => 'personne mécontente : peau modérément foncée',
    '🙍🏿' => 'personne mécontente : peau foncée',
    '🙎🏻' => 'personne qui boude : peau claire',
    '🙎🏼' => 'personne qui boude : peau modérément claire',
    '🙎🏽' => 'personne qui boude : peau légèrement mate',
    '🙎🏾' => 'personne qui boude : peau modérément foncée',
    '🙎🏿' => 'personne qui boude : peau foncée',
    '🙅🏻' => 'personne faisant un geste d’interdiction : peau claire',
    '🙅🏼' => 'personne faisant un geste d’interdiction : peau modérément claire',
    '🙅🏽' => 'personne faisant un geste d’interdiction : peau légèrement mate',
    '🙅🏾' => 'personne faisant un geste d’interdiction : peau modérément foncée',
    '🙅🏿' => 'personne faisant un geste d’interdiction : peau foncée',
    '🙆🏻' => 'geste d’affirmation : peau claire',
    '🙆🏼' => 'geste d’affirmation : peau modérément claire',
    '🙆🏽' => 'geste d’affirmation : peau légèrement mate',
    '🙆🏾' => 'geste d’affirmation : peau modérément foncée',
    '🙆🏿' => 'geste d’affirmation : peau foncée',
    '💁🏻' => 'personne paume vers le haut : peau claire',
    '💁🏼' => 'personne paume vers le haut : peau modérément claire',
    '💁🏽' => 'personne paume vers le haut : peau légèrement mate',
    '💁🏾' => 'personne paume vers le haut : peau modérément foncée',
    '💁🏿' => 'personne paume vers le haut : peau foncée',
    '🙋🏻' => 'personne qui lève la main : peau claire',
    '🙋🏼' => 'personne qui lève la main : peau modérément claire',
    '🙋🏽' => 'personne qui lève la main : peau légèrement mate',
    '🙋🏾' => 'personne qui lève la main : peau modérément foncée',
    '🙋🏿' => 'personne qui lève la main : peau foncée',
    '🧏🏻' => 'personne sourde : peau claire',
    '🧏🏼' => 'personne sourde : peau modérément claire',
    '🧏🏽' => 'personne sourde : peau légèrement mate',
    '🧏🏾' => 'personne sourde : peau modérément foncée',
    '🧏🏿' => 'personne sourde : peau foncée',
    '🙇🏻' => 'personne qui s’incline : peau claire',
    '🙇🏼' => 'personne qui s’incline : peau modérément claire',
    '🙇🏽' => 'personne qui s’incline : peau légèrement mate',
    '🙇🏾' => 'personne qui s’incline : peau modérément foncée',
    '🙇🏿' => 'personne qui s’incline : peau foncée',
    '🤦🏻' => 'personne avec la paume sur le visage : peau claire',
    '🤦🏼' => 'personne avec la paume sur le visage : peau modérément claire',
    '🤦🏽' => 'personne avec la paume sur le visage : peau légèrement mate',
    '🤦🏾' => 'personne avec la paume sur le visage : peau modérément foncée',
    '🤦🏿' => 'personne avec la paume sur le visage : peau foncée',
    '🤷🏻' => 'personne qui hausse les épaules : peau claire',
    '🤷🏼' => 'personne qui hausse les épaules : peau modérément claire',
    '🤷🏽' => 'personne qui hausse les épaules : peau légèrement mate',
    '🤷🏾' => 'personne qui hausse les épaules : peau modérément foncée',
    '🤷🏿' => 'personne qui hausse les épaules : peau foncée',
    '👮🏻' => 'policier : peau claire',
    '👮🏼' => 'policier : peau modérément claire',
    '👮🏽' => 'policier : peau légèrement mate',
    '👮🏾' => 'policier : peau modérément foncée',
    '👮🏿' => 'policier : peau foncée',
    '🕵🏻' => 'détective : peau claire',
    '🕵🏼' => 'détective : peau modérément claire',
    '🕵🏽' => 'détective : peau légèrement mate',
    '🕵🏾' => 'détective : peau modérément foncée',
    '🕵🏿' => 'détective : peau foncée',
    '💂🏻' => 'garde : peau claire',
    '💂🏼' => 'garde : peau modérément claire',
    '💂🏽' => 'garde : peau légèrement mate',
    '💂🏾' => 'garde : peau modérément foncée',
    '💂🏿' => 'garde : peau foncée',
    '🥷🏻' => 'ninja : peau claire',
    '🥷🏼' => 'ninja : peau modérément claire',
    '🥷🏽' => 'ninja : peau légèrement mate',
    '🥷🏾' => 'ninja : peau modérément foncée',
    '🥷🏿' => 'ninja : peau foncée',
    '👷🏻' => 'personnel du bâtiment : peau claire',
    '👷🏼' => 'personnel du bâtiment : peau modérément claire',
    '👷🏽' => 'personnel du bâtiment : peau légèrement mate',
    '👷🏾' => 'personnel du bâtiment : peau modérément foncée',
    '👷🏿' => 'personnel du bâtiment : peau foncée',
    '🫅🏻' => 'personne avec une couronne : peau claire',
    '🫅🏼' => 'personne avec une couronne : peau modérément claire',
    '🫅🏽' => 'personne avec une couronne : peau légèrement mate',
    '🫅🏾' => 'personne avec une couronne : peau modérément foncée',
    '🫅🏿' => 'personne avec une couronne : peau foncée',
    '🤴🏻' => 'prince : peau claire',
    '🤴🏼' => 'prince : peau modérément claire',
    '🤴🏽' => 'prince : peau légèrement mate',
    '🤴🏾' => 'prince : peau modérément foncée',
    '🤴🏿' => 'prince : peau foncée',
    '👸🏻' => 'princesse : peau claire',
    '👸🏼' => 'princesse : peau modérément claire',
    '👸🏽' => 'princesse : peau légèrement mate',
    '👸🏾' => 'princesse : peau modérément foncée',
    '👸🏿' => 'princesse : peau foncée',
    '👳🏻' => 'personne en turban : peau claire',
    '👳🏼' => 'personne en turban : peau modérément claire',
    '👳🏽' => 'personne en turban : peau légèrement mate',
    '👳🏾' => 'personne en turban : peau modérément foncée',
    '👳🏿' => 'personne en turban : peau foncée',
    '👲🏻' => 'personne coiffée d’une calotte chinoise : peau claire',
    '👲🏼' => 'personne coiffée d’une calotte chinoise : peau modérément claire',
    '👲🏽' => 'personne coiffée d’une calotte chinoise : peau légèrement mate',
    '👲🏾' => 'personne coiffée d’une calotte chinoise : peau modérément foncée',
    '👲🏿' => 'personne coiffée d’une calotte chinoise : peau foncée',
    '🧕🏻' => 'femme avec foulard : peau claire',
    '🧕🏼' => 'femme avec foulard : peau modérément claire',
    '🧕🏽' => 'femme avec foulard : peau légèrement mate',
    '🧕🏾' => 'femme avec foulard : peau modérément foncée',
    '🧕🏿' => 'femme avec foulard : peau foncée',
    '🤵🏻' => 'personne en smoking : peau claire',
    '🤵🏼' => 'personne en smoking : peau modérément claire',
    '🤵🏽' => 'personne en smoking : peau légèrement mate',
    '🤵🏾' => 'personne en smoking : peau modérément foncée',
    '🤵🏿' => 'personne en smoking : peau foncée',
    '👰🏻' => 'personne avec voile : peau claire',
    '👰🏼' => 'personne avec voile : peau modérément claire',
    '👰🏽' => 'personne avec voile : peau légèrement mate',
    '👰🏾' => 'personne avec voile : peau modérément foncée',
    '👰🏿' => 'personne avec voile : peau foncée',
    '🤰🏻' => 'femme enceinte : peau claire',
    '🤰🏼' => 'femme enceinte : peau modérément claire',
    '🤰🏽' => 'femme enceinte : peau légèrement mate',
    '🤰🏾' => 'femme enceinte : peau modérément foncée',
    '🤰🏿' => 'femme enceinte : peau foncée',
    '🫃🏻' => 'homme enceint : peau claire',
    '🫃🏼' => 'homme enceint : peau modérément claire',
    '🫃🏽' => 'homme enceint : peau légèrement mate',
    '🫃🏾' => 'homme enceint : peau modérément foncée',
    '🫃🏿' => 'homme enceint : peau foncée',
    '🫄🏻' => 'personne enceinte : peau claire',
    '🫄🏼' => 'personne enceinte : peau modérément claire',
    '🫄🏽' => 'personne enceinte : peau légèrement mate',
    '🫄🏾' => 'personne enceinte : peau modérément foncée',
    '🫄🏿' => 'personne enceinte : peau foncée',
    '🤱🏻' => 'allaitement : peau claire',
    '🤱🏼' => 'allaitement : peau modérément claire',
    '🤱🏽' => 'allaitement : peau légèrement mate',
    '🤱🏾' => 'allaitement : peau modérément foncée',
    '🤱🏿' => 'allaitement : peau foncée',
    '👼🏻' => 'bébé ange : peau claire',
    '👼🏼' => 'bébé ange : peau modérément claire',
    '👼🏽' => 'bébé ange : peau légèrement mate',
    '👼🏾' => 'bébé ange : peau modérément foncée',
    '👼🏿' => 'bébé ange : peau foncée',
    '🎅🏻' => 'père Noël : peau claire',
    '🎅🏼' => 'père Noël : peau modérément claire',
    '🎅🏽' => 'père Noël : peau légèrement mate',
    '🎅🏾' => 'père Noël : peau modérément foncée',
    '🎅🏿' => 'père Noël : peau foncée',
    '🤶🏻' => 'mère Noël : peau claire',
    '🤶🏼' => 'mère Noël : peau modérément claire',
    '🤶🏽' => 'mère Noël : peau légèrement mate',
    '🤶🏾' => 'mère Noël : peau modérément foncée',
    '🤶🏿' => 'mère Noël : peau foncée',
    '🦸🏻' => 'superhéros : peau claire',
    '🦸🏼' => 'superhéros : peau modérément claire',
    '🦸🏽' => 'superhéros : peau légèrement mate',
    '🦸🏾' => 'superhéros : peau modérément foncée',
    '🦸🏿' => 'superhéros : peau foncée',
    '🦹🏻' => 'super-vilain : peau claire',
    '🦹🏼' => 'super-vilain : peau modérément claire',
    '🦹🏽' => 'super-vilain : peau légèrement mate',
    '🦹🏾' => 'super-vilain : peau modérément foncée',
    '🦹🏿' => 'super-vilain : peau foncée',
    '🧙🏻' => 'mage : peau claire',
    '🧙🏼' => 'mage : peau modérément claire',
    '🧙🏽' => 'mage : peau légèrement mate',
    '🧙🏾' => 'mage : peau modérément foncée',
    '🧙🏿' => 'mage : peau foncée',
    '🧚🏻' => 'personnage féérique : peau claire',
    '🧚🏼' => 'personnage féérique : peau modérément claire',
    '🧚🏽' => 'personnage féérique : peau légèrement mate',
    '🧚🏾' => 'personnage féérique : peau modérément foncée',
    '🧚🏿' => 'personnage féérique : peau foncée',
    '🧛🏻' => 'vampire : peau claire',
    '🧛🏼' => 'vampire : peau modérément claire',
    '🧛🏽' => 'vampire : peau légèrement mate',
    '🧛🏾' => 'vampire : peau modérément foncée',
    '🧛🏿' => 'vampire : peau foncée',
    '🧜🏻' => 'créature aquatique : peau claire',
    '🧜🏼' => 'créature aquatique : peau modérément claire',
    '🧜🏽' => 'créature aquatique : peau légèrement mate',
    '🧜🏾' => 'créature aquatique : peau modérément foncée',
    '🧜🏿' => 'créature aquatique : peau foncée',
    '🧝🏻' => 'elfe : peau claire',
    '🧝🏼' => 'elfe : peau modérément claire',
    '🧝🏽' => 'elfe : peau légèrement mate',
    '🧝🏾' => 'elfe : peau modérément foncée',
    '🧝🏿' => 'elfe : peau foncée',
    '💆🏻' => 'personne qui se fait masser : peau claire',
    '💆🏼' => 'personne qui se fait masser : peau modérément claire',
    '💆🏽' => 'personne qui se fait masser : peau légèrement mate',
    '💆🏾' => 'personne qui se fait masser : peau modérément foncée',
    '💆🏿' => 'personne qui se fait masser : peau foncée',
    '💇🏻' => 'personne qui se fait couper les cheveux : peau claire',
    '💇🏼' => 'personne qui se fait couper les cheveux : peau modérément claire',
    '💇🏽' => 'personne qui se fait couper les cheveux : peau légèrement mate',
    '💇🏾' => 'personne qui se fait couper les cheveux : peau modérément foncée',
    '💇🏿' => 'personne qui se fait couper les cheveux : peau foncée',
    '🚶🏻' => 'personne qui marche : peau claire',
    '🚶🏼' => 'personne qui marche : peau modérément claire',
    '🚶🏽' => 'personne qui marche : peau légèrement mate',
    '🚶🏾' => 'personne qui marche : peau modérément foncée',
    '🚶🏿' => 'personne qui marche : peau foncée',
    '🧍🏻' => 'personne debout : peau claire',
    '🧍🏼' => 'personne debout : peau modérément claire',
    '🧍🏽' => 'personne debout : peau légèrement mate',
    '🧍🏾' => 'personne debout : peau modérément foncée',
    '🧍🏿' => 'personne debout : peau foncée',
    '🧎🏻' => 'personne à genoux : peau claire',
    '🧎🏼' => 'personne à genoux : peau modérément claire',
    '🧎🏽' => 'personne à genoux : peau légèrement mate',
    '🧎🏾' => 'personne à genoux : peau modérément foncée',
    '🧎🏿' => 'personne à genoux : peau foncée',
    '🏃🏻' => 'personne qui court : peau claire',
    '🏃🏼' => 'personne qui court : peau modérément claire',
    '🏃🏽' => 'personne qui court : peau légèrement mate',
    '🏃🏾' => 'personne qui court : peau modérément foncée',
    '🏃🏿' => 'personne qui court : peau foncée',
    '💃🏻' => 'danseuse : peau claire',
    '💃🏼' => 'danseuse : peau modérément claire',
    '💃🏽' => 'danseuse : peau légèrement mate',
    '💃🏾' => 'danseuse : peau modérément foncée',
    '💃🏿' => 'danseuse : peau foncée',
    '🕺🏻' => 'danseur : peau claire',
    '🕺🏼' => 'danseur : peau modérément claire',
    '🕺🏽' => 'danseur : peau légèrement mate',
    '🕺🏾' => 'danseur : peau modérément foncée',
    '🕺🏿' => 'danseur : peau foncée',
    '🕴🏻' => 'homme d’affaires en lévitation : peau claire',
    '🕴🏼' => 'homme d’affaires en lévitation : peau modérément claire',
    '🕴🏽' => 'homme d’affaires en lévitation : peau légèrement mate',
    '🕴🏾' => 'homme d’affaires en lévitation : peau modérément foncée',
    '🕴🏿' => 'homme d’affaires en lévitation : peau foncée',
    '👯🏻' => 'personnes qui portent des oreilles de lapin : peau claire',
    '👯🏼' => 'personnes qui portent des oreilles de lapin : peau modérément claire',
    '👯🏽' => 'personnes qui portent des oreilles de lapin : peau légèrement mate',
    '👯🏾' => 'personnes qui portent des oreilles de lapin : peau modérément foncée',
    '👯🏿' => 'personnes qui portent des oreilles de lapin : peau foncée',
    '🧖🏻' => 'personne dans un bain de vapeur : peau claire',
    '🧖🏼' => 'personne dans un bain de vapeur : peau modérément claire',
    '🧖🏽' => 'personne dans un bain de vapeur : peau légèrement mate',
    '🧖🏾' => 'personne dans un bain de vapeur : peau modérément foncée',
    '🧖🏿' => 'personne dans un bain de vapeur : peau foncée',
    '🧗🏻' => 'personne qui grimpe : peau claire',
    '🧗🏼' => 'personne qui grimpe : peau modérément claire',
    '🧗🏽' => 'personne qui grimpe : peau légèrement mate',
    '🧗🏾' => 'personne qui grimpe : peau modérément foncée',
    '🧗🏿' => 'personne qui grimpe : peau foncée',
    '🏇🏻' => 'course hippique : peau claire',
    '🏇🏼' => 'course hippique : peau modérément claire',
    '🏇🏽' => 'course hippique : peau légèrement mate',
    '🏇🏾' => 'course hippique : peau modérément foncée',
    '🏇🏿' => 'course hippique : peau foncée',
    '🏂🏻' => 'planchiste : peau claire',
    '🏂🏼' => 'planchiste : peau modérément claire',
    '🏂🏽' => 'planchiste : peau légèrement mate',
    '🏂🏾' => 'planchiste : peau modérément foncée',
    '🏂🏿' => 'planchiste : peau foncée',
    '🏌🏻' => 'joueur de golf : peau claire',
    '🏌🏼' => 'joueur de golf : peau modérément claire',
    '🏌🏽' => 'joueur de golf : peau légèrement mate',
    '🏌🏾' => 'joueur de golf : peau modérément foncée',
    '🏌🏿' => 'joueur de golf : peau foncée',
    '🏄🏻' => 'personne qui fait du surf : peau claire',
    '🏄🏼' => 'personne qui fait du surf : peau modérément claire',
    '🏄🏽' => 'personne qui fait du surf : peau légèrement mate',
    '🏄🏾' => 'personne qui fait du surf : peau modérément foncée',
    '🏄🏿' => 'personne qui fait du surf : peau foncée',
    '🚣🏻' => 'personne qui rame dans une barque : peau claire',
    '🚣🏼' => 'personne qui rame dans une barque : peau modérément claire',
    '🚣🏽' => 'personne qui rame dans une barque : peau légèrement mate',
    '🚣🏾' => 'personne qui rame dans une barque : peau modérément foncée',
    '🚣🏿' => 'personne qui rame dans une barque : peau foncée',
    '🏊🏻' => 'personne qui nage : peau claire',
    '🏊🏼' => 'personne qui nage : peau modérément claire',
    '🏊🏽' => 'personne qui nage : peau légèrement mate',
    '🏊🏾' => 'personne qui nage : peau modérément foncée',
    '🏊🏿' => 'personne qui nage : peau foncée',
    '⛹🏻' => 'personne qui fait rebondir un ballon : peau claire',
    '⛹🏼' => 'personne qui fait rebondir un ballon : peau modérément claire',
    '⛹🏽' => 'personne qui fait rebondir un ballon : peau légèrement mate',
    '⛹🏾' => 'personne qui fait rebondir un ballon : peau modérément foncée',
    '⛹🏿' => 'personne qui fait rebondir un ballon : peau foncée',
    '🏋🏻' => 'haltérophile : peau claire',
    '🏋🏼' => 'haltérophile : peau modérément claire',
    '🏋🏽' => 'haltérophile : peau légèrement mate',
    '🏋🏾' => 'haltérophile : peau modérément foncée',
    '🏋🏿' => 'haltérophile : peau foncée',
    '🚴🏻' => 'cycliste : peau claire',
    '🚴🏼' => 'cycliste : peau modérément claire',
    '🚴🏽' => 'cycliste : peau légèrement mate',
    '🚴🏾' => 'cycliste : peau modérément foncée',
    '🚴🏿' => 'cycliste : peau foncée',
    '🚵🏻' => 'personne en vélo de montagne : peau claire',
    '🚵🏼' => 'personne en vélo de montagne : peau modérément claire',
    '🚵🏽' => 'personne en vélo de montagne : peau légèrement mate',
    '🚵🏾' => 'personne en vélo de montagne : peau modérément foncée',
    '🚵🏿' => 'personne en vélo de montagne : peau foncée',
    '🤸🏻' => 'personne faisant la roue : peau claire',
    '🤸🏼' => 'personne faisant la roue : peau modérément claire',
    '🤸🏽' => 'personne faisant la roue : peau légèrement mate',
    '🤸🏾' => 'personne faisant la roue : peau modérément foncée',
    '🤸🏿' => 'personne faisant la roue : peau foncée',
    '🤼🏻' => 'personnes faisant de la lutte : peau claire',
    '🤼🏼' => 'personnes faisant de la lutte : peau modérément claire',
    '🤼🏽' => 'personnes faisant de la lutte : peau légèrement mate',
    '🤼🏾' => 'personnes faisant de la lutte : peau modérément foncée',
    '🤼🏿' => 'personnes faisant de la lutte : peau foncée',
    '🤽🏻' => 'personne qui joue au water-polo : peau claire',
    '🤽🏼' => 'personne qui joue au water-polo : peau modérément claire',
    '🤽🏽' => 'personne qui joue au water-polo : peau légèrement mate',
    '🤽🏾' => 'personne qui joue au water-polo : peau modérément foncée',
    '🤽🏿' => 'personne qui joue au water-polo : peau foncée',
    '🤾🏻' => 'personne qui joue au handball : peau claire',
    '🤾🏼' => 'personne qui joue au handball : peau modérément claire',
    '🤾🏽' => 'personne qui joue au handball : peau légèrement mate',
    '🤾🏾' => 'personne qui joue au handball : peau modérément foncée',
    '🤾🏿' => 'personne qui joue au handball : peau foncée',
    '🤹🏻' => 'personne qui jongle : peau claire',
    '🤹🏼' => 'personne qui jongle : peau modérément claire',
    '🤹🏽' => 'personne qui jongle : peau légèrement mate',
    '🤹🏾' => 'personne qui jongle : peau modérément foncée',
    '🤹🏿' => 'personne qui jongle : peau foncée',
    '🧘🏻' => 'personne dans la posture du lotus : peau claire',
    '🧘🏼' => 'personne dans la posture du lotus : peau modérément claire',
    '🧘🏽' => 'personne dans la posture du lotus : peau légèrement mate',
    '🧘🏾' => 'personne dans la posture du lotus : peau modérément foncée',
    '🧘🏿' => 'personne dans la posture du lotus : peau foncée',
    '🛀🏻' => 'personne prenant un bain : peau claire',
    '🛀🏼' => 'personne prenant un bain : peau modérément claire',
    '🛀🏽' => 'personne prenant un bain : peau légèrement mate',
    '🛀🏾' => 'personne prenant un bain : peau modérément foncée',
    '🛀🏿' => 'personne prenant un bain : peau foncée',
    '🛌🏻' => 'personne au lit : peau claire',
    '🛌🏼' => 'personne au lit : peau modérément claire',
    '🛌🏽' => 'personne au lit : peau légèrement mate',
    '🛌🏾' => 'personne au lit : peau modérément foncée',
    '🛌🏿' => 'personne au lit : peau foncée',
    '👭🏻' => 'deux femmes se tenant par la main : peau claire',
    '👭🏼' => 'deux femmes se tenant par la main : peau modérément claire',
    '👭🏽' => 'deux femmes se tenant par la main : peau légèrement mate',
    '👭🏾' => 'deux femmes se tenant par la main : peau modérément foncée',
    '👭🏿' => 'deux femmes se tenant par la main : peau foncée',
    '👫🏻' => 'homme et femme se tenant par la main : peau claire',
    '👫🏼' => 'homme et femme se tenant par la main : peau modérément claire',
    '👫🏽' => 'homme et femme se tenant par la main : peau légèrement mate',
    '👫🏾' => 'homme et femme se tenant par la main : peau modérément foncée',
    '👫🏿' => 'homme et femme se tenant par la main : peau foncée',
    '👬🏻' => 'deux hommes se tenant par la main : peau claire',
    '👬🏼' => 'deux hommes se tenant par la main : peau modérément claire',
    '👬🏽' => 'deux hommes se tenant par la main : peau légèrement mate',
    '👬🏾' => 'deux hommes se tenant par la main : peau modérément foncée',
    '👬🏿' => 'deux hommes se tenant par la main : peau foncée',
    '💏🏻' => 'bisou : peau claire',
    '💏🏼' => 'bisou : peau modérément claire',
    '💏🏽' => 'bisou : peau légèrement mate',
    '💏🏾' => 'bisou : peau modérément foncée',
    '💏🏿' => 'bisou : peau foncée',
    '💑🏻' => 'couple avec cœur : peau claire',
    '💑🏼' => 'couple avec cœur : peau modérément claire',
    '💑🏽' => 'couple avec cœur : peau légèrement mate',
    '💑🏾' => 'couple avec cœur : peau modérément foncée',
    '💑🏿' => 'couple avec cœur : peau foncée',
    '🇦🇨' => 'drapeau : île de l’Ascension',
    '🇦🇩' => 'drapeau : Andorre',
    '🇦🇪' => 'drapeau : Émirats arabes unis',
    '🇦🇫' => 'drapeau : Afghanistan',
    '🇦🇬' => 'drapeau : Antigua-et-Barbuda',
    '🇦🇮' => 'drapeau : Anguilla',
    '🇦🇱' => 'drapeau : Albanie',
    '🇦🇲' => 'drapeau : Arménie',
    '🇦🇴' => 'drapeau : Angola',
    '🇦🇶' => 'drapeau : Antarctique',
    '🇦🇷' => 'drapeau : Argentine',
    '🇦🇸' => 'drapeau : Samoa américaines',
    '🇦🇹' => 'drapeau : Autriche',
    '🇦🇺' => 'drapeau : Australie',
    '🇦🇼' => 'drapeau : Aruba',
    '🇦🇽' => 'drapeau : îles d’Åland',
    '🇦🇿' => 'drapeau : Azerbaïdjan',
    '🇧🇦' => 'drapeau : Bosnie-Herzégovine',
    '🇧🇧' => 'drapeau : Barbade',
    '🇧🇩' => 'drapeau : Bangladesh',
    '🇧🇪' => 'drapeau : Belgique',
    '🇧🇫' => 'drapeau : Burkina Faso',
    '🇧🇬' => 'drapeau : Bulgarie',
    '🇧🇭' => 'drapeau : Bahreïn',
    '🇧🇮' => 'drapeau : Burundi',
    '🇧🇯' => 'drapeau : Bénin',
    '🇧🇱' => 'drapeau : Saint-Barthélemy',
    '🇧🇲' => 'drapeau : Bermudes',
    '🇧🇳' => 'drapeau : Brunéi',
    '🇧🇴' => 'drapeau : Bolivie',
    '🇧🇶' => 'drapeau : Pays-Bas caribéens',
    '🇧🇷' => 'drapeau : Brésil',
    '🇧🇸' => 'drapeau : Bahamas',
    '🇧🇹' => 'drapeau : Bhoutan',
    '🇧🇻' => 'drapeau : île Bouvet',
    '🇧🇼' => 'drapeau : Botswana',
    '🇧🇾' => 'drapeau : Bélarus',
    '🇧🇿' => 'drapeau : Bélize',
    '🇨🇦' => 'drapeau : Canada',
    '🇨🇨' => 'drapeau : îles Cocos (Keeling)',
    '🇨🇩' => 'drapeau : Congo-Kinshasa',
    '🇨🇫' => 'drapeau : République centrafricaine',
    '🇨🇬' => 'drapeau : Congo-Brazzaville',
    '🇨🇭' => 'drapeau : Suisse',
    '🇨🇮' => 'drapeau : Côte d’Ivoire',
    '🇨🇰' => 'drapeau : îles Cook',
    '🇨🇱' => 'drapeau : Chili',
    '🇨🇲' => 'drapeau : Cameroun',
    '🇨🇳' => 'drapeau : Chine',
    '🇨🇴' => 'drapeau : Colombie',
    '🇨🇵' => 'drapeau : île Clipperton',
    '🇨🇶' => 'drapeau : Sercq',
    '🇨🇷' => 'drapeau : Costa Rica',
    '🇨🇺' => 'drapeau : Cuba',
    '🇨🇻' => 'drapeau : Cap-Vert',
    '🇨🇼' => 'drapeau : Curaçao',
    '🇨🇽' => 'drapeau : île Christmas',
    '🇨🇾' => 'drapeau : Chypre',
    '🇨🇿' => 'drapeau : Tchéquie',
    '🇩🇪' => 'drapeau : Allemagne',
    '🇩🇬' => 'drapeau : Diego Garcia',
    '🇩🇯' => 'drapeau : Djibouti',
    '🇩🇰' => 'drapeau : Danemark',
    '🇩🇲' => 'drapeau : Dominique',
    '🇩🇴' => 'drapeau : République dominicaine',
    '🇩🇿' => 'drapeau : Algérie',
    '🇪🇦' => 'drapeau : Ceuta et Melilla',
    '🇪🇨' => 'drapeau : Équateur',
    '🇪🇪' => 'drapeau : Estonie',
    '🇪🇬' => 'drapeau : Égypte',
    '🇪🇭' => 'drapeau : Sahara occidental',
    '🇪🇷' => 'drapeau : Érythrée',
    '🇪🇸' => 'drapeau : Espagne',
    '🇪🇹' => 'drapeau : Éthiopie',
    '🇪🇺' => 'drapeau : Union européenne',
    '🇫🇮' => 'drapeau : Finlande',
    '🇫🇯' => 'drapeau : Fidji',
    '🇫🇰' => 'drapeau : îles Malouines',
    '🇫🇲' => 'drapeau : Micronésie',
    '🇫🇴' => 'drapeau : îles Féroé',
    '🇫🇷' => 'drapeau : France',
    '🇬🇦' => 'drapeau : Gabon',
    '🇬🇧' => 'drapeau : Royaume-Uni',
    '🇬🇩' => 'drapeau : Grenade',
    '🇬🇪' => 'drapeau : Géorgie',
    '🇬🇫' => 'drapeau : Guyane française',
    '🇬🇬' => 'drapeau : Guernesey',
    '🇬🇭' => 'drapeau : Ghana',
    '🇬🇮' => 'drapeau : Gibraltar',
    '🇬🇱' => 'drapeau : Groenland',
    '🇬🇲' => 'drapeau : Gambie',
    '🇬🇳' => 'drapeau : Guinée',
    '🇬🇵' => 'drapeau : Guadeloupe',
    '🇬🇶' => 'drapeau : Guinée équatoriale',
    '🇬🇷' => 'drapeau : Grèce',
    '🇬🇸' => 'drapeau : Géorgie du Sud-et-les Îles Sandwich du Sud',
    '🇬🇹' => 'drapeau : Guatemala',
    '🇬🇺' => 'drapeau : Guam',
    '🇬🇼' => 'drapeau : Guinée-Bissau',
    '🇬🇾' => 'drapeau : Guyana',
    '🇭🇰' => 'drapeau : R.A.S. chinoise de Hong Kong',
    '🇭🇲' => 'drapeau : îles Heard et McDonald',
    '🇭🇳' => 'drapeau : Honduras',
    '🇭🇷' => 'drapeau : Croatie',
    '🇭🇹' => 'drapeau : Haïti',
    '🇭🇺' => 'drapeau : Hongrie',
    '🇮🇨' => 'drapeau : îles Canaries',
    '🇮🇩' => 'drapeau : Indonésie',
    '🇮🇪' => 'drapeau : Irlande',
    '🇮🇱' => 'drapeau : Israël',
    '🇮🇲' => 'drapeau : île de Man',
    '🇮🇳' => 'drapeau : Inde',
    '🇮🇴' => 'drapeau : Territoire britannique de l’océan Indien',
    '🇮🇶' => 'drapeau : Irak',
    '🇮🇷' => 'drapeau : Iran',
    '🇮🇸' => 'drapeau : Islande',
    '🇮🇹' => 'drapeau : Italie',
    '🇯🇪' => 'drapeau : Jersey',
    '🇯🇲' => 'drapeau : Jamaïque',
    '🇯🇴' => 'drapeau : Jordanie',
    '🇯🇵' => 'drapeau : Japon',
    '🇰🇪' => 'drapeau : Kenya',
    '🇰🇬' => 'drapeau : Kirghizistan',
    '🇰🇭' => 'drapeau : Cambodge',
    '🇰🇮' => 'drapeau : Kiribati',
    '🇰🇲' => 'drapeau : Comores',
    '🇰🇳' => 'drapeau : Saint‑Kitts‑et‑Nevis',
    '🇰🇵' => 'drapeau : Corée du Nord',
    '🇰🇷' => 'drapeau : Corée du Sud',
    '🇰🇼' => 'drapeau : Koweït',
    '🇰🇾' => 'drapeau : Îles Caïmans',
    '🇰🇿' => 'drapeau : Kazakhstan',
    '🇱🇦' => 'drapeau : Laos',
    '🇱🇧' => 'drapeau : Liban',
    '🇱🇨' => 'drapeau : Sainte-Lucie',
    '🇱🇮' => 'drapeau : Liechtenstein',
    '🇱🇰' => 'drapeau : Sri Lanka',
    '🇱🇷' => 'drapeau : Libéria',
    '🇱🇸' => 'drapeau : Lesotho',
    '🇱🇹' => 'drapeau : Lituanie',
    '🇱🇺' => 'drapeau : Luxembourg',
    '🇱🇻' => 'drapeau : Lettonie',
    '🇱🇾' => 'drapeau : Libye',
    '🇲🇦' => 'drapeau : Maroc',
    '🇲🇨' => 'drapeau : Monaco',
    '🇲🇩' => 'drapeau : Moldavie',
    '🇲🇪' => 'drapeau : Monténégro',
    '🇲🇫' => 'drapeau : Saint-Martin (France)',
    '🇲🇬' => 'drapeau : Madagascar',
    '🇲🇭' => 'drapeau : Îles Marshall',
    '🇲🇰' => 'drapeau : Macédoine du Nord',
    '🇲🇱' => 'drapeau : Mali',
    '🇲🇲' => 'drapeau : Myanmar',
    '🇲🇳' => 'drapeau : Mongolie',
    '🇲🇴' => 'drapeau : R.A.S. chinoise de Macao',
    '🇲🇵' => 'drapeau : Mariannes du Nord',
    '🇲🇶' => 'drapeau : Martinique',
    '🇲🇷' => 'drapeau : Mauritanie',
    '🇲🇸' => 'drapeau : Montserrat',
    '🇲🇹' => 'drapeau : Malte',
    '🇲🇺' => 'drapeau : Maurice',
    '🇲🇻' => 'drapeau : Maldives',
    '🇲🇼' => 'drapeau : Malawi',
    '🇲🇽' => 'drapeau : Mexique',
    '🇲🇾' => 'drapeau : Malaisie',
    '🇲🇿' => 'drapeau : Mozambique',
    '🇳🇦' => 'drapeau : Namibie',
    '🇳🇨' => 'drapeau : Nouvelle-Calédonie',
    '🇳🇪' => 'drapeau : Niger',
    '🇳🇫' => 'drapeau : île Norfolk',
    '🇳🇬' => 'drapeau : Nigéria',
    '🇳🇮' => 'drapeau : Nicaragua',
    '🇳🇱' => 'drapeau : Pays-Bas',
    '🇳🇴' => 'drapeau : Norvège',
    '🇳🇵' => 'drapeau : Népal',
    '🇳🇷' => 'drapeau : Nauru',
    '🇳🇺' => 'drapeau : Niue',
    '🇳🇿' => 'drapeau : Nouvelle-Zélande',
    '🇴🇲' => 'drapeau : Oman',
    '🇵🇦' => 'drapeau : Panama',
    '🇵🇪' => 'drapeau : Pérou',
    '🇵🇫' => 'drapeau : Polynésie française',
    '🇵🇬' => 'drapeau : Papouasie-Nouvelle-Guinée',
    '🇵🇭' => 'drapeau : Philippines',
    '🇵🇰' => 'drapeau : Pakistan',
    '🇵🇱' => 'drapeau : Pologne',
    '🇵🇲' => 'drapeau : Saint-Pierre-et-Miquelon',
    '🇵🇳' => 'drapeau : îles Pitcairn',
    '🇵🇷' => 'drapeau : Porto Rico',
    '🇵🇸' => 'drapeau : Territoires palestiniens',
    '🇵🇹' => 'drapeau : Portugal',
    '🇵🇼' => 'drapeau : Palaos',
    '🇵🇾' => 'drapeau : Paraguay',
    '🇶🇦' => 'drapeau : Qatar',
    '🇷🇪' => 'drapeau : la Réunion',
    '🇷🇴' => 'drapeau : Roumanie',
    '🇷🇸' => 'drapeau : Serbie',
    '🇷🇺' => 'drapeau : Russie',
    '🇷🇼' => 'drapeau : Rwanda',
    '🇸🇦' => 'drapeau : Arabie saoudite',
    '🇸🇧' => 'drapeau : Îles Salomon',
    '🇸🇨' => 'drapeau : Seychelles',
    '🇸🇩' => 'drapeau : Soudan',
    '🇸🇪' => 'drapeau : Suède',
    '🇸🇬' => 'drapeau : Singapour',
    '🇸🇭' => 'drapeau : Sainte-Hélène',
    '🇸🇮' => 'drapeau : Slovénie',
    '🇸🇯' => 'drapeau : Svalbard et Jan Mayen',
    '🇸🇰' => 'drapeau : Slovaquie',
    '🇸🇱' => 'drapeau : Sierra Leone',
    '🇸🇲' => 'drapeau : Saint-Marin',
    '🇸🇳' => 'drapeau : Sénégal',
    '🇸🇴' => 'drapeau : Somalie',
    '🇸🇷' => 'drapeau : Suriname',
    '🇸🇸' => 'drapeau : Soudan du Sud',
    '🇸🇹' => 'drapeau : Sao Tomé-et-Principe',
    '🇸🇻' => 'drapeau : Salvador',
    '🇸🇽' => 'drapeau : Saint-Martin (Pays-Bas)',
    '🇸🇾' => 'drapeau : Syrie',
    '🇸🇿' => 'drapeau : Eswatini',
    '🇹🇦' => 'drapeau : Tristan da Cunha',
    '🇹🇨' => 'drapeau : Îles Turques-et-Caïques',
    '🇹🇩' => 'drapeau : Tchad',
    '🇹🇫' => 'drapeau : Terres australes françaises',
    '🇹🇬' => 'drapeau : Togo',
    '🇹🇭' => 'drapeau : Thaïlande',
    '🇹🇯' => 'drapeau : Tadjikistan',
    '🇹🇰' => 'drapeau : Tokelau',
    '🇹🇱' => 'drapeau : Timor-Leste',
    '🇹🇲' => 'drapeau : Turkménistan',
    '🇹🇳' => 'drapeau : Tunisie',
    '🇹🇴' => 'drapeau : Tonga',
    '🇹🇷' => 'drapeau : Turquie',
    '🇹🇹' => 'drapeau : Trinité-et-Tobago',
    '🇹🇻' => 'drapeau : Tuvalu',
    '🇹🇼' => 'drapeau : Taïwan',
    '🇹🇿' => 'drapeau : Tanzanie',
    '🇺🇦' => 'drapeau : Ukraine',
    '🇺🇬' => 'drapeau : Ouganda',
    '🇺🇲' => 'drapeau : îles mineures éloignées des États-Unis',
    '🇺🇳' => 'drapeau : Nations Unies',
    '🇺🇸' => 'drapeau : États-Unis',
    '🇺🇾' => 'drapeau : Uruguay',
    '🇺🇿' => 'drapeau : Ouzbékistan',
    '🇻🇦' => 'drapeau : Cité du Vatican',
    '🇻🇨' => 'drapeau : Saint-Vincent-et-les Grenadines',
    '🇻🇪' => 'drapeau : Vénézuéla',
    '🇻🇬' => 'drapeau : îles Vierges britanniques',
    '🇻🇮' => 'drapeau : îles Vierges américaines',
    '🇻🇳' => 'drapeau : Vietnam',
    '🇻🇺' => 'drapeau : Vanuatu',
    '🇼🇫' => 'drapeau : Wallis-et-Futuna',
    '🇼🇸' => 'drapeau : Samoa',
    '🇽🇰' => 'drapeau : Kosovo',
    '🇾🇪' => 'drapeau : Yémen',
    '🇾🇹' => 'drapeau : Mayotte',
    '🇿🇦' => 'drapeau : Afrique du Sud',
    '🇿🇲' => 'drapeau : Zambie',
    '🇿🇼' => 'drapeau : Zimbabwe',
    '🔟' => 'dessus de touche : 10',
    '🏻' => 'peau claire',
    '🏼' => 'peau modérément claire',
    '🏽' => 'peau légèrement mate',
    '🏾' => 'peau modérément foncée',
    '🏿' => 'peau foncée',
    '😀' => 'visage avec large sourire',
    '😃' => 'visage souriant les yeux grands ouverts',
    '😄' => 'visage avec large sourire et yeux rieurs',
    '😁' => 'visage radieux et yeux rieurs',
    '😆' => 'visage avec large sourire, les yeux fermés',
    '😅' => 'visage souriant avec une goutte de sueur',
    '🤣' => 'rire à se rouler par terre',
    '😂' => 'visage pleurant de joie',
    '🙂' => 'visage avec un léger sourire',
    '🙃' => 'visage à l’envers',
    '🫠' => 'visage qui fond',
    '😉' => 'visage clignant d’un œil',
    '😊' => 'visage souriant les yeux plissés',
    '😇' => 'visage qui sourit avec une auréole',
    '🥰' => 'visage souriant avec cœurs',
    '😍' => 'visage souriant aux yeux en forme de cœur',
    '🤩' => 'visage aux yeux en forme d’étoiles',
    '😘' => 'visage envoyant un baiser',
    '😗' => 'visage donnant un baiser',
    '☺' => 'visage souriant',
    '😚' => 'visage faisant un baiser les yeux fermés',
    '😙' => 'visage faisant un baiser les yeux rieurs',
    '🥲' => 'visage souriant avec larme',
    '😋' => 'visage savourant',
    '😛' => 'visage qui tire la langue',
    '😜' => 'visage qui tire la langue et fait un clin d’œil',
    '🤪' => 'tête de fou',
    '😝' => 'visage qui tire la langue les yeux plissés',
    '🤑' => 'argent dans les yeux et la bouche',
    '🤗' => 'visage heureux et câlin',
    '🤭' => 'visage avec une main sur la bouche',
    '🫢' => 'visage avec yeux ouverts et main sur la bouche',
    '🫣' => 'visage qui regarde entre ses doigts',
    '🤫' => 'visage avec un doigt sur la bouche',
    '🤔' => 'visage en pleine réflexion',
    '🫡' => 'visage qui fait un salut militaire',
    '🤐' => 'visage avec bouche fermeture éclair',
    '🤨' => 'visage avec les sourcils relevés',
    '😐' => 'visage neutre',
    '😑' => 'visage sans expression',
    '😶' => 'visage sans bouche',
    '🫥' => 'visage en pointillés',
    '😏' => 'visage au sourire malin',
    '😒' => 'visage désabusé',
    '🙄' => 'visage qui roule des yeux',
    '😬' => 'visage grimaçant',
    '🤥' => 'visage de menteur',
    '🫨' => 'visage secoué',
    '😌' => 'visage soulagé',
    '😔' => 'visage pensif',
    '😪' => 'visage endormi',
    '🤤' => 'visage qui bave',
    '😴' => 'visage somnolent',
    '🫩' => 'visage avec des cernes sous les yeux',
    '😷' => 'visage avec masque',
    '🤒' => 'visage avec thermomètre',
    '🤕' => 'visage bandé',
    '🤢' => 'visage écœuré',
    '🤮' => 'visage qui vomit',
    '🤧' => 'visage qui éternue',
    '🥵' => 'visage rouge et chaud',
    '🥶' => 'visage bleu et froid',
    '🥴' => 'visage abruti',
    '😵' => 'visage inconscient',
    '🤯' => 'tête qui explose',
    '🤠' => 'visage avec chapeau de cowboy',
    '🥳' => 'visage festif',
    '🥸' => 'visage déguisé',
    '😎' => 'visage souriant avec des lunettes de soleil',
    '🤓' => 'visage de tronche',
    '🧐' => 'visage avec un monocle',
    '😕' => 'visage confus',
    '🫤' => 'visage avec bouche en diagonale',
    '😟' => 'visage inquiet',
    '🙁' => 'visage légèrement mécontent',
    '☹' => 'visage mécontent',
    '😮' => 'visage épaté',
    '😯' => 'visage ébahi',
    '😲' => 'visage stupéfait',
    '😳' => 'visage qui rougit',
    '🫪' => 'visage déformé',
    '🥺' => 'visage implorant',
    '🥹' => 'visage retenant ses larmes',
    '😦' => 'visage mécontent avec bouche ouverte',
    '😧' => 'visage angoissé',
    '😨' => 'visage effrayé',
    '😰' => 'visage inquiet et en sueur',
    '😥' => 'visage triste mais soulagé',
    '😢' => 'visage qui pleure',
    '😭' => 'visage qui pleure à chaudes larmes',
    '😱' => 'visage qui hurle de peur',
    '😖' => 'visage déconcerté',
    '😣' => 'visage persévérant',
    '😞' => 'visage déçu',
    '😓' => 'visage triste et en sueur',
    '😩' => 'visage épuisé',
    '😫' => 'visage fatigué',
    '🥱' => 'visage bâillant',
    '😤' => 'visage avec fumée sortant des narines',
    '😡' => 'visage boudeur',
    '😠' => 'visage en colère',
    '🤬' => 'visage avec des symboles dans la bouche',
    '😈' => 'visage souriant avec des cornes',
    '👿' => 'visage en colère avec des cornes',
    '💀' => 'crâne',
    '☠' => 'tête de mort',
    '💩' => 'tas de crotte',
    '🤡' => 'visage de clown',
    '👹' => 'ogre',
    '👺' => 'gobelin',
    '👻' => 'fantôme',
    '👽' => 'extraterrestre',
    '👾' => 'monstre de l’espace',
    '🤖' => 'robot',
    '😺' => 'chat qui sourit',
    '😸' => 'chat qui sourit avec des yeux rieurs',
    '😹' => 'chat qui pleure de joie',
    '😻' => 'chat souriant aux yeux en cœurs',
    '😼' => 'chat avec sourire en coin',
    '😽' => 'chat qui fait un bisou',
    '🙀' => 'chat fatigué',
    '😿' => 'chat qui pleure',
    '😾' => 'chat qui boude',
    '🙈' => 'singe ne rien voir',
    '🙉' => 'singe ne rien entendre',
    '🙊' => 'singe ne rien dire',
    '💌' => 'lettre d’amour',
    '💘' => 'cœur et flèche',
    '💝' => 'cœur avec ruban',
    '💖' => 'cœur étincelant',
    '💗' => 'cœur grandissant',
    '💓' => 'cœur battant',
    '💞' => 'cœurs qui tournent',
    '💕' => 'deux cœurs',
    '💟' => 'décoration avec cœur',
    '❣' => 'cœur point d’exclamation',
    '💔' => 'cœur brisé',
    '❤' => 'cœur rouge',
    '🩷' => 'cœur rose',
    '🧡' => 'cœur orange',
    '💛' => 'cœur jaune',
    '💚' => 'cœur vert',
    '💙' => 'cœur bleu',
    '🩵' => 'cœur bleu clair',
    '💜' => 'cœur violet',
    '🤎' => 'cœur brun',
    '🖤' => 'cœur noir',
    '🩶' => 'cœur gris',
    '🤍' => 'cœur blanc',
    '💋' => 'trace de rouge à lèvres',
    '💯' => 'cent points',
    '💢' => 'symbole de colère',
    '🫯' => 'nuage de colère',
    '💥' => 'explosion',
    '💫' => 'étourdissement',
    '💦' => 'gouttes de sueur',
    '💨' => 'décamper',
    '🕳' => 'trou',
    '💬' => 'bulle de parole',
    '🗨' => 'bulle de parole à gauche',
    '🗯' => 'bulle de colère à droite',
    '💭' => 'bulle de pensée',
    '💤' => 'endormi',
    '👋' => 'signe de la main',
    '🤚' => 'dos de main levée',
    '🖐' => 'main aux doigts écartés',
    '✋' => 'main levée',
    '🖖' => 'salut vulcain',
    '🫱' => 'main vers la droite',
    '🫲' => 'main vers la gauche',
    '🫳' => 'main paume vers le bas',
    '🫴' => 'main paume vers le haut',
    '🫷' => 'main qui pousse vers la gauche',
    '🫸' => 'main qui pousse vers la droite',
    '👌' => 'ok',
    '🤌' => 'main qui interroge',
    '🤏' => 'pouce et index rapprochés',
    '✌' => 'V de la victoire',
    '🤞' => 'doigts croisés',
    '🫰' => 'main avec index et pouce croisés',
    '🤟' => 'signe je t’aime',
    '🤘' => 'cornes avec les doigts',
    '🤙' => 'appelle-moi',
    '👈' => 'main avec index pointant à gauche',
    '👉' => 'main avec index pointant à droite',
    '👆' => 'main avec index pointant vers le haut',
    '🖕' => 'doigt d’honneur',
    '👇' => 'main avec index pointant vers le bas',
    '☝' => 'index pointant vers le haut',
    '🫵' => 'index pointant vers l’utilisateur',
    '👍' => 'pouce vers le haut',
    '👎' => 'pouce vers le bas',
    '✊' => 'poing levé',
    '👊' => 'poing de face',
    '🤛' => 'poing à gauche',
    '🤜' => 'poing à droite',
    '👏' => 'applaudissements',
    '🙌' => 'mains levées',
    '🫶' => 'mains qui forment un cœur',
    '👐' => 'mains ouvertes',
    '🤲' => 'paume contre paume doigts vers le haut',
    '🤝' => 'poignée de main',
    '🙏' => 'mains en prière',
    '✍' => 'main qui écrit',
    '💅' => 'vernis à ongles',
    '🤳' => 'égoportrait',
    '💪' => 'biceps contracté',
    '🦾' => 'bras mécanique',
    '🦿' => 'jambe mécanique',
    '🦵' => 'jambe',
    '🦶' => 'pied',
    '👂' => 'oreille',
    '🦻' => 'oreille appareillée',
    '👃' => 'nez',
    '🧠' => 'cerveau',
    '🫀' => 'cœur',
    '🫁' => 'poumons',
    '🦷' => 'dent',
    '🦴' => 'os',
    '👀' => 'yeux',
    '👁' => 'œil',
    '👅' => 'langue',
    '👄' => 'bouche',
    '🫦' => 'lèvres qui se mordent',
    '👶' => 'bébé',
    '🧒' => 'enfant',
    '👦' => 'garçon',
    '👧' => 'fille',
    '🧑' => 'adulte',
    '👱' => 'personne blonde',
    '👨' => 'homme',
    '🧔' => 'personne barbue',
    '👩' => 'femme',
    '🧓' => 'personne âgée',
    '👴' => 'homme âgé',
    '👵' => 'femme âgée',
    '🙍' => 'personne mécontente',
    '🙎' => 'personne qui boude',
    '🙅' => 'personne faisant un geste d’interdiction',
    '🙆' => 'geste d’affirmation',
    '💁' => 'personne paume vers le haut',
    '🙋' => 'personne qui lève la main',
    '🧏' => 'personne sourde',
    '🙇' => 'personne qui s’incline',
    '🤦' => 'personne avec la paume sur le visage',
    '🤷' => 'personne qui hausse les épaules',
    '👮' => 'policier',
    '🕵' => 'détective',
    '💂' => 'garde',
    '🥷' => 'ninja',
    '👷' => 'personnel du bâtiment',
    '🫅' => 'personne avec une couronne',
    '🤴' => 'prince',
    '👸' => 'princesse',
    '👳' => 'personne en turban',
    '👲' => 'personne coiffée d’une calotte chinoise',
    '🧕' => 'femme avec foulard',
    '🤵' => 'personne en smoking',
    '👰' => 'personne avec voile',
    '🤰' => 'femme enceinte',
    '🫃' => 'homme enceint',
    '🫄' => 'personne enceinte',
    '🤱' => 'allaitement',
    '👼' => 'bébé ange',
    '🎅' => 'père Noël',
    '🤶' => 'mère Noël',
    '🦸' => 'superhéros',
    '🦹' => 'super-vilain',
    '🧙' => 'mage',
    '🧚' => 'personnage féérique',
    '🧛' => 'vampire',
    '🧜' => 'créature aquatique',
    '🧝' => 'elfe',
    '🧞' => 'génie',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'créature velue',
    '💆' => 'personne qui se fait masser',
    '💇' => 'personne qui se fait couper les cheveux',
    '🚶' => 'personne qui marche',
    '🧍' => 'personne debout',
    '🧎' => 'personne à genoux',
    '🏃' => 'personne qui court',
    '💃' => 'danseuse',
    '🕺' => 'danseur',
    '🕴' => 'homme d’affaires en lévitation',
    '👯' => 'personnes qui portent des oreilles de lapin',
    '🧖' => 'personne dans un bain de vapeur',
    '🧗' => 'personne qui grimpe',
    '🤺' => 'escrimeur',
    '🏇' => 'course hippique',
    '⛷' => 'skieur',
    '🏂' => 'planchiste',
    '🏌' => 'joueur de golf',
    '🏄' => 'personne qui fait du surf',
    '🚣' => 'personne qui rame dans une barque',
    '🏊' => 'personne qui nage',
    '⛹' => 'personne qui fait rebondir un ballon',
    '🏋' => 'haltérophile',
    '🚴' => 'cycliste',
    '🚵' => 'personne en vélo de montagne',
    '🤸' => 'personne faisant la roue',
    '🤼' => 'personnes faisant de la lutte',
    '🤽' => 'personne qui joue au water-polo',
    '🤾' => 'personne qui joue au handball',
    '🤹' => 'personne qui jongle',
    '🧘' => 'personne dans la posture du lotus',
    '🛀' => 'personne prenant un bain',
    '🛌' => 'personne au lit',
    '👭' => 'deux femmes se tenant par la main',
    '👫' => 'homme et femme se tenant par la main',
    '👬' => 'deux hommes se tenant par la main',
    '💏' => 'bisou',
    '💑' => 'couple avec cœur',
    '🗣' => 'tête qui parle',
    '👤' => 'silhouette de buste',
    '👥' => 'silhouettes de bustes',
    '🫂' => 'personnes qui s’étreignent',
    '👪' => 'famille',
    '👣' => 'traces de pas',
    '🫆' => 'empreinte digitale',
    '🦰' => 'cheveux roux',
    '🦱' => 'cheveux bouclés',
    '🦳' => 'cheveux blancs',
    '🦲' => 'chauve',
    '🐵' => 'tête de singe',
    '🐒' => 'singe',
    '🦍' => 'gorille',
    '🦧' => 'orang-outan',
    '🐶' => 'tête de chien',
    '🐕' => 'chien',
    '🦮' => 'chien-guide',
    '🐩' => 'caniche',
    '🐺' => 'loup',
    '🦊' => 'renard',
    '🦝' => 'raton laveur',
    '🐱' => 'tête de chat',
    '🐈' => 'chat',
    '🦁' => 'tête de lion',
    '🐯' => 'tête de tigre',
    '🐅' => 'tigre',
    '🐆' => 'léopard',
    '🐴' => 'tête de cheval',
    '🫎' => 'orignal',
    '🫏' => 'âne',
    '🐎' => 'cheval',
    '🦄' => 'licorne',
    '🦓' => 'zèbre',
    '🦌' => 'cerf',
    '🦬' => 'bison',
    '🐮' => 'tête de vache',
    '🐂' => 'bœuf',
    '🐃' => 'buffle',
    '🐄' => 'vache',
    '🐷' => 'tête de cochon',
    '🐖' => 'cochon',
    '🐗' => 'sanglier',
    '🐽' => 'nez de cochon',
    '🐏' => 'bélier',
    '🐑' => 'brebis',
    '🐐' => 'chèvre',
    '🐪' => 'dromadaire',
    '🐫' => 'chameau',
    '🦙' => 'lama',
    '🦒' => 'girafe',
    '🐘' => 'éléphant',
    '🦣' => 'mammouth',
    '🦏' => 'rhinocéros',
    '🦛' => 'hippopotame',
    '🐭' => 'tête de souris',
    '🐁' => 'souris',
    '🐀' => 'rat',
    '🐹' => 'hamster',
    '🐰' => 'tête de lapin',
    '🐇' => 'lapin',
    '🐿' => 'écureuil',
    '🦫' => 'castor',
    '🦔' => 'hérisson',
    '🦇' => 'chauve-souris',
    '🐻' => 'ours',
    '🐨' => 'koala',
    '🐼' => 'tête de panda',
    '🦥' => 'paresseux',
    '🦦' => 'loutre',
    '🦨' => 'mouffette',
    '🦘' => 'kangourou',
    '🦡' => 'blaireau',
    '🐾' => 'empreintes d’animaux',
    '🦃' => 'dinde',
    '🐔' => 'poule',
    '🐓' => 'coq',
    '🐣' => 'poussin qui éclôt',
    '🐤' => 'poussin',
    '🐥' => 'poussin de face',
    '🐦' => 'oiseau',
    '🐧' => 'pingouin',
    '🕊' => 'colombe',
    '🦅' => 'aigle',
    '🦆' => 'canard',
    '🦢' => 'cygne',
    '🦉' => 'chouette',
    '🦤' => 'dodo',
    '🪶' => 'plume',
    '🦩' => 'flamant',
    '🦚' => 'paon',
    '🦜' => 'perroquet',
    '🪽' => 'aile',
    '🪿' => 'oie',
    '🐸' => 'grenouille',
    '🐊' => 'crocodile',
    '🐢' => 'tortue',
    '🦎' => 'lézard',
    '🐍' => 'serpent',
    '🐲' => 'tête de dragon',
    '🐉' => 'dragon',
    '🦕' => 'sauropode',
    '🦖' => 'T. rex',
    '🐳' => 'baleine qui expulse de l’eau',
    '🐋' => 'baleine',
    '🐬' => 'dauphin',
    '🫍' => 'orque',
    '🦭' => 'phoque',
    '🐟' => 'poisson',
    '🐠' => 'poisson tropical',
    '🐡' => 'poisson-globe',
    '🦈' => 'requin',
    '🐙' => 'pieuvre',
    '🐚' => 'coquille en spirale',
    '🪸' => 'corail',
    '🪼' => 'méduse',
    '🦀' => 'crabe',
    '🦞' => 'homard',
    '🦐' => 'crevette',
    '🦑' => 'calamar',
    '🦪' => 'huître',
    '🐌' => 'escargot',
    '🦋' => 'papillon',
    '🐛' => 'chenille',
    '🐜' => 'fourmi',
    '🐝' => 'abeille',
    '🪲' => 'scarabée',
    '🐞' => 'coccinelle',
    '🦗' => 'criquet',
    '🪳' => 'coquerelle',
    '🕷' => 'araignée',
    '🕸' => 'toile d’araignée',
    '🦂' => 'scorpion',
    '🦟' => 'moustique',
    '🪰' => 'mouche',
    '🪱' => 'ver',
    '🦠' => 'microbe',
    '💐' => 'bouquet',
    '🌸' => 'fleur de cerisier',
    '💮' => 'fleur blanche',
    '🪷' => 'lotus',
    '🏵' => 'rosette',
    '🌹' => 'rose',
    '🥀' => 'fleur fanée',
    '🌺' => 'hibiscus',
    '🌻' => 'tournesol',
    '🌼' => 'bourgeon',
    '🌷' => 'tulipe',
    '🪻' => 'jacinthe',
    '🌱' => 'jeune pousse',
    '🪴' => 'plante en pot',
    '🌲' => 'conifère',
    '🌳' => 'arbre à feuilles caduques',
    '🌴' => 'palmier',
    '🌵' => 'cactus',
    '🌾' => 'plant de riz',
    '🌿' => 'feuille',
    '☘' => 'trèfle à trois feuilles',
    '🍀' => 'trèfle à quatre feuilles',
    '🍁' => 'feuille d’érable',
    '🍂' => 'feuille morte',
    '🍃' => 'feuille virevoltante',
    '🪹' => 'nid vide',
    '🪺' => 'nid avec œufs',
    '🍄' => 'champignon',
    '🪾' => 'arbre sans feuille',
    '🍇' => 'raisin',
    '🍈' => 'melon',
    '🍉' => 'melon d’eau',
    '🍊' => 'tangerine',
    '🍋' => 'citron',
    '🍌' => 'banane',
    '🍍' => 'ananas',
    '🥭' => 'mangue',
    '🍎' => 'pomme rouge',
    '🍏' => 'pomme verte',
    '🍐' => 'poire',
    '🍑' => 'pêche',
    '🍒' => 'cerises',
    '🍓' => 'fraise',
    '🫐' => 'bleuets',
    '🥝' => 'kiwi',
    '🍅' => 'tomate',
    '🫒' => 'olive',
    '🥥' => 'noix de coco',
    '🥑' => 'avocat',
    '🍆' => 'aubergine',
    '🥔' => 'pomme de terre',
    '🥕' => 'carotte',
    '🌽' => 'épi de maïs',
    '🌶' => 'piment rouge',
    '🫑' => 'poivron rouge',
    '🥒' => 'concombre',
    '🥬' => 'légume à feuilles vertes',
    '🥦' => 'brocoli',
    '🧄' => 'ail',
    '🧅' => 'oignon',
    '🥜' => 'arachides',
    '🫘' => 'fèves',
    '🌰' => 'châtaigne',
    '🫚' => 'racine de gingembre',
    '🫛' => 'cosse de petits pois',
    '🫜' => 'légume-racine',
    '🍞' => 'pain',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'pain plat',
    '🥨' => 'bretzel',
    '🥯' => 'bagel',
    '🥞' => 'crêpes',
    '🧇' => 'gaufre',
    '🧀' => 'morceau de fromage',
    '🍖' => 'viande sur son os',
    '🍗' => 'cuisse de poulet',
    '🥩' => 'morceau de viande',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'frites',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'pain plat garni',
    '🧆' => 'falafels',
    '🥚' => 'œuf',
    '🍳' => 'cuisine',
    '🥘' => 'plat mitonné',
    '🍲' => 'bol de nourriture',
    '🫕' => 'fondue',
    '🥣' => 'bol avec cuillère',
    '🥗' => 'salade verte',
    '🍿' => 'popcorn',
    '🧈' => 'beurre',
    '🧂' => 'sel',
    '🥫' => 'aliments en conserve',
    '🍱' => 'boîte à bento',
    '🍘' => 'craquelin de riz',
    '🍙' => 'boulette de riz',
    '🍚' => 'bol de riz',
    '🍛' => 'riz au curry',
    '🍜' => 'bol fumant',
    '🍝' => 'spaghetti',
    '🍠' => 'patate douce grillée',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'crevette frite',
    '🍥' => 'surimi avec décoration',
    '🥮' => 'gâteau de lune',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'biscuit chinois',
    '🥡' => 'boîte à emporter',
    '🍦' => 'crème glacée molle',
    '🍧' => 'glace pilée',
    '🍨' => 'crème glacée',
    '🍩' => 'beigne',
    '🍪' => 'biscuit',
    '🎂' => 'gâteau de fête',
    '🍰' => 'gâteau sablé',
    '🧁' => 'petit gâteau',
    '🥧' => 'tarte',
    '🍫' => 'tablette de chocolat',
    '🍬' => 'bonbon',
    '🍭' => 'suçon',
    '🍮' => 'crème caramel',
    '🍯' => 'pot de miel',
    '🍼' => 'biberon',
    '🥛' => 'verre de lait',
    '☕' => 'boisson chaude',
    '🫖' => 'théière',
    '🍵' => 'tasse',
    '🍶' => 'saké',
    '🍾' => 'bouteille de champagne',
    '🍷' => 'verre de vin',
    '🍸' => 'verre à cocktail',
    '🍹' => 'cocktail tropical',
    '🍺' => 'chope de bière',
    '🍻' => 'chopes de bière qui tintent',
    '🥂' => 'verres qui tintent',
    '🥃' => 'verre',
    '🫗' => 'verser un liquide',
    '🥤' => 'verre avec paille',
    '🧋' => 'thé aux perles',
    '🧃' => 'boîte à boire',
    '🧉' => 'maté',
    '🧊' => 'glaçon',
    '🥢' => 'baguettes',
    '🍽' => 'fourchette et couteau avec assiette',
    '🍴' => 'fourchette et couteau',
    '🥄' => 'cuillère',
    '🔪' => 'couteau de cuisine',
    '🫙' => 'bocal',
    '🏺' => 'amphore',
    '🌍' => 'globe qui montre l’Europe et l’Afrique',
    '🌎' => 'globe qui montre l’Amérique',
    '🌏' => 'globe qui montre l’Asie et l’Australie',
    '🌐' => 'globe qui montre les méridiens',
    '🗺' => 'carte du monde',
    '🗾' => 'carte du Japon',
    '🧭' => 'boussole',
    '🏔' => 'montagne enneigée',
    '⛰' => 'montagne',
    '🛘' => 'éboulement',
    '🌋' => 'volcan',
    '🗻' => 'mont Fuji',
    '🏕' => 'camping',
    '🏖' => 'plage et parasol',
    '🏜' => 'désert',
    '🏝' => 'île déserte',
    '🏞' => 'parc national',
    '🏟' => 'stade',
    '🏛' => 'monument classique',
    '🏗' => 'construction d’un bâtiment',
    '🧱' => 'brique',
    '🪨' => 'roche',
    '🪵' => 'bois',
    '🛖' => 'hutte',
    '🏘' => 'maisons',
    '🏚' => 'maison abandonnée',
    '🏠' => 'maison',
    '🏡' => 'maison avec jardin',
    '🏢' => 'immeuble de bureaux',
    '🏣' => 'bureau de poste japonais',
    '🏤' => 'bureau de poste',
    '🏥' => 'hôpital',
    '🏦' => 'banque',
    '🏨' => 'hôtel',
    '🏩' => 'hôtel pour couples',
    '🏪' => 'épicerie',
    '🏫' => 'école',
    '🏬' => 'grand magasin',
    '🏭' => 'usine',
    '🏯' => 'château japonais',
    '🏰' => 'château',
    '💒' => 'mariage',
    '🗼' => 'tour de Tokyo',
    '🗽' => 'statue de la Liberté',
    '⛪' => 'église',
    '🕌' => 'mosquée',
    '🛕' => 'temple hindou',
    '🕍' => 'synagogue',
    '⛩' => 'sanctuaire shinto',
    '🕋' => 'kaaba',
    '⛲' => 'fontaine',
    '⛺' => 'tente',
    '🌁' => 'brume',
    '🌃' => 'nuit étoilée',
    '🏙' => 'paysage urbain',
    '🌄' => 'lever de soleil sur les montagnes',
    '🌅' => 'lever de soleil',
    '🌆' => 'ville au crépuscule',
    '🌇' => 'coucher de soleil',
    '🌉' => 'pont de nuit',
    '♨' => 'sources thermales',
    '🎠' => 'cheval de carrousel',
    '🛝' => 'glissade',
    '🎡' => 'grande roue',
    '🎢' => 'montagnes russes',
    '💈' => 'enseigne de barbier',
    '🎪' => 'chapiteau',
    '🚂' => 'locomotive',
    '🚃' => 'wagon',
    '🚄' => 'train à grande vitesse',
    '🚅' => 'train superexpress',
    '🚆' => 'train',
    '🚇' => 'métro',
    '🚈' => 'train de banlieue',
    '🚉' => 'gare',
    '🚊' => 'tramway',
    '🚝' => 'monorail',
    '🚞' => 'train de montagne',
    '🚋' => 'wagon de tramway',
    '🚌' => 'bus',
    '🚍' => 'bus de face',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulance',
    '🚒' => 'camion de pompier',
    '🚓' => 'voiture de police',
    '🚔' => 'voiture de police de face',
    '🚕' => 'taxi',
    '🚖' => 'taxi de face',
    '🚗' => 'voiture',
    '🚘' => 'voiture de face',
    '🚙' => 'véhicule utilitaire sport',
    '🛻' => 'camionnette',
    '🚚' => 'camion de livraison',
    '🚛' => 'camion semi-remorque',
    '🚜' => 'tracteur',
    '🏎' => 'voiture de course',
    '🏍' => 'moto',
    '🛵' => 'scooter',
    '🦽' => 'fauteuil roulant manuel',
    '🦼' => 'fauteuil motorisé',
    '🛺' => 'tuk tuk',
    '🚲' => 'vélo',
    '🛴' => 'trottinette',
    '🛹' => 'planche à roulettes',
    '🛼' => 'patin à roulettes',
    '🚏' => 'arrêt de bus',
    '🛣' => 'autoroute',
    '🛤' => 'voie ferrée',
    '🛢' => 'baril de pétrole',
    '⛽' => 'pompe à essence',
    '🛞' => 'roue',
    '🚨' => 'gyrophare',
    '🚥' => 'feu de circulation horizontal',
    '🚦' => 'feu de circulation vertical',
    '🛑' => 'stop',
    '🚧' => 'travaux',
    '⚓' => 'ancre',
    '🛟' => 'bouée de sauvetage',
    '⛵' => 'voilier',
    '🛶' => 'canoë',
    '🚤' => 'hors-bord',
    '🛳' => 'paquebot',
    '⛴' => 'traversier',
    '🛥' => 'bateau à moteur',
    '🚢' => 'navire',
    '✈' => 'avion',
    '🛩' => 'petit avion',
    '🛫' => 'avion au décollage',
    '🛬' => 'avion à l’atterissage',
    '🪂' => 'parachute',
    '💺' => 'siège',
    '🚁' => 'hélicoptère',
    '🚟' => 'train suspendu',
    '🚠' => 'télécabine',
    '🚡' => 'téléphérique',
    '🛰' => 'satellite',
    '🚀' => 'fusée',
    '🛸' => 'soucoupe volante',
    '🛎' => 'cloche de comptoir',
    '🧳' => 'bagage',
    '⌛' => 'sablier',
    '⏳' => 'sablier avec sable qui coule',
    '⌚' => 'montre',
    '⏰' => 'réveil',
    '⏱' => 'chronomètre',
    '⏲' => 'minuterie',
    '🕰' => 'pendule de cheminée',
    '🕛' => 'midi/minuit',
    '🕧' => 'midi/minuit et demie',
    '🕐' => 'une heure',
    '🕜' => 'une heure et demie',
    '🕑' => 'deux heures',
    '🕝' => 'deux heures et demie',
    '🕒' => 'trois heures',
    '🕞' => 'trois heures et demie',
    '🕓' => 'quatre heures',
    '🕟' => 'quatre heures et demie',
    '🕔' => 'cinq heures',
    '🕠' => 'cinq heures et demie',
    '🕕' => 'six heures',
    '🕡' => 'six heures et demie',
    '🕖' => 'sept heures',
    '🕢' => 'sept heures et demie',
    '🕗' => 'huit heures',
    '🕣' => 'huit heures et demie',
    '🕘' => 'neuf heures',
    '🕤' => 'neuf heures et demie',
    '🕙' => 'dix heures',
    '🕥' => 'dix heures et demie',
    '🕚' => 'onze heures',
    '🕦' => 'onze heures et demie',
    '🌑' => 'nouvelle lune',
    '🌒' => 'premier croissant de lune',
    '🌓' => 'premier quartier de lune',
    '🌔' => 'lune gibbeuse croissante',
    '🌕' => 'pleine lune',
    '🌖' => 'lune gibbeuse décroissante',
    '🌗' => 'dernier quartier de lune',
    '🌘' => 'dernier croissant de lune',
    '🌙' => 'croissant de lune',
    '🌚' => 'nouvelle lune avec visage',
    '🌛' => 'premier quartier de lune avec visage',
    '🌜' => 'dernier quartier de lune avec visage',
    '🌡' => 'thermomètre',
    '☀' => 'soleil',
    '🌝' => 'pleine lune avec visage',
    '🌞' => 'soleil avec visage',
    '🪐' => 'planète à anneaux',
    '⭐' => 'étoile moyenne',
    '🌟' => 'étoile brillante',
    '🌠' => 'étoile filante',
    '🌌' => 'voie lactée',
    '☁' => 'nuage',
    '⛅' => 'soleil derrière un nuage',
    '⛈' => 'nuage avec éclair et pluie',
    '🌤' => 'soleil derrière un petit nuage',
    '🌥' => 'soleil derrière un gros nuage',
    '🌦' => 'soleil derrière un nuage de pluie',
    '🌧' => 'nuage de pluie',
    '🌨' => 'nuage avec de la neige',
    '🌩' => 'nuage avec un éclair',
    '🌪' => 'tornade',
    '🌫' => 'brouillard',
    '🌬' => 'visage qui souffle du vent',
    '🌀' => 'cyclone',
    '🌈' => 'arc-en-ciel',
    '🌂' => 'parapluie fermé',
    '☂' => 'parapluie ouvert',
    '☔' => 'parapluie avec gouttes de pluie',
    '⛱' => 'parasol sur le sol',
    '⚡' => 'haute tension',
    '❄' => 'flocon de neige',
    '☃' => 'bonhomme de neige',
    '⛄' => 'bonhomme de neige sans neige',
    '☄' => 'comète',
    '🔥' => 'feu',
    '💧' => 'goutte d’eau',
    '🌊' => 'vague',
    '🎃' => 'citrouille',
    '🎄' => 'sapin de Noël',
    '🎆' => 'feu d’artifice',
    '🎇' => 'feu de Bengale',
    '🧨' => 'pétard',
    '✨' => 'étincelles',
    '🎈' => 'ballon de fête',
    '🎉' => 'cornet à confettis',
    '🎊' => 'boule de confetti',
    '🎋' => 'arbre à prières',
    '🎍' => 'composition florale japonaise',
    '🎎' => 'poupées japonaises',
    '🎏' => 'koinobori',
    '🎐' => 'carillon à vent',
    '🎑' => 'cérémonie d’observation de la lune',
    '🧧' => 'enveloppe rouge',
    '🎀' => 'ruban',
    '🎁' => 'cadeau',
    '🎗' => 'ruban commémoratif',
    '🎟' => 'billets d’entrée',
    '🎫' => 'billet',
    '🎖' => 'médaille militaire',
    '🏆' => 'trophée',
    '🏅' => 'médaille sportive',
    '🥇' => 'médaille d’or',
    '🥈' => 'médaille d’argent',
    '🥉' => 'médaille de bronze',
    '⚽' => 'ballon de soccer',
    '⚾' => 'baseball',
    '🥎' => 'balle molle',
    '🏀' => 'ballon de basket',
    '🏐' => 'ballon de volley',
    '🏈' => 'ballon de football',
    '🏉' => 'ballon de rugby',
    '🎾' => 'tennis',
    '🥏' => 'disque volant',
    '🎳' => 'jeu de quilles',
    '🏏' => 'cricket',
    '🏑' => 'hockey sur gazon',
    '🏒' => 'hockey sur glace',
    '🥍' => 'crosse',
    '🏓' => 'tennis de table',
    '🏸' => 'badminton',
    '🥊' => 'gant de boxe',
    '🥋' => 'uniforme d’arts martiaux',
    '🥅' => 'filet',
    '⛳' => 'drapeau de golf',
    '⛸' => 'patin à glace',
    '🎣' => 'pêche à la ligne',
    '🤿' => 'masque de plongée',
    '🎽' => 'maillot de course',
    '🎿' => 'skis',
    '🛷' => 'luge',
    '🥌' => 'pierre de curling',
    '🎯' => 'dans le mille',
    '🪀' => 'yoyo',
    '🪁' => 'cerf-volant',
    '🔫' => 'pistolet à eau',
    '🎱' => 'boule de billard',
    '🔮' => 'boule de cristal',
    '🪄' => 'baguette magique',
    '🎮' => 'jeu vidéo',
    '🕹' => 'manette de jeu',
    '🎰' => 'machine à sous',
    '🎲' => 'dé',
    '🧩' => 'casse-tête',
    '🧸' => 'ours en peluche',
    '🪅' => 'piñata',
    '🪩' => 'boule à facettes',
    '🪆' => 'poupées russes',
    '♠' => 'pique',
    '♥' => 'cœur cartes',
    '♦' => 'carreau',
    '♣' => 'trèfle',
    '♟' => 'pion',
    '🃏' => 'joker',
    '🀄' => 'dragon rouge mahjong',
    '🎴' => 'jeu des fleurs',
    '🎭' => 'arts du spectacle',
    '🖼' => 'cadre avec image',
    '🎨' => 'palette de peinture',
    '🧵' => 'bobine de fil',
    '🪡' => 'aiguille à coudre',
    '🧶' => 'fil',
    '🪢' => 'nœud',
    '👓' => 'lunettes de vue',
    '🕶' => 'lunettes de soleil',
    '🥽' => 'lunettes',
    '🥼' => 'blouse blanche',
    '🦺' => 'veste de sécurité',
    '👔' => 'cravate',
    '👕' => 'T-shirt',
    '👖' => 'jean',
    '🧣' => 'foulard',
    '🧤' => 'gants',
    '🧥' => 'manteau',
    '🧦' => 'chaussettes',
    '👗' => 'robe',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'maillot de bain une pièce',
    '🩲' => 'slip',
    '🩳' => 'short',
    '👙' => 'bikini',
    '👚' => 'vêtements de femme',
    '🪭' => 'éventail',
    '👛' => 'porte-monnaie',
    '👜' => 'sac à main',
    '👝' => 'pochette',
    '🛍' => 'sacs de magasinage',
    '🎒' => 'sac d’école',
    '🩴' => 'gougoune',
    '👞' => 'chaussure d’homme',
    '👟' => 'chaussure de sport',
    '🥾' => 'chaussure de randonnée',
    '🥿' => 'chaussure plate',
    '👠' => 'chaussure à talon haut',
    '👡' => 'sandale à talon',
    '🩰' => 'chaussons de danse',
    '👢' => 'botte de femme',
    '🪮' => 'démêloir',
    '👑' => 'couronne',
    '👒' => 'chapeau de femme',
    '🎩' => 'haut-de-forme',
    '🎓' => 'chapeau de diplômé',
    '🧢' => 'casquette de baseball',
    '🪖' => 'casque militaire',
    '⛑' => 'casque avec une croix blanche',
    '📿' => 'chapelet',
    '💄' => 'rouge à lèvres',
    '💍' => 'bague',
    '💎' => 'pierre précieuse',
    '🔇' => 'son coupé',
    '🔈' => 'volume faible',
    '🔉' => 'volume moyen',
    '🔊' => 'volume élevé',
    '📢' => 'haut-parleur',
    '📣' => 'porte-voix',
    '📯' => 'cor postal',
    '🔔' => 'cloche',
    '🔕' => 'cloche barrée',
    '🎼' => 'partition',
    '🎵' => 'note de musique',
    '🎶' => 'notes de musique',
    '🎙' => 'micro de studio',
    '🎚' => 'curseur de niveau',
    '🎛' => 'boutons de réglage',
    '🎤' => 'micro',
    '🎧' => 'casque d’écoute',
    '📻' => 'radio',
    '🎷' => 'saxophone',
    '🎺' => 'trompette',
    '🪗' => 'accordéon',
    '🎸' => 'guitare',
    '🎹' => 'piano',
    '🎻' => 'violon',
    '🪕' => 'banjo',
    '🥁' => 'tambour',
    '🪘' => 'djembé',
    '🪇' => 'maracas',
    '🪈' => 'flûte',
    '🪉' => 'harpe',
    '📱' => 'téléphone cellulaire',
    '📲' => 'téléphone cellulaire précédé par une flèche',
    '☎' => 'téléphone',
    '📞' => 'récepteur téléphonique',
    '📟' => 'téléavertisseur',
    '📠' => 'télécopieur',
    '🔋' => 'pile',
    '🪫' => 'pile faible',
    '🔌' => 'prise électrique',
    '💻' => 'ordinateur portable',
    '🖥' => 'ordinateur de bureau',
    '🖨' => 'imprimante',
    '⌨' => 'clavier',
    '🖱' => 'souris d’ordinateur',
    '🖲' => 'boule de commande',
    '💽' => 'disque dur',
    '💾' => 'disquette',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'abaque',
    '🎥' => 'caméra',
    '🎞' => 'pellicule',
    '📽' => 'projecteur cinématographique',
    '🎬' => 'clap',
    '📺' => 'téléviseur',
    '📷' => 'appareil photo',
    '📸' => 'appareil photo avec flash',
    '📹' => 'caméscope',
    '📼' => 'cassette vidéo',
    '🔍' => 'loupe orientée à gauche',
    '🔎' => 'loupe orientée à droite',
    '🕯' => 'bougie',
    '💡' => 'ampoule',
    '🔦' => 'lampe de poche',
    '🏮' => 'lanterne d’izakaya',
    '🪔' => 'diya',
    '📔' => 'carnet avec couverture décorative',
    '📕' => 'livre fermé',
    '📖' => 'livre ouvert',
    '📗' => 'livre vert',
    '📘' => 'livre bleu',
    '📙' => 'livre orange',
    '📚' => 'livres',
    '📓' => 'carnet',
    '📒' => 'carnet de compte',
    '📃' => 'page enroulée',
    '📜' => 'parchemin',
    '📄' => 'page',
    '📰' => 'journal',
    '🗞' => 'journal roulé',
    '📑' => 'onglets',
    '🔖' => 'marque-page',
    '🏷' => 'étiquette',
    '🪙' => 'pièce de monnaie',
    '💰' => 'sac plein d’argent',
    '🪎' => 'coffre au trésor',
    '💴' => 'billet en yens',
    '💵' => 'billet en dollars',
    '💶' => 'billet en euros',
    '💷' => 'billet en livres',
    '💸' => 'billet avec des ailes',
    '💳' => 'carte de crédit',
    '🧾' => 'reçu',
    '💹' => 'courbe croissante précédée du symbole du yen',
    '✉' => 'enveloppe',
    '📧' => 'courriel',
    '📨' => 'message reçu',
    '📩' => 'enveloppe avec flèche',
    '📤' => 'boîte d’envoi',
    '📥' => 'boîte de réception',
    '📦' => 'colis',
    '📫' => 'boîte aux lettres fermée avec drapeau levé',
    '📪' => 'boîte aux lettres fermée avec drapeau baissé',
    '📬' => 'boîte aux lettres ouverte avec drapeau levé',
    '📭' => 'boîte aux lettres ouverte drapeau baissé',
    '📮' => 'boîte aux lettres',
    '🗳' => 'urne électorale',
    '✏' => 'crayon',
    '✒' => 'plume noire',
    '🖋' => 'stylo-plume',
    '🖊' => 'stylo',
    '🖌' => 'pinceau',
    '🖍' => 'crayon de cire',
    '📝' => 'mémo',
    '💼' => 'porte-documents',
    '📁' => 'dossier',
    '📂' => 'dossier ouvert',
    '🗂' => 'intercalaires',
    '📅' => 'calendrier',
    '📆' => 'calendrier à effeuiller',
    '🗒' => 'bloc-notes à spirale',
    '🗓' => 'calendrier à spirale',
    '📇' => 'fiche',
    '📈' => 'graphique en hausse',
    '📉' => 'graphique en baisse',
    '📊' => 'graphiques à barres',
    '📋' => 'presse-papiers',
    '📌' => 'épingle',
    '📍' => 'épingle à tête ronde',
    '📎' => 'trombone',
    '🖇' => 'trombones accrochés',
    '📏' => 'règle',
    '📐' => 'équerre',
    '✂' => 'ciseaux',
    '🗃' => 'boîte à dossiers',
    '🗄' => 'classeur',
    '🗑' => 'corbeille',
    '🔒' => 'cadenas fermé',
    '🔓' => 'cadenas ouvert',
    '🔏' => 'cadenas fermé avec stylo',
    '🔐' => 'cadenas avec clé',
    '🔑' => 'clé',
    '🗝' => 'clé ancienne',
    '🔨' => 'marteau',
    '🪓' => 'hache',
    '⛏' => 'pic',
    '⚒' => 'marteau et pic',
    '🛠' => 'marteau et clé à molette',
    '🗡' => 'dague',
    '⚔' => 'épées croisées',
    '💣' => 'bombe',
    '🪃' => 'boomerang',
    '🏹' => 'arc et flèche',
    '🛡' => 'bouclier',
    '🪚' => 'scie à bois',
    '🔧' => 'clé à molette',
    '🪛' => 'tournevis',
    '🔩' => 'vis et écrou',
    '⚙' => 'engrenage',
    '🗜' => 'serre-joint',
    '⚖' => 'balance à poids',
    '🦯' => 'canne blanche',
    '🔗' => 'chaînons',
    '⛓' => 'chaînes',
    '🪝' => 'crochet',
    '🧰' => 'boîte à outils',
    '🧲' => 'aimant',
    '🪜' => 'échelle',
    '🪏' => 'pelle',
    '⚗' => 'alambic',
    '🧪' => 'tube à essai',
    '🧫' => 'boîte de pétri',
    '🧬' => 'adn',
    '🔬' => 'microscope',
    '🔭' => 'télescope',
    '📡' => 'antenne satellite',
    '💉' => 'seringue',
    '🩸' => 'goutte de sang',
    '💊' => 'pilule',
    '🩹' => 'sparadrap',
    '🩼' => 'béquille',
    '🩺' => 'stéthoscope',
    '🩻' => 'radiographie',
    '🚪' => 'porte',
    '🛗' => 'ascenseur',
    '🪞' => 'miroir',
    '🪟' => 'fenêtre',
    '🛏' => 'lit',
    '🛋' => 'sofa et lampe',
    '🪑' => 'chaise',
    '🚽' => 'siège de toilette',
    '🪠' => 'débouchoir',
    '🚿' => 'douche',
    '🛁' => 'baignoire',
    '🪤' => 'piège à souris',
    '🪒' => 'rasoir',
    '🧴' => 'bouteille de lotion',
    '🧷' => 'épingle de sûreté',
    '🧹' => 'balai',
    '🧺' => 'panier',
    '🧻' => 'rouleau de papier',
    '🪣' => 'seau',
    '🧼' => 'savon',
    '🫧' => 'bulles',
    '🪥' => 'brosse à dents',
    '🧽' => 'éponge',
    '🧯' => 'extincteur',
    '🛒' => 'panier d’épicerie',
    '🚬' => 'cigarette',
    '⚰' => 'cercueil',
    '🪦' => 'pierre tombale',
    '⚱' => 'urne funéraire',
    '🧿' => 'mauvais œil',
    '🪬' => 'main de Fatma',
    '🗿' => 'moaï',
    '🪧' => 'pancarte',
    '🪪' => 'carte d’identité',
    '🏧' => 'guichet automatique bancaire',
    '🚮' => 'icône Poubelle',
    '🚰' => 'eau potable',
    '♿' => 'symbole de fauteuil roulant',
    '🚹' => 'toilettes pour hommes',
    '🚺' => 'toilettes pour femmes',
    '🚻' => 'toilettes',
    '🚼' => 'symbole bébé',
    '🚾' => 'symbole Toilettes',
    '🛂' => 'contrôle des passeports',
    '🛃' => 'douane',
    '🛄' => 'retrait des bagages',
    '🛅' => 'consigne à bagages',
    '⚠' => 'avertissement',
    '🚸' => 'attention, enfants',
    '⛔' => 'sens interdit',
    '🚫' => 'interdit',
    '🚳' => 'vélos interdits',
    '🚭' => 'interdiction de fumer',
    '🚯' => 'dépôt d’ordures interdit',
    '🚱' => 'eau non potable',
    '🚷' => 'interdit aux piétons',
    '📵' => 'téléphones cellulaires interdits',
    '🔞' => '18 ans et plus',
    '☢' => 'radioactif',
    '☣' => 'danger biologique',
    '⬆' => 'flèche pointant vers le haut',
    '↗' => 'flèche pointant vers le haut à droite',
    '➡' => 'flèche pointant vers la droite',
    '↘' => 'flèche pointant vers le bas à droite',
    '⬇' => 'flèche pointant vers le bas',
    '↙' => 'flèche pointant vers le bas à gauche',
    '⬅' => 'flèche pointant vers la gauche',
    '↖' => 'flèche pointant vers le haut à gauche',
    '↕' => 'flèche pointant vers le haut et vers le bas',
    '↔' => 'flèche pointant à gauche et à droite',
    '↩' => 'flèche courbe vers la gauche',
    '↪' => 'flèche courbe vers la droite',
    '⤴' => 'flèche courbe vers le haut',
    '⤵' => 'flèche courbe vers le bas',
    '🔃' => 'flèches verticales dans le sens horaire',
    '🔄' => 'flèches verticales dans le sens antihoraire',
    '🔙' => 'étiquette « BACK » et flèche',
    '🔚' => 'étiquette « END » et flèche',
    '🔛' => 'étiquette « ON! » et flèche',
    '🔜' => 'étiquette « SOON » et flèche',
    '🔝' => 'étiquette « TOP » et flèche',
    '🛐' => 'lieu de culte',
    '⚛' => 'symbole de l’atome',
    '🕉' => 'om',
    '✡' => 'étoile de David',
    '☸' => 'roue du Dharma',
    '☯' => 'yin yang',
    '✝' => 'croix latine',
    '☦' => 'croix orthodoxe',
    '☪' => 'étoile et croissant de lune',
    '☮' => 'symbole de paix',
    '🕎' => 'menora',
    '🔯' => 'étoile à 6 branches et point au milieu',
    '🪯' => 'khanda',
    '♈' => 'Bélier zodiaque',
    '♉' => 'Taureau',
    '♊' => 'Gémeaux',
    '♋' => 'Cancer',
    '♌' => 'Lion',
    '♍' => 'Vierge',
    '♎' => 'Balance',
    '♏' => 'Scorpion zodiaque',
    '♐' => 'Sagittaire',
    '♑' => 'Capricorne',
    '♒' => 'Verseau',
    '♓' => 'Poissons',
    '⛎' => 'Serpentaire',
    '🔀' => 'bouton de lecture aléatoire',
    '🔁' => 'bouton de répétition',
    '🔂' => 'bouton de répétition unique',
    '▶' => 'bouton de lecture',
    '⏩' => 'bouton d’avance rapide',
    '⏭' => 'bouton piste suivante',
    '⏯' => 'bouton lecture/pause',
    '◀' => 'bouton de retour',
    '⏪' => 'bouton de retour rapide',
    '⏮' => 'bouton piste précédente',
    '🔼' => 'bouton vers le haut',
    '⏫' => 'bouton d’accès rapide vers le haut',
    '🔽' => 'bouton vers le bas',
    '⏬' => 'bouton d’accès rapide vers le bas',
    '⏸' => 'bouton pause',
    '⏹' => 'bouton stop',
    '⏺' => 'bouton enregistrer',
    '⏏' => 'bouton éjecter',
    '🎦' => 'cinéma',
    '🔅' => 'luminosité faible',
    '🔆' => 'luminosité élevée',
    '📶' => 'barres de signal',
    '🛜' => 'sans fil',
    '📳' => 'mode vibration',
    '📴' => 'téléphone cellulaire éteint',
    '♀' => 'symbole de la femme',
    '♂' => 'symbole de l’homme',
    '⚧' => 'symbole transgenre',
    '✖' => 'signe de multiplication',
    '➕' => 'signe d’addition',
    '➖' => 'signe de soustraction',
    '➗' => 'signe de division',
    '🟰' => 'signe égal gras',
    '♾' => 'infini',
    '‼' => 'double point d’exclamation',
    '⁉' => 'points d’exclamation et d’interrogation',
    '❓' => 'point d’interrogation rouge',
    '❔' => 'point d’interrogation blanc',
    '❕' => 'point d’exclamation blanc',
    '❗' => 'point d’exclamation rouge',
    '〰' => 'ligne ondulée',
    '💱' => 'change',
    '💲' => 'symbole du dollar en gras',
    '⚕' => 'symbole la médecine',
    '♻' => 'symbole de recyclage',
    '⚜' => 'fleur de lys',
    '🔱' => 'trident',
    '📛' => 'badge nominatif',
    '🔰' => 'symbole japonais du débutant',
    '⭕' => 'cercle rouge',
    '✅' => 'bouton coché',
    '☑' => 'case cochée',
    '✔' => 'coche',
    '❌' => 'croix',
    '❎' => 'bouton croix',
    '➰' => 'boucle',
    '➿' => 'double boucle',
    '〽' => 'marque d’alternance',
    '✳' => 'astérique à huit branches',
    '✴' => 'étoile à huit branches',
    '❇' => 'éclat',
    '™' => 'marque de commerce',
    '🫟' => 'éclaboussure',
    '🔠' => 'majuscules',
    '🔡' => 'minuscules',
    '🔢' => 'saisie de chiffres',
    '🔣' => 'saisie de symboles',
    '🔤' => 'alphabet latin',
    '🅰' => 'groupe sanguin A',
    '🆎' => 'groupe sanguin AB',
    '🅱' => 'groupe sanguin B',
    '🆑' => 'bouton Effacer',
    '🆒' => 'bouton Cool',
    '🆓' => 'free',
    'ℹ' => 'informations',
    '🆔' => 'bouton Identifiant',
    'Ⓜ' => 'm encerclé',
    '🆕' => 'bouton Nouveau',
    '🆖' => 'bouton Pas bien',
    '🅾' => 'groupe sanguin O',
    '🆗' => 'bouton OK',
    '🅿' => 'icône Stationnement',
    '🆘' => 'bouton SOS',
    '🆙' => 'icône UP!',
    '🆚' => 'bouton VS',
    '🈁' => 'symbole japonais signifiant « ici »',
    '🈂' => 'bouton frais de service en japonais',
    '🈷' => 'bouton montant mensuel en japonais',
    '🈶' => 'symbole japonais signifiant « payant »',
    '🈯' => 'symbole japonais signifiant « réservé »',
    '🉐' => 'symbole japonais signifiant « aubaine »',
    '🈹' => 'symbole japonais signifiant « rabais »',
    '🈚' => 'symbole japonais signifiant « gratuit »',
    '🈲' => 'symbole japonais signifiant « interdit »',
    '🉑' => 'symbole japonais signifiant « acceptable »',
    '🈸' => 'symbole japonais signifiant « application »',
    '🈴' => 'symbole japonais signifiant « note de passage »',
    '🈳' => 'bouton chambres disponibles en japonais',
    '㊗' => 'symbole japonais signifiant « félicitations »',
    '㊙' => 'symbole japonais signifiant « secret »',
    '🈺' => 'symbole japonais signifiant « ouvert »',
    '🈵' => 'symbole japonais signifiant « complet »',
    '🔴' => 'disque rouge',
    '🟠' => 'cercle orange',
    '🟡' => 'cercle jaune',
    '🟢' => 'cercle vert',
    '🔵' => 'rond bleu',
    '🟣' => 'cercle violet',
    '🟤' => 'cercle brun',
    '⚫' => 'rond noir',
    '⚪' => 'rond blanc',
    '🟥' => 'carré rouge',
    '🟧' => 'carré orange',
    '🟨' => 'carré jaune',
    '🟩' => 'carré vert',
    '🟦' => 'carré bleu',
    '🟪' => 'carré violet',
    '🟫' => 'carré brun',
    '⬛' => 'grand carré noir',
    '⬜' => 'grand carré blanc',
    '◼' => 'carré noir de taille moyenne',
    '◻' => 'carré blanc de taille moyenne',
    '◾' => 'carré noir de taille intermédiaire',
    '◽' => 'carré blanc de taille intermédiaire',
    '▪' => 'petit carré noir',
    '▫' => 'petit carré blanc',
    '🔶' => 'grand losange orange',
    '🔷' => 'grand losange bleu',
    '🔸' => 'petit losange orange',
    '🔹' => 'petit losange bleu',
    '🔺' => 'triangle rouge qui pointe vers le haut',
    '🔻' => 'triangle rouge qui pointe vers le bas',
    '💠' => 'diamant avec un point',
    '🔘' => 'bouton radio',
    '🔳' => 'bouton représentant un carré blanc',
    '🔲' => 'bouton représentant un carré noir',
    '🏁' => 'drapeau à damier',
    '🚩' => 'drapeau triangulaire',
    '🎌' => 'drapeaux croisés',
    '🏴' => 'drapeau noir',
    '🏳' => 'drapeau blanc',
];
